@@ -40,12 +40,11 @@ struct _ValaCCodeBlockPrivate {
 
 #define VALA_CCODE_BLOCK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_BLOCK, ValaCCodeBlockPrivate))
 enum  {
-	VALA_CCODE_BLOCK_DUMMY_PROPERTY,
-	VALA_CCODE_BLOCK_SUPPRESS_NEWLINE
+	VALA_CCODE_BLOCK_DUMMY_PROPERTY
 };
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_block_parent_class = NULL;
-static void vala_ccode_block_dispose (GObject * obj);
+static void vala_ccode_block_finalize (ValaCCodeNode* obj);
 
 
 
@@ -91,17 +90,17 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 				if (VALA_IS_CCODE_LABEL (statement)) {
 					ValaCCodeNode* _tmp0;
 					_tmp0 = NULL;
-					last_statement = (_tmp0 = NULL, (last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL))), _tmp0);
+					last_statement = (_tmp0 = NULL, (last_statement == NULL ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL))), _tmp0);
 				} else {
 					if (VALA_IS_CCODE_RETURN_STATEMENT (statement) || VALA_IS_CCODE_GOTO_STATEMENT (statement) || VALA_IS_CCODE_CONTINUE_STATEMENT (statement) || VALA_IS_CCODE_BREAK_STATEMENT (statement)) {
 						ValaCCodeNode* _tmp2;
 						ValaCCodeNode* _tmp1;
 						_tmp2 = NULL;
 						_tmp1 = NULL;
-						last_statement = (_tmp2 = (_tmp1 = statement, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL))), _tmp2);
+						last_statement = (_tmp2 = (_tmp1 = statement, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (last_statement == NULL ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL))), _tmp2);
 					}
 				}
-				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
+				(statement == NULL ? NULL : (statement = (vala_ccode_node_unref (statement), NULL)));
 			}
 		}
 	}
@@ -116,10 +115,10 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 				vala_ccode_node_write (statement, writer);
 				/* only output reachable code*/
 				if (statement == last_statement) {
-					(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
+					(statement == NULL ? NULL : (statement = (vala_ccode_node_unref (statement), NULL)));
 					break;
 				}
-				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
+				(statement == NULL ? NULL : (statement = (vala_ccode_node_unref (statement), NULL)));
 			}
 		}
 	}
@@ -127,20 +126,25 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 	if (!self->priv->_suppress_newline) {
 		vala_ccode_writer_write_newline (writer);
 	}
-	(last_statement == NULL ? NULL : (last_statement = (g_object_unref (last_statement), NULL)));
+	(last_statement == NULL ? NULL : (last_statement = (vala_ccode_node_unref (last_statement), NULL)));
 }
 
 
 /**
  * Represents a C code block.
  */
-ValaCCodeBlock* vala_ccode_block_new (void) {
-	ValaCCodeBlock * self;
-	self = g_object_newv (VALA_TYPE_CCODE_BLOCK, 0, NULL);
+ValaCCodeBlock* vala_ccode_block_construct (GType object_type) {
+	ValaCCodeBlock* self;
+	self = ((ValaCCodeBlock*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeBlock* vala_ccode_block_new (void) {
+	return vala_ccode_block_construct (VALA_TYPE_CCODE_BLOCK);
+}
+
+
 gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_BLOCK (self), FALSE);
 	return self->priv->_suppress_newline;
@@ -153,63 +157,32 @@ void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value
 }
 
 
-static void vala_ccode_block_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeBlock * self;
-	self = VALA_CCODE_BLOCK (object);
-	switch (property_id) {
-		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
-		g_value_set_boolean (value, vala_ccode_block_get_suppress_newline (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_block_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeBlock * self;
-	self = VALA_CCODE_BLOCK (object);
-	switch (property_id) {
-		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
-		vala_ccode_block_set_suppress_newline (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass) {
 	vala_ccode_block_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_block_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeBlockPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_block_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_block_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_block_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_block_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BLOCK_SUPPRESS_NEWLINE, g_param_spec_boolean ("suppress-newline", "suppress-newline", "suppress-newline", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_block_instance_init (ValaCCodeBlock * self) {
 	self->priv = VALA_CCODE_BLOCK_GET_PRIVATE (self);
-	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_block_dispose (GObject * obj) {
+static void vala_ccode_block_finalize (ValaCCodeNode* obj) {
 	ValaCCodeBlock * self;
 	self = VALA_CCODE_BLOCK (obj);
-	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_object_unref (self->priv->statements), NULL)));
-	G_OBJECT_CLASS (vala_ccode_block_parent_class)->dispose (obj);
+	(self->priv->statements == NULL ? NULL : (self->priv->statements = (gee_collection_object_unref (self->priv->statements), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_block_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_block_get_type (void) {
 	static GType vala_ccode_block_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_block_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBlock), 0, (GInstanceInitFunc) vala_ccode_block_instance_init };
+	if (vala_ccode_block_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBlock), 0, (GInstanceInitFunc) vala_ccode_block_instance_init, NULL };
 		vala_ccode_block_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeBlock", &g_define_type_info, 0);
 	}
 	return vala_ccode_block_type_id;
