@@ -50,13 +50,18 @@ static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCod
 /**
  * Represents a break statement in the C code.
  */
-ValaCCodeBreakStatement* vala_ccode_break_statement_new (void) {
-	ValaCCodeBreakStatement * self;
-	self = g_object_newv (VALA_TYPE_CCODE_BREAK_STATEMENT, 0, NULL);
+ValaCCodeBreakStatement* vala_ccode_break_statement_construct (GType object_type) {
+	ValaCCodeBreakStatement* self;
+	self = ((ValaCCodeBreakStatement*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeBreakStatement* vala_ccode_break_statement_new (void) {
+	return vala_ccode_break_statement_construct (VALA_TYPE_CCODE_BREAK_STATEMENT);
+}
+
+
 static void vala_ccode_break_statement_class_init (ValaCCodeBreakStatementClass * klass) {
 	vala_ccode_break_statement_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_break_statement_real_write;
@@ -70,7 +75,7 @@ static void vala_ccode_break_statement_instance_init (ValaCCodeBreakStatement *
 GType vala_ccode_break_statement_get_type (void) {
 	static GType vala_ccode_break_statement_type_id = 0;
 	if (vala_ccode_break_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBreakStatement), 0, (GInstanceInitFunc) vala_ccode_break_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBreakStatement), 0, (GInstanceInitFunc) vala_ccode_break_statement_instance_init, NULL };
 		vala_ccode_break_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeBreakStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_break_statement_type_id;
