@@ -1,6 +1,6 @@
 /* valaccodecastexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,41 +30,30 @@ struct _ValaCCodeCastExpressionPrivate {
 	ValaCCodeExpression* _inner;
 	char* _type_name;
 };
+
 #define VALA_CCODE_CAST_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CAST_EXPRESSION, ValaCCodeCastExpressionPrivate))
 enum  {
-	VALA_CCODE_CAST_EXPRESSION_DUMMY_PROPERTY,
-	VALA_CCODE_CAST_EXPRESSION_INNER,
-	VALA_CCODE_CAST_EXPRESSION_TYPE_NAME
+	VALA_CCODE_CAST_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_cast_expression_parent_class = NULL;
-static void vala_ccode_cast_expression_dispose (GObject * obj);
+static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeCastExpression* vala_ccode_cast_expression_construct (GType object_type, ValaCCodeExpression* expr, const char* type) {
+	ValaCCodeCastExpression* self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (type != NULL, NULL);
+	self = ((ValaCCodeCastExpression*) (g_type_create_instance (object_type)));
+	vala_ccode_cast_expression_set_inner (self, expr);
+	vala_ccode_cast_expression_set_type_name (self, type);
+	return self;
+}
+
+
 ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* expr, const char* type) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeCastExpression * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (type != NULL, NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, expr);
-	__params_it++;
-	__params_it->name = "type-name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, type);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_CAST_EXPRESSION, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_cast_expression_construct (VALA_TYPE_CCODE_CAST_EXPRESSION, expr, type);
 }
 
 
@@ -75,8 +64,9 @@ static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCod
 	vala_ccode_writer_write_string (writer, "((");
 	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, ") ");
+	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
-	vala_ccode_writer_write_string (writer, ")");
+	vala_ccode_writer_write_string (writer, "))");
 }
 
 
@@ -92,11 +82,11 @@ void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCC
 	g_return_if_fail (VALA_IS_CCODE_CAST_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
-char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
+const char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_CAST_EXPRESSION (self), NULL);
 	return self->priv->_type_name;
 }
@@ -112,70 +102,32 @@ void vala_ccode_cast_expression_set_type_name (ValaCCodeCastExpression* self, co
 }
 
 
-static void vala_ccode_cast_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeCastExpression * self;
-	self = VALA_CCODE_CAST_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_CCODE_CAST_EXPRESSION_INNER:
-		g_value_set_object (value, vala_ccode_cast_expression_get_inner (self));
-		break;
-		case VALA_CCODE_CAST_EXPRESSION_TYPE_NAME:
-		g_value_set_string (value, vala_ccode_cast_expression_get_type_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_cast_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeCastExpression * self;
-	self = VALA_CCODE_CAST_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_CCODE_CAST_EXPRESSION_INNER:
-		vala_ccode_cast_expression_set_inner (self, g_value_get_object (value));
-		break;
-		case VALA_CCODE_CAST_EXPRESSION_TYPE_NAME:
-		vala_ccode_cast_expression_set_type_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_ccode_cast_expression_class_init (ValaCCodeCastExpressionClass * klass) {
 	vala_ccode_cast_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_cast_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeCastExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_cast_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_cast_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_cast_expression_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_cast_expression_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CAST_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CAST_EXPRESSION_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_ccode_cast_expression_init (ValaCCodeCastExpression * self) {
+static void vala_ccode_cast_expression_instance_init (ValaCCodeCastExpression * self) {
 	self->priv = VALA_CCODE_CAST_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_cast_expression_dispose (GObject * obj) {
+static void vala_ccode_cast_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)));
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_cast_expression_parent_class)->dispose (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_cast_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_cast_expression_get_type (void) {
 	static GType vala_ccode_cast_expression_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_cast_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCastExpression), 0, (GInstanceInitFunc) vala_ccode_cast_expression_init };
+	if (vala_ccode_cast_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCastExpression), 0, (GInstanceInitFunc) vala_ccode_cast_expression_instance_init, NULL };
 		vala_ccode_cast_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeCastExpression", &g_define_type_info, 0);
 	}
 	return vala_ccode_cast_expression_type_id;
