@@ -39,24 +39,27 @@ struct _ValaCCodeDeclarationPrivate {
 
 #define VALA_CCODE_DECLARATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DECLARATION, ValaCCodeDeclarationPrivate))
 enum  {
-	VALA_CCODE_DECLARATION_DUMMY_PROPERTY,
-	VALA_CCODE_DECLARATION_TYPE_NAME,
-	VALA_CCODE_DECLARATION_MODIFIERS
+	VALA_CCODE_DECLARATION_DUMMY_PROPERTY
 };
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self);
 static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_declaration_parent_class = NULL;
-static void vala_ccode_declaration_finalize (GObject * obj);
+static void vala_ccode_declaration_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeDeclaration* vala_ccode_declaration_construct (GType object_type, const char* type_name) {
+	ValaCCodeDeclaration* self;
+	g_return_val_if_fail (type_name != NULL, NULL);
+	self = ((ValaCCodeDeclaration*) (g_type_create_instance (object_type)));
+	vala_ccode_declaration_set_type_name (self, type_name);
+	return self;
+}
+
+
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name) {
-	ValaCCodeDeclaration * self;
-	g_return_val_if_fail (type_name != NULL, NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_DECLARATION, 0, NULL);
-	vala_ccode_declaration_set_type_name (self, type_name);
-	return self;
+	return vala_ccode_declaration_construct (VALA_TYPE_CCODE_DECLARATION, type_name);
 }
 
 
@@ -106,7 +109,7 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 						first = FALSE;
 					}
 					vala_ccode_node_write (VALA_CCODE_NODE (decl), writer);
-					(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
+					(decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)));
 				}
 			}
 		}
@@ -122,7 +125,7 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 				decl = ((ValaCCodeDeclarator*) (gee_list_get (GEE_LIST (decl_collection), decl_it)));
 				{
 					vala_ccode_declarator_write_initialization (decl, writer);
-					(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
+					(decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)));
 				}
 			}
 		}
@@ -145,13 +148,13 @@ static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* se
 				ValaCCodeVariableDeclarator* var_decl;
 				_tmp1 = NULL;
 				_tmp0 = NULL;
-				var_decl = (_tmp1 = (_tmp0 = decl, (VALA_IS_CCODE_VARIABLE_DECLARATOR (_tmp0) ? ((ValaCCodeVariableDeclarator*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				var_decl = (_tmp1 = (_tmp0 = decl, (VALA_IS_CCODE_VARIABLE_DECLARATOR (_tmp0) ? ((ValaCCodeVariableDeclarator*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1)));
 				if (var_decl != NULL && vala_ccode_variable_declarator_get_initializer (var_decl) == NULL) {
 					gboolean _tmp2;
-					return (_tmp2 = FALSE, (decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL))), (var_decl == NULL ? NULL : (var_decl = (g_object_unref (var_decl), NULL))), _tmp2);
+					return (_tmp2 = FALSE, (decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL))), (var_decl == NULL ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL))), _tmp2);
 				}
-				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
-				(var_decl == NULL ? NULL : (var_decl = (g_object_unref (var_decl), NULL)));
+				(decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)));
+				(var_decl == NULL ? NULL : (var_decl = (vala_ccode_node_unref (var_decl), NULL)));
 			}
 		}
 	}
@@ -189,7 +192,7 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 					first = FALSE;
 				}
 				vala_ccode_node_write_declaration (VALA_CCODE_NODE (decl), writer);
-				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
+				(decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)));
 			}
 		}
 	}
@@ -211,7 +214,6 @@ void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const cha
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "type-name");
 }
 
 
@@ -224,76 +226,37 @@ ValaCCodeModifiers vala_ccode_declaration_get_modifiers (ValaCCodeDeclaration* s
 void vala_ccode_declaration_set_modifiers (ValaCCodeDeclaration* self, ValaCCodeModifiers value) {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATION (self));
 	self->priv->_modifiers = value;
-	g_object_notify (((GObject *) (self)), "modifiers");
-}
-
-
-static void vala_ccode_declaration_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeDeclaration * self;
-	self = VALA_CCODE_DECLARATION (object);
-	switch (property_id) {
-		case VALA_CCODE_DECLARATION_TYPE_NAME:
-		g_value_set_string (value, vala_ccode_declaration_get_type_name (self));
-		break;
-		case VALA_CCODE_DECLARATION_MODIFIERS:
-		g_value_set_flags (value, vala_ccode_declaration_get_modifiers (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_declaration_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeDeclaration * self;
-	self = VALA_CCODE_DECLARATION (object);
-	switch (property_id) {
-		case VALA_CCODE_DECLARATION_TYPE_NAME:
-		vala_ccode_declaration_set_type_name (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_DECLARATION_MODIFIERS:
-		vala_ccode_declaration_set_modifiers (self, g_value_get_flags (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_ccode_declaration_class_init (ValaCCodeDeclarationClass * klass) {
 	vala_ccode_declaration_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_declaration_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeDeclarationPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_declaration_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_declaration_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_declaration_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_declaration_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_declaration_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_MODIFIERS, g_param_spec_flags ("modifiers", "modifiers", "modifiers", VALA_TYPE_CCODE_MODIFIERS, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_declaration_instance_init (ValaCCodeDeclaration * self) {
 	self->priv = VALA_CCODE_DECLARATION_GET_PRIVATE (self);
-	self->priv->declarators = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_DECLARATOR, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->declarators = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_DECLARATOR, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_declaration_finalize (GObject * obj) {
+static void vala_ccode_declaration_finalize (ValaCCodeNode* obj) {
 	ValaCCodeDeclaration * self;
 	self = VALA_CCODE_DECLARATION (obj);
 	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	(self->priv->declarators == NULL ? NULL : (self->priv->declarators = (g_object_unref (self->priv->declarators), NULL)));
-	G_OBJECT_CLASS (vala_ccode_declaration_parent_class)->finalize (obj);
+	(self->priv->declarators == NULL ? NULL : (self->priv->declarators = (gee_collection_object_unref (self->priv->declarators), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_declaration_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_declaration_get_type (void) {
 	static GType vala_ccode_declaration_type_id = 0;
 	if (vala_ccode_declaration_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDeclarationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_declaration_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDeclaration), 0, (GInstanceInitFunc) vala_ccode_declaration_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDeclarationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_declaration_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDeclaration), 0, (GInstanceInitFunc) vala_ccode_declaration_instance_init, NULL };
 		vala_ccode_declaration_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeDeclaration", &g_define_type_info, 0);
 	}
 	return vala_ccode_declaration_type_id;
