@@ -22,8 +22,8 @@
 
 #include <ccode/valaccodefragment.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 
 
 
@@ -40,7 +40,7 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_fragment_parent_class = NULL;
-static void vala_ccode_fragment_dispose (GObject * obj);
+static void vala_ccode_fragment_finalize (ValaCCodeNode* obj);
 
 
 
@@ -61,9 +61,9 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
  *
  * @return children list
  */
-GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
+GeeList* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FRAGMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->children)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, self->priv->children));
 }
 
 
@@ -73,18 +73,16 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write (node, writer);
-				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
+				(node == NULL ? NULL : (node = (vala_ccode_node_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -95,18 +93,16 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_declaration (node, writer);
-				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
+				(node == NULL ? NULL : (node = (vala_ccode_node_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -117,18 +113,16 @@ static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCC
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_combined (node, writer);
-				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
+				(node == NULL ? NULL : (node = (vala_ccode_node_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -136,41 +130,46 @@ static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCC
 /**
  * Represents a container for C code nodes.
  */
-ValaCCodeFragment* vala_ccode_fragment_new (void) {
-	ValaCCodeFragment * self;
-	self = g_object_newv (VALA_TYPE_CCODE_FRAGMENT, 0, NULL);
+ValaCCodeFragment* vala_ccode_fragment_construct (GType object_type) {
+	ValaCCodeFragment* self;
+	self = ((ValaCCodeFragment*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeFragment* vala_ccode_fragment_new (void) {
+	return vala_ccode_fragment_construct (VALA_TYPE_CCODE_FRAGMENT);
+}
+
+
 static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass) {
 	vala_ccode_fragment_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_fragment_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeFragmentPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_fragment_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_fragment_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_fragment_real_write_declaration;
 	VALA_CCODE_NODE_CLASS (klass)->write_combined = vala_ccode_fragment_real_write_combined;
 }
 
 
-static void vala_ccode_fragment_init (ValaCCodeFragment * self) {
+static void vala_ccode_fragment_instance_init (ValaCCodeFragment * self) {
 	self->priv = VALA_CCODE_FRAGMENT_GET_PRIVATE (self);
-	self->priv->children = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->children = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_fragment_dispose (GObject * obj) {
+static void vala_ccode_fragment_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (obj);
-	(self->priv->children == NULL ? NULL : (self->priv->children = (g_object_unref (self->priv->children), NULL)));
-	G_OBJECT_CLASS (vala_ccode_fragment_parent_class)->dispose (obj);
+	(self->priv->children == NULL ? NULL : (self->priv->children = (gee_collection_object_unref (self->priv->children), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_fragment_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_fragment_get_type (void) {
 	static GType vala_ccode_fragment_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_fragment_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_init };
+	if (vala_ccode_fragment_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_instance_init, NULL };
 		vala_ccode_fragment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFragment", &g_define_type_info, 0);
 	}
 	return vala_ccode_fragment_type_id;
