@@ -39,29 +39,30 @@ struct _ValaCCodeFunctionPrivate {
 
 #define VALA_CCODE_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION, ValaCCodeFunctionPrivate))
 enum  {
-	VALA_CCODE_FUNCTION_DUMMY_PROPERTY,
-	VALA_CCODE_FUNCTION_NAME,
-	VALA_CCODE_FUNCTION_MODIFIERS,
-	VALA_CCODE_FUNCTION_RETURN_TYPE,
-	VALA_CCODE_FUNCTION_BLOCK
+	VALA_CCODE_FUNCTION_DUMMY_PROPERTY
 };
 static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_parent_class = NULL;
-static void vala_ccode_function_dispose (GObject * obj);
+static void vala_ccode_function_finalize (ValaCCodeNode* obj);
 
 
 
-ValaCCodeFunction* vala_ccode_function_new (const char* name, const char* return_type) {
-	ValaCCodeFunction * self;
+ValaCCodeFunction* vala_ccode_function_construct (GType object_type, const char* name, const char* return_type) {
+	ValaCCodeFunction* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (return_type != NULL, NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION, 0, NULL);
+	self = ((ValaCCodeFunction*) (g_type_create_instance (object_type)));
 	vala_ccode_function_set_return_type (self, return_type);
 	vala_ccode_function_set_name (self, name);
 	return self;
 }
 
 
+ValaCCodeFunction* vala_ccode_function_new (const char* name, const char* return_type) {
+	return vala_ccode_function_construct (VALA_TYPE_CCODE_FUNCTION, name, return_type);
+}
+
+
 /**
  * Appends the specified parameter to the list of function parameters.
  *
@@ -89,18 +90,16 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self) {
 	 */
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaCCodeFormalParameter* param;
-			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaCCodeFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				gee_collection_add (GEE_COLLECTION (func->priv->parameters), param);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_ccode_node_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	vala_ccode_function_set_block (func, self->priv->_block);
 	return func;
@@ -126,12 +125,11 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	first = TRUE;
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaCCodeFormalParameter* param;
-			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaCCodeFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -139,10 +137,9 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 					first = FALSE;
 				}
 				vala_ccode_node_write (VALA_CCODE_NODE (param), writer);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_ccode_node_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	if (first) {
 		vala_ccode_writer_write_string (writer, "void");
@@ -158,7 +155,7 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 }
 
 
-char* vala_ccode_function_get_name (ValaCCodeFunction* self) {
+const char* vala_ccode_function_get_name (ValaCCodeFunction* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
 	return self->priv->_name;
 }
@@ -186,7 +183,7 @@ void vala_ccode_function_set_modifiers (ValaCCodeFunction* self, ValaCCodeModifi
 }
 
 
-char* vala_ccode_function_get_return_type (ValaCCodeFunction* self) {
+const char* vala_ccode_function_get_return_type (ValaCCodeFunction* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
 	return self->priv->_return_type;
 }
@@ -214,91 +211,39 @@ void vala_ccode_function_set_block (ValaCCodeFunction* self, ValaCCodeBlock* val
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunction * self;
-	self = VALA_CCODE_FUNCTION (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_NAME:
-		g_value_set_string (value, vala_ccode_function_get_name (self));
-		break;
-		case VALA_CCODE_FUNCTION_MODIFIERS:
-		g_value_set_flags (value, vala_ccode_function_get_modifiers (self));
-		break;
-		case VALA_CCODE_FUNCTION_RETURN_TYPE:
-		g_value_set_string (value, vala_ccode_function_get_return_type (self));
-		break;
-		case VALA_CCODE_FUNCTION_BLOCK:
-		g_value_set_object (value, vala_ccode_function_get_block (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunction * self;
-	self = VALA_CCODE_FUNCTION (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_NAME:
-		vala_ccode_function_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_FUNCTION_MODIFIERS:
-		vala_ccode_function_set_modifiers (self, g_value_get_flags (value));
-		break;
-		case VALA_CCODE_FUNCTION_RETURN_TYPE:
-		vala_ccode_function_set_return_type (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_FUNCTION_BLOCK:
-		vala_ccode_function_set_block (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_block == NULL ? NULL : (self->priv->_block = (vala_ccode_node_unref (self->priv->_block), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_function_class_init (ValaCCodeFunctionClass * klass) {
 	vala_ccode_function_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_function_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_MODIFIERS, g_param_spec_flags ("modifiers", "modifiers", "modifiers", VALA_TYPE_CCODE_MODIFIERS, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_RETURN_TYPE, g_param_spec_string ("return-type", "return-type", "return-type", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_BLOCK, g_param_spec_object ("block", "block", "block", VALA_TYPE_CCODE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_init (ValaCCodeFunction * self) {
+static void vala_ccode_function_instance_init (ValaCCodeFunction * self) {
 	self->priv = VALA_CCODE_FUNCTION_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_dispose (GObject * obj) {
+static void vala_ccode_function_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFunction * self;
 	self = VALA_CCODE_FUNCTION (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	self->priv->_return_type = (g_free (self->priv->_return_type), NULL);
-	(self->priv->_block == NULL ? NULL : (self->priv->_block = (g_object_unref (self->priv->_block), NULL)));
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	G_OBJECT_CLASS (vala_ccode_function_parent_class)->dispose (obj);
+	(self->priv->_block == NULL ? NULL : (self->priv->_block = (vala_ccode_node_unref (self->priv->_block), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_function_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_function_get_type (void) {
 	static GType vala_ccode_function_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunction), 0, (GInstanceInitFunc) vala_ccode_function_init };
+	if (vala_ccode_function_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunction), 0, (GInstanceInitFunc) vala_ccode_function_instance_init, NULL };
 		vala_ccode_function_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFunction", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_type_id;
