@@ -38,21 +38,25 @@ struct _ValaCCodeFunctionCallPrivate {
 
 #define VALA_CCODE_FUNCTION_CALL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCallPrivate))
 enum  {
-	VALA_CCODE_FUNCTION_CALL_DUMMY_PROPERTY,
-	VALA_CCODE_FUNCTION_CALL_CALL
+	VALA_CCODE_FUNCTION_CALL_DUMMY_PROPERTY
 };
 static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_call_parent_class = NULL;
-static void vala_ccode_function_call_dispose (GObject * obj);
+static void vala_ccode_function_call_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeFunctionCall* vala_ccode_function_call_construct (GType object_type, ValaCCodeExpression* call) {
+	ValaCCodeFunctionCall* self;
+	g_return_val_if_fail (call == NULL || VALA_IS_CCODE_EXPRESSION (call), NULL);
+	self = ((ValaCCodeFunctionCall*) (g_type_create_instance (object_type)));
+	vala_ccode_function_call_set_call (self, call);
+	return self;
+}
+
+
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call) {
-	ValaCCodeFunctionCall * self;
-	g_return_val_if_fail (call == NULL || VALA_IS_CCODE_EXPRESSION (call), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_CALL, 0, NULL);
-	vala_ccode_function_call_set_call (self, call);
-	return self;
+	return vala_ccode_function_call_construct (VALA_TYPE_CCODE_FUNCTION_CALL, call);
 }
 
 
@@ -75,7 +79,7 @@ void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCo
  */
 GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->arguments));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, self->priv->arguments));
 }
 
 
@@ -89,12 +93,11 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 	first = TRUE;
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->arguments;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaCCodeExpression* expr;
-			expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
+			expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -104,10 +107,9 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 				if (expr != NULL) {
 					vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
 				}
-				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				(expr == NULL ? NULL : (expr = (vala_ccode_node_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
@@ -125,68 +127,37 @@ void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeEx
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_function_call_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionCall * self;
-	self = VALA_CCODE_FUNCTION_CALL (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_CALL_CALL:
-		g_value_set_object (value, vala_ccode_function_call_get_call (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_function_call_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionCall * self;
-	self = VALA_CCODE_FUNCTION_CALL (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_CALL_CALL:
-		vala_ccode_function_call_set_call (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (vala_ccode_node_unref (self->priv->_call), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * klass) {
 	vala_ccode_function_call_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_function_call_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionCallPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_call_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_call_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_function_call_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_call_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_CALL_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self) {
+static void vala_ccode_function_call_instance_init (ValaCCodeFunctionCall * self) {
 	self->priv = VALA_CCODE_FUNCTION_CALL_GET_PRIVATE (self);
-	self->priv->arguments = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->arguments = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_call_dispose (GObject * obj) {
+static void vala_ccode_function_call_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (obj);
-	(self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL)));
-	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (g_object_unref (self->priv->arguments), NULL)));
-	G_OBJECT_CLASS (vala_ccode_function_call_parent_class)->dispose (obj);
+	(self->priv->_call == NULL ? NULL : (self->priv->_call = (vala_ccode_node_unref (self->priv->_call), NULL)));
+	(self->priv->arguments == NULL ? NULL : (self->priv->arguments = (gee_collection_object_unref (self->priv->arguments), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_function_call_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_function_call_get_type (void) {
 	static GType vala_ccode_function_call_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_function_call_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_init };
+	if (vala_ccode_function_call_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_instance_init, NULL };
 		vala_ccode_function_call_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeFunctionCall", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_call_type_id;
