@@ -35,22 +35,26 @@ struct _ValaCCodeFunctionDeclaratorPrivate {
 
 #define VALA_CCODE_FUNCTION_DECLARATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_DECLARATOR, ValaCCodeFunctionDeclaratorPrivate))
 enum  {
-	VALA_CCODE_FUNCTION_DECLARATOR_DUMMY_PROPERTY,
-	VALA_CCODE_FUNCTION_DECLARATOR_NAME
+	VALA_CCODE_FUNCTION_DECLARATOR_DUMMY_PROPERTY
 };
 static void vala_ccode_function_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_function_declarator_parent_class = NULL;
-static void vala_ccode_function_declarator_finalize (GObject * obj);
+static void vala_ccode_function_declarator_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_construct (GType object_type, const char* name) {
+	ValaCCodeFunctionDeclarator* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	self = ((ValaCCodeFunctionDeclarator*) (g_type_create_instance (object_type)));
+	vala_ccode_function_declarator_set_name (self, name);
+	return self;
+}
+
+
 ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name) {
-	ValaCCodeFunctionDeclarator * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, 0, NULL);
-	vala_ccode_function_declarator_set_name (self, name);
-	return self;
+	return vala_ccode_function_declarator_construct (VALA_TYPE_CCODE_FUNCTION_DECLARATOR, name);
 }
 
 
@@ -97,7 +101,7 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 					first = FALSE;
 				}
 				vala_ccode_node_write (VALA_CCODE_NODE (param), writer);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_ccode_node_unref (param), NULL)));
 			}
 		}
 	}
@@ -118,69 +122,37 @@ void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self,
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
-}
-
-
-static void vala_ccode_function_declarator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionDeclarator * self;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_DECLARATOR_NAME:
-		g_value_set_string (value, vala_ccode_function_declarator_get_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_function_declarator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeFunctionDeclarator * self;
-	self = VALA_CCODE_FUNCTION_DECLARATOR (object);
-	switch (property_id) {
-		case VALA_CCODE_FUNCTION_DECLARATOR_NAME:
-		vala_ccode_function_declarator_set_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_ccode_function_declarator_class_init (ValaCCodeFunctionDeclaratorClass * klass) {
 	vala_ccode_function_declarator_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_function_declarator_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeFunctionDeclaratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_function_declarator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_function_declarator_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_function_declarator_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_function_declarator_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_function_declarator_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_FUNCTION_DECLARATOR_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_function_declarator_instance_init (ValaCCodeFunctionDeclarator * self) {
 	self->priv = VALA_CCODE_FUNCTION_DECLARATOR_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_function_declarator_finalize (GObject * obj) {
+static void vala_ccode_function_declarator_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	G_OBJECT_CLASS (vala_ccode_function_declarator_parent_class)->finalize (obj);
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_function_declarator_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_function_declarator_get_type (void) {
 	static GType vala_ccode_function_declarator_type_id = 0;
 	if (vala_ccode_function_declarator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionDeclarator), 0, (GInstanceInitFunc) vala_ccode_function_declarator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionDeclarator), 0, (GInstanceInitFunc) vala_ccode_function_declarator_instance_init, NULL };
 		vala_ccode_function_declarator_type_id = g_type_register_static (VALA_TYPE_CCODE_DECLARATOR, "ValaCCodeFunctionDeclarator", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_declarator_type_id;
