@@ -32,33 +32,25 @@ struct _ValaCCodeLabelPrivate {
 
 #define VALA_CCODE_LABEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_LABEL, ValaCCodeLabelPrivate))
 enum  {
-	VALA_CCODE_LABEL_DUMMY_PROPERTY,
-	VALA_CCODE_LABEL_NAME
+	VALA_CCODE_LABEL_DUMMY_PROPERTY
 };
 static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_label_parent_class = NULL;
-static void vala_ccode_label_finalize (GObject * obj);
+static void vala_ccode_label_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeLabel* vala_ccode_label_construct (GType object_type, const char* name) {
+	ValaCCodeLabel* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	self = ((ValaCCodeLabel*) (g_type_create_instance (object_type)));
+	vala_ccode_label_set_name (self, name);
+	return self;
+}
+
+
 ValaCCodeLabel* vala_ccode_label_new (const char* name) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeLabel * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, name);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_LABEL, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_label_construct (VALA_TYPE_CCODE_LABEL, name);
 }
 
 
@@ -86,46 +78,14 @@ void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
-}
-
-
-static void vala_ccode_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeLabel * self;
-	self = VALA_CCODE_LABEL (object);
-	switch (property_id) {
-		case VALA_CCODE_LABEL_NAME:
-		g_value_set_string (value, vala_ccode_label_get_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeLabel * self;
-	self = VALA_CCODE_LABEL (object);
-	switch (property_id) {
-		case VALA_CCODE_LABEL_NAME:
-		vala_ccode_label_set_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_ccode_label_class_init (ValaCCodeLabelClass * klass) {
 	vala_ccode_label_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_label_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeLabelPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_label_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_label_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_label_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_label_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LABEL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -134,18 +94,18 @@ static void vala_ccode_label_instance_init (ValaCCodeLabel * self) {
 }
 
 
-static void vala_ccode_label_finalize (GObject * obj) {
+static void vala_ccode_label_finalize (ValaCCodeNode* obj) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_label_parent_class)->finalize (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_label_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_label_get_type (void) {
 	static GType vala_ccode_label_type_id = 0;
 	if (vala_ccode_label_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_instance_init, NULL };
 		vala_ccode_label_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeLabel", &g_define_type_info, 0);
 	}
 	return vala_ccode_label_type_id;
