@@ -33,35 +33,26 @@ struct _ValaCCodeLineDirectivePrivate {
 
 #define VALA_CCODE_LINE_DIRECTIVE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectivePrivate))
 enum  {
-	VALA_CCODE_LINE_DIRECTIVE_DUMMY_PROPERTY,
-	VALA_CCODE_LINE_DIRECTIVE_FILENAME,
-	VALA_CCODE_LINE_DIRECTIVE_LINE
+	VALA_CCODE_LINE_DIRECTIVE_DUMMY_PROPERTY
 };
 static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_line_directive_parent_class = NULL;
-static void vala_ccode_line_directive_finalize (GObject * obj);
+static void vala_ccode_line_directive_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeLineDirective* vala_ccode_line_directive_construct (GType object_type, const char* _filename, gint _line) {
+	ValaCCodeLineDirective* self;
+	g_return_val_if_fail (_filename != NULL, NULL);
+	self = ((ValaCCodeLineDirective*) (g_type_create_instance (object_type)));
+	vala_ccode_line_directive_set_filename (self, _filename);
+	vala_ccode_line_directive_set_line (self, _line);
+	return self;
+}
+
+
 ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gint _line) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeLineDirective * self;
-	g_return_val_if_fail (_filename != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "filename";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _filename);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_LINE_DIRECTIVE, __params_it - __params, __params);
-	vala_ccode_line_directive_set_line (self, _line);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_line_directive_construct (VALA_TYPE_CCODE_LINE_DIRECTIVE, _filename, _line);
 }
 
 
@@ -93,7 +84,6 @@ void vala_ccode_line_directive_set_filename (ValaCCodeLineDirective* self, const
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "filename");
 }
 
 
@@ -106,53 +96,14 @@ gint vala_ccode_line_directive_get_line (ValaCCodeLineDirective* self) {
 void vala_ccode_line_directive_set_line (ValaCCodeLineDirective* self, gint value) {
 	g_return_if_fail (VALA_IS_CCODE_LINE_DIRECTIVE (self));
 	self->priv->_line = value;
-	g_object_notify (((GObject *) (self)), "line");
-}
-
-
-static void vala_ccode_line_directive_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeLineDirective * self;
-	self = VALA_CCODE_LINE_DIRECTIVE (object);
-	switch (property_id) {
-		case VALA_CCODE_LINE_DIRECTIVE_FILENAME:
-		g_value_set_string (value, vala_ccode_line_directive_get_filename (self));
-		break;
-		case VALA_CCODE_LINE_DIRECTIVE_LINE:
-		g_value_set_int (value, vala_ccode_line_directive_get_line (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_line_directive_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeLineDirective * self;
-	self = VALA_CCODE_LINE_DIRECTIVE (object);
-	switch (property_id) {
-		case VALA_CCODE_LINE_DIRECTIVE_FILENAME:
-		vala_ccode_line_directive_set_filename (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_LINE_DIRECTIVE_LINE:
-		vala_ccode_line_directive_set_line (self, g_value_get_int (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_ccode_line_directive_class_init (ValaCCodeLineDirectiveClass * klass) {
 	vala_ccode_line_directive_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_line_directive_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeLineDirectivePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_line_directive_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_line_directive_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_ccode_line_directive_finalize;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_line_directive_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LINE_DIRECTIVE_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_LINE_DIRECTIVE_LINE, g_param_spec_int ("line", "line", "line", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -161,18 +112,18 @@ static void vala_ccode_line_directive_instance_init (ValaCCodeLineDirective * se
 }
 
 
-static void vala_ccode_line_directive_finalize (GObject * obj) {
+static void vala_ccode_line_directive_finalize (ValaCCodeNode* obj) {
 	ValaCCodeLineDirective * self;
 	self = VALA_CCODE_LINE_DIRECTIVE (obj);
 	self->priv->_filename = (g_free (self->priv->_filename), NULL);
-	G_OBJECT_CLASS (vala_ccode_line_directive_parent_class)->finalize (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_line_directive_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_line_directive_get_type (void) {
 	static GType vala_ccode_line_directive_type_id = 0;
 	if (vala_ccode_line_directive_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLineDirectiveClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_line_directive_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLineDirective), 0, (GInstanceInitFunc) vala_ccode_line_directive_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLineDirectiveClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_line_directive_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLineDirective), 0, (GInstanceInitFunc) vala_ccode_line_directive_instance_init, NULL };
 		vala_ccode_line_directive_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeLineDirective", &g_define_type_info, 0);
 	}
 	return vala_ccode_line_directive_type_id;
