@@ -34,60 +34,43 @@ struct _ValaCCodeMacroReplacementPrivate {
 
 #define VALA_CCODE_MACRO_REPLACEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_MACRO_REPLACEMENT, ValaCCodeMacroReplacementPrivate))
 enum  {
-	VALA_CCODE_MACRO_REPLACEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_MACRO_REPLACEMENT_NAME,
-	VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT,
-	VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT_EXPRESSION
+	VALA_CCODE_MACRO_REPLACEMENT_DUMMY_PROPERTY
 };
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_macro_replacement_parent_class = NULL;
-static void vala_ccode_macro_replacement_dispose (GObject * obj);
+static void vala_ccode_macro_replacement_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct (GType object_type, const char* name, const char* replacement) {
+	ValaCCodeMacroReplacement* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (replacement != NULL, NULL);
+	self = ((ValaCCodeMacroReplacement*) (g_type_create_instance (object_type)));
+	vala_ccode_macro_replacement_set_replacement (self, replacement);
+	vala_ccode_macro_replacement_set_name (self, name);
+	return self;
+}
+
+
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeMacroReplacement * self;
+	return vala_ccode_macro_replacement_construct (VALA_TYPE_CCODE_MACRO_REPLACEMENT, name, replacement);
+}
+
+
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct_with_expression (GType object_type, const char* name, ValaCCodeExpression* replacement_expression) {
+	ValaCCodeMacroReplacement* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (replacement != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, name);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
-	vala_ccode_macro_replacement_set_replacement (self, replacement);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
+	self = ((ValaCCodeMacroReplacement*) (g_type_create_instance (object_type)));
+	vala_ccode_macro_replacement_set_name (self, name);
+	vala_ccode_macro_replacement_set_replacement_expression (self, replacement_expression);
 	return self;
 }
 
 
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (const char* name, ValaCCodeExpression* replacement_expression) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeMacroReplacement * self;
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, name);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
-	vala_ccode_macro_replacement_set_replacement_expression (self, replacement_expression);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_macro_replacement_construct_with_expression (VALA_TYPE_CCODE_MACRO_REPLACEMENT, name, replacement_expression);
 }
 
 
@@ -108,7 +91,7 @@ static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCC
 }
 
 
-char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self) {
+const char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_name;
 }
@@ -124,7 +107,7 @@ void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, con
 }
 
 
-char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self) {
+const char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_replacement;
 }
@@ -152,82 +135,37 @@ void vala_ccode_macro_replacement_set_replacement_expression (ValaCCodeMacroRepl
 	g_return_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_replacement_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (g_object_unref (self->priv->_replacement_expression), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_macro_replacement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeMacroReplacement * self;
-	self = VALA_CCODE_MACRO_REPLACEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_MACRO_REPLACEMENT_NAME:
-		g_value_set_string (value, vala_ccode_macro_replacement_get_name (self));
-		break;
-		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT:
-		g_value_set_string (value, vala_ccode_macro_replacement_get_replacement (self));
-		break;
-		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT_EXPRESSION:
-		g_value_set_object (value, vala_ccode_macro_replacement_get_replacement_expression (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_macro_replacement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeMacroReplacement * self;
-	self = VALA_CCODE_MACRO_REPLACEMENT (object);
-	switch (property_id) {
-		case VALA_CCODE_MACRO_REPLACEMENT_NAME:
-		vala_ccode_macro_replacement_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT:
-		vala_ccode_macro_replacement_set_replacement (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT_EXPRESSION:
-		vala_ccode_macro_replacement_set_replacement_expression (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_replacement_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (vala_ccode_node_unref (self->priv->_replacement_expression), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_macro_replacement_class_init (ValaCCodeMacroReplacementClass * klass) {
 	vala_ccode_macro_replacement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_macro_replacement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeMacroReplacementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_macro_replacement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_macro_replacement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_macro_replacement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_macro_replacement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT, g_param_spec_string ("replacement", "replacement", "replacement", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT_EXPRESSION, g_param_spec_object ("replacement-expression", "replacement-expression", "replacement-expression", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self) {
+static void vala_ccode_macro_replacement_instance_init (ValaCCodeMacroReplacement * self) {
 	self->priv = VALA_CCODE_MACRO_REPLACEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_macro_replacement_dispose (GObject * obj) {
+static void vala_ccode_macro_replacement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
 	self->priv->_replacement = (g_free (self->priv->_replacement), NULL);
-	(self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (g_object_unref (self->priv->_replacement_expression), NULL)));
-	G_OBJECT_CLASS (vala_ccode_macro_replacement_parent_class)->dispose (obj);
+	(self->priv->_replacement_expression == NULL ? NULL : (self->priv->_replacement_expression = (vala_ccode_node_unref (self->priv->_replacement_expression), NULL)));
+	VALA_CCODE_NODE_CLASS (vala_ccode_macro_replacement_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_macro_replacement_get_type (void) {
 	static GType vala_ccode_macro_replacement_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_init };
+	if (vala_ccode_macro_replacement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_instance_init, NULL };
 		vala_ccode_macro_replacement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeMacroReplacement", &g_define_type_info, 0);
 	}
 	return vala_ccode_macro_replacement_type_id;
