@@ -34,68 +34,45 @@ struct _ValaCCodeMemberAccessPrivate {
 
 #define VALA_CCODE_MEMBER_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_MEMBER_ACCESS, ValaCCodeMemberAccessPrivate))
 enum  {
-	VALA_CCODE_MEMBER_ACCESS_DUMMY_PROPERTY,
-	VALA_CCODE_MEMBER_ACCESS_INNER,
-	VALA_CCODE_MEMBER_ACCESS_MEMBER_NAME,
-	VALA_CCODE_MEMBER_ACCESS_IS_POINTER
+	VALA_CCODE_MEMBER_ACCESS_DUMMY_PROPERTY
 };
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_member_access_parent_class = NULL;
-static void vala_ccode_member_access_dispose (GObject * obj);
+static void vala_ccode_member_access_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeMemberAccess* vala_ccode_member_access_construct (GType object_type, ValaCCodeExpression* container, const char* member, gboolean pointer) {
+	ValaCCodeMemberAccess* self;
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (member != NULL, NULL);
+	self = ((ValaCCodeMemberAccess*) (g_type_create_instance (object_type)));
+	vala_ccode_member_access_set_inner (self, container);
+	vala_ccode_member_access_set_member_name (self, member);
+	vala_ccode_member_access_set_is_pointer (self, pointer);
+	return self;
+}
+
+
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeMemberAccess * self;
+	return vala_ccode_member_access_construct (VALA_TYPE_CCODE_MEMBER_ACCESS, container, member, pointer);
+}
+
+
+ValaCCodeMemberAccess* vala_ccode_member_access_construct_pointer (GType object_type, ValaCCodeExpression* container, const char* member) {
+	ValaCCodeMemberAccess* self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
 	g_return_val_if_fail (member != NULL, NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, container);
-	__params_it++;
-	__params_it->name = "member-name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, member);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
-	vala_ccode_member_access_set_is_pointer (self, pointer);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+	self = ((ValaCCodeMemberAccess*) (g_type_create_instance (object_type)));
+	vala_ccode_member_access_set_inner (self, container);
+	vala_ccode_member_access_set_member_name (self, member);
+	vala_ccode_member_access_set_is_pointer (self, TRUE);
 	return self;
 }
 
 
 ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression* container, const char* member) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeMemberAccess * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
-	g_return_val_if_fail (member != NULL, NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
-	g_value_set_object (&__params_it->value, container);
-	__params_it++;
-	__params_it->name = "member-name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, member);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
-	vala_ccode_member_access_set_is_pointer (self, TRUE);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_member_access_construct_pointer (VALA_TYPE_CCODE_MEMBER_ACCESS, container, member);
 }
 
 
@@ -125,7 +102,7 @@ void vala_ccode_member_access_set_inner (ValaCCodeMemberAccess* self, ValaCCodeE
 	g_return_if_fail (VALA_IS_CCODE_MEMBER_ACCESS (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
@@ -157,56 +134,11 @@ void vala_ccode_member_access_set_is_pointer (ValaCCodeMemberAccess* self, gbool
 }
 
 
-static void vala_ccode_member_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeMemberAccess * self;
-	self = VALA_CCODE_MEMBER_ACCESS (object);
-	switch (property_id) {
-		case VALA_CCODE_MEMBER_ACCESS_INNER:
-		g_value_set_object (value, vala_ccode_member_access_get_inner (self));
-		break;
-		case VALA_CCODE_MEMBER_ACCESS_MEMBER_NAME:
-		g_value_set_string (value, vala_ccode_member_access_get_member_name (self));
-		break;
-		case VALA_CCODE_MEMBER_ACCESS_IS_POINTER:
-		g_value_set_boolean (value, vala_ccode_member_access_get_is_pointer (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_member_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeMemberAccess * self;
-	self = VALA_CCODE_MEMBER_ACCESS (object);
-	switch (property_id) {
-		case VALA_CCODE_MEMBER_ACCESS_INNER:
-		vala_ccode_member_access_set_inner (self, g_value_get_object (value));
-		break;
-		case VALA_CCODE_MEMBER_ACCESS_MEMBER_NAME:
-		vala_ccode_member_access_set_member_name (self, g_value_get_string (value));
-		break;
-		case VALA_CCODE_MEMBER_ACCESS_IS_POINTER:
-		vala_ccode_member_access_set_is_pointer (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_ccode_member_access_class_init (ValaCCodeMemberAccessClass * klass) {
 	vala_ccode_member_access_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_member_access_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeMemberAccessPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_member_access_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_member_access_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_member_access_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_member_access_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "member-name", "member-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_MEMBER_ACCESS_IS_POINTER, g_param_spec_boolean ("is-pointer", "is-pointer", "is-pointer", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -215,19 +147,19 @@ static void vala_ccode_member_access_instance_init (ValaCCodeMemberAccess * self
 }
 
 
-static void vala_ccode_member_access_dispose (GObject * obj) {
+static void vala_ccode_member_access_finalize (ValaCCodeNode* obj) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)));
 	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
-	G_OBJECT_CLASS (vala_ccode_member_access_parent_class)->dispose (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_member_access_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_member_access_get_type (void) {
 	static GType vala_ccode_member_access_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_member_access_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccess), 0, (GInstanceInitFunc) vala_ccode_member_access_instance_init };
+	if (vala_ccode_member_access_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMemberAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_member_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMemberAccess), 0, (GInstanceInitFunc) vala_ccode_member_access_instance_init, NULL };
 		vala_ccode_member_access_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeMemberAccess", &g_define_type_info, 0);
 	}
 	return vala_ccode_member_access_type_id;
