@@ -33,34 +33,26 @@ struct _ValaCCodeOnceSectionPrivate {
 
 #define VALA_CCODE_ONCE_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ONCE_SECTION, ValaCCodeOnceSectionPrivate))
 enum  {
-	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY,
-	VALA_CCODE_ONCE_SECTION_DEFINE
+	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY
 };
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_once_section_parent_class = NULL;
-static void vala_ccode_once_section_dispose (GObject * obj);
+static void vala_ccode_once_section_finalize (ValaCCodeNode* obj);
 
 
 
+ValaCCodeOnceSection* vala_ccode_once_section_construct (GType object_type, const char* def) {
+	ValaCCodeOnceSection* self;
+	g_return_val_if_fail (def != NULL, NULL);
+	self = ((ValaCCodeOnceSection*) (g_type_create_instance (object_type)));
+	vala_ccode_once_section_set_define (self, def);
+	return self;
+}
+
+
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaCCodeOnceSection * self;
-	g_return_val_if_fail (def != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "define";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, def);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_CCODE_ONCE_SECTION, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_ccode_once_section_construct (VALA_TYPE_CCODE_ONCE_SECTION, def);
 }
 
 
@@ -84,10 +76,10 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_combined (node, writer);
-				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
+				(node == NULL ? NULL : (node = (vala_ccode_node_unref (node), NULL)));
 			}
 		}
-		(node_collection == NULL ? NULL : (node_collection = (g_object_unref (node_collection), NULL)));
+		(node_collection == NULL ? NULL : (node_collection = (gee_collection_object_unref (node_collection), NULL)));
 	}
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#endif");
@@ -118,43 +110,12 @@ void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char*
 }
 
 
-static void vala_ccode_once_section_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (object);
-	switch (property_id) {
-		case VALA_CCODE_ONCE_SECTION_DEFINE:
-		g_value_set_string (value, vala_ccode_once_section_get_define (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_once_section_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeOnceSection * self;
-	self = VALA_CCODE_ONCE_SECTION (object);
-	switch (property_id) {
-		case VALA_CCODE_ONCE_SECTION_DEFINE:
-		vala_ccode_once_section_set_define (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_ccode_once_section_class_init (ValaCCodeOnceSectionClass * klass) {
 	vala_ccode_once_section_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_once_section_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeOnceSectionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_once_section_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_once_section_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_once_section_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_once_section_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_once_section_real_write_declaration;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ONCE_SECTION_DEFINE, g_param_spec_string ("define", "define", "define", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -163,18 +124,18 @@ static void vala_ccode_once_section_instance_init (ValaCCodeOnceSection * self)
 }
 
 
-static void vala_ccode_once_section_dispose (GObject * obj) {
+static void vala_ccode_once_section_finalize (ValaCCodeNode* obj) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (obj);
 	self->priv->_define = (g_free (self->priv->_define), NULL);
-	G_OBJECT_CLASS (vala_ccode_once_section_parent_class)->dispose (obj);
+	VALA_CCODE_NODE_CLASS (vala_ccode_once_section_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_once_section_get_type (void) {
 	static GType vala_ccode_once_section_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_once_section_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_instance_init };
+	if (vala_ccode_once_section_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeOnceSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_once_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeOnceSection), 0, (GInstanceInitFunc) vala_ccode_once_section_instance_init, NULL };
 		vala_ccode_once_section_type_id = g_type_register_static (VALA_TYPE_CCODE_FRAGMENT, "ValaCCodeOnceSection", &g_define_type_info, 0);
 	}
 	return vala_ccode_once_section_type_id;
