@@ -35,12 +35,12 @@ typedef struct _GeeReadOnlyListIteratorClass GeeReadOnlyListIteratorClass;
 typedef struct _GeeReadOnlyListIteratorPrivate GeeReadOnlyListIteratorPrivate;
 
 struct _GeeReadOnlyListIterator {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeReadOnlyListIteratorPrivate * priv;
 };
 
 struct _GeeReadOnlyListIteratorClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
 
@@ -54,12 +54,7 @@ struct _GeeReadOnlyListPrivate {
 
 #define GEE_READ_ONLY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListPrivate))
 enum  {
-	GEE_READ_ONLY_LIST_DUMMY_PROPERTY,
-	GEE_READ_ONLY_LIST_SIZE,
-	GEE_READ_ONLY_LIST_LIST,
-	GEE_READ_ONLY_LIST_G_TYPE,
-	GEE_READ_ONLY_LIST_G_DUP_FUNC,
-	GEE_READ_ONLY_LIST_G_DESTROY_FUNC
+	GEE_READ_ONLY_LIST_DUMMY_PROPERTY
 };
 static GType gee_read_only_list_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base);
@@ -80,13 +75,11 @@ struct _GeeReadOnlyListIteratorPrivate {
 
 #define GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIteratorPrivate))
 enum  {
-	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY,
-	GEE_READ_ONLY_LIST_ITERATOR_G_TYPE,
-	GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC,
-	GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC
+	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY
 };
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_list_iterator_gee_iterator_parent_iface = NULL;
@@ -95,37 +88,24 @@ static gpointer gee_read_only_list_parent_class = NULL;
 static GeeIterableIface* gee_read_only_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_read_only_list_gee_list_parent_iface = NULL;
-static void gee_read_only_list_dispose (GObject * obj);
+static void gee_read_only_list_finalize (GeeCollectionObject* obj);
 
 
 
+GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
+	GeeReadOnlyList* self;
+	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
+	self = ((GeeReadOnlyList*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	gee_read_only_list_set_list (self, list);
+	return self;
+}
+
+
 GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyList * self;
-	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_TYPE_READ_ONLY_LIST, __params_it - __params, __params);
-	gee_read_only_list_set_list (self, list);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return gee_read_only_list_construct (GEE_TYPE_READ_ONLY_LIST, g_type, g_dup_func, g_destroy_func, list);
 }
 
 
@@ -140,7 +120,7 @@ static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (base);
 	if (self->priv->_list == NULL) {
-		return GEE_ITERATOR (gee_read_only_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func));
+		return GEE_ITERATOR (gee_read_only_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_list));
 }
@@ -218,8 +198,9 @@ static void gee_read_only_list_real_clear (GeeCollection* base) {
 }
 
 
-static gint gee_read_only_list_real_get_size (GeeReadOnlyList* self) {
-	g_return_val_if_fail (GEE_IS_READ_ONLY_LIST (self), 0);
+static gint gee_read_only_list_real_get_size (GeeCollection* base) {
+	GeeReadOnlyList* self;
+	self = GEE_READ_ONLY_LIST (base);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->_list));
 }
 
@@ -230,7 +211,7 @@ void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
 	g_return_if_fail (GEE_IS_READ_ONLY_LIST (self));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL))), _tmp1);
 }
 
 
@@ -248,73 +229,24 @@ static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 }
 
 
-static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyListIterator * self;
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_READ_ONLY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GeeReadOnlyListIterator* self;
+	self = ((GeeReadOnlyListIterator*) (g_type_create_instance (object_type)));
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static void gee_read_only_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (object);
-	switch (property_id) {
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_ITERATOR_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	return gee_read_only_list_iterator_construct (GEE_READ_ONLY_LIST_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func);
 }
 
 
 static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass * klass) {
 	gee_read_only_list_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListIteratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_iterator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -325,71 +257,27 @@ static void gee_read_only_list_iterator_gee_iterator_interface_init (GeeIterator
 }
 
 
-static void gee_read_only_list_iterator_init (GeeReadOnlyListIterator * self) {
+static void gee_read_only_list_iterator_instance_init (GeeReadOnlyListIterator * self) {
 	self->priv = GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE (self);
 }
 
 
 static GType gee_read_only_list_iterator_get_type (void) {
 	static GType gee_read_only_list_iterator_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_list_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_init };
+	if (gee_read_only_list_iterator_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_list_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_list_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyListIterator", &g_define_type_info, 0);
+		gee_read_only_list_iterator_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyListIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_list_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
 	}
 	return gee_read_only_list_iterator_type_id;
 }
 
 
-static void gee_read_only_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_SIZE:
-		g_value_set_int (value, gee_read_only_list_real_get_size (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_LIST:
-		gee_read_only_list_set_list (self, g_value_get_object (value));
-		break;
-		case GEE_READ_ONLY_LIST_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_LIST_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_LIST_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass) {
 	gee_read_only_list_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_read_only_list_finalize;
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_set_property;
-	G_OBJECT_CLASS (klass)->dispose = gee_read_only_list_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -406,6 +294,7 @@ static void gee_read_only_list_gee_collection_interface_init (GeeCollectionIface
 	iface->add = gee_read_only_list_real_add;
 	iface->remove = gee_read_only_list_real_remove;
 	iface->clear = gee_read_only_list_real_clear;
+	iface->get_size = gee_read_only_list_real_get_size;
 }
 
 
@@ -419,27 +308,27 @@ static void gee_read_only_list_gee_list_interface_init (GeeListIface * iface) {
 }
 
 
-static void gee_read_only_list_init (GeeReadOnlyList * self) {
+static void gee_read_only_list_instance_init (GeeReadOnlyList * self) {
 	self->priv = GEE_READ_ONLY_LIST_GET_PRIVATE (self);
 }
 
 
-static void gee_read_only_list_dispose (GObject * obj) {
+static void gee_read_only_list_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (obj);
-	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	G_OBJECT_CLASS (gee_read_only_list_parent_class)->dispose (obj);
+	(self->priv->_list == NULL ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)));
+	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_list_get_type (void) {
 	static GType gee_read_only_list_type_id = 0;
-	if (G_UNLIKELY (gee_read_only_list_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_init };
+	if (gee_read_only_list_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_list_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_list_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_list_info = { (GInterfaceInitFunc) gee_read_only_list_gee_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_list_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyList", &g_define_type_info, 0);
+		gee_read_only_list_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyList", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_ITERABLE, &gee_iterable_info);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_COLLECTION, &gee_collection_info);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_LIST, &gee_list_info);
