@@ -89,6 +89,7 @@ struct _ValaProjectGeneratorPrivate {
 enum  {
 	VALA_PROJECT_GENERATOR_DUMMY_PROPERTY
 };
+static ValaProjectGenerator* vala_project_generator_construct (GType object_type);
 static ValaProjectGenerator* vala_project_generator_new (void);
 static GtkHBox* vala_project_generator_create_hbox (ValaProjectGenerator* self, const char* title, GtkSizeGroup* size_group);
 static void vala_project_generator_create_project (ValaProjectGenerator* self);
@@ -106,7 +107,7 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 static void vala_project_generator_main (char** args, int args_length1);
 static GObject * vala_project_generator_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_project_generator_parent_class = NULL;
-static void vala_project_generator_dispose (GObject * obj);
+static void vala_project_generator_finalize (GObject* obj);
 static GType vala_project_generator_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
@@ -134,14 +135,19 @@ GType vala_project_license_get_type (void) {
 }
 
 
-static ValaProjectGenerator* vala_project_generator_new (void) {
+static ValaProjectGenerator* vala_project_generator_construct (GType object_type) {
 	ValaProjectGenerator * self;
-	self = g_object_newv (VALA_TYPE_PROJECT_GENERATOR, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	gtk_window_set_title (GTK_WINDOW (self), "Vala Project Generator");
 	return self;
 }
 
 
+static ValaProjectGenerator* vala_project_generator_new (void) {
+	return vala_project_generator_construct (VALA_TYPE_PROJECT_GENERATOR);
+}
+
+
 static GtkHBox* vala_project_generator_create_hbox (ValaProjectGenerator* self, const char* title, GtkSizeGroup* size_group) {
 	GtkHBox* hbox;
 	GtkLabel* label;
@@ -151,16 +157,16 @@ static GtkHBox* vala_project_generator_create_hbox (ValaProjectGenerator* self,
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
 	g_return_val_if_fail (title != NULL, NULL);
 	g_return_val_if_fail (GTK_IS_SIZE_GROUP (size_group), NULL);
-	hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 6));
-	gtk_box_pack_start (GTK_BOX ((GTK_VBOX (GTK_DIALOG (self)->vbox))), GTK_WIDGET (hbox), FALSE, FALSE, ((guint) 0));
+	hbox = g_object_ref_sink (((GtkHBox*) (gtk_hbox_new (FALSE, 6))));
+	gtk_box_pack_start (GTK_BOX ((GTK_VBOX (GTK_DIALOG (self)->vbox))), GTK_WIDGET (hbox), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (hbox));
-	label = g_object_ref_sink (gtk_label_new ("    "));
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+	label = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("    "))));
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (label));
 	_tmp0 = NULL;
-	label = (_tmp0 = g_object_ref_sink (gtk_label_new (title)), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
-	g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+	label = (_tmp0 = g_object_ref_sink (((GtkLabel*) (gtk_label_new (title)))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
+	g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 	gtk_widget_show (GTK_WIDGET (label));
 	gtk_size_group_add_widget (size_group, GTK_WIDGET (label));
 	_tmp2 = NULL;
@@ -214,8 +220,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_string_append_unichar (namespace_name_str, c);
 			} else {
 				if (c == '-' || c == ' ') {
-					g_string_append_unichar (project_name_str, ((gunichar) '-'));
-					g_string_append_unichar (make_name_str, ((gunichar) '_'));
+					g_string_append_unichar (project_name_str, ((gunichar) ('-')));
+					g_string_append_unichar (make_name_str, ((gunichar) ('_')));
 				}
 			}
 		}
@@ -229,17 +235,17 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 	_tmp7 = NULL;
 	_tmp6 = NULL;
 	_tmp5 = NULL;
-	self->priv->namespace_name = (_tmp10 = g_strconcat ((_tmp7 = g_utf8_strup ((_tmp6 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) 0)), g_strndup (_tmp6, g_utf8_offset_to_pointer (_tmp6, ((glong) 1)) - _tmp6)), -1)), (_tmp9 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) 1)), g_strndup (_tmp9, g_utf8_offset_to_pointer (_tmp9, g_utf8_strlen (namespace_name_str->str, -1) - 1) - _tmp9)), NULL), (self->priv->namespace_name = (g_free (self->priv->namespace_name), NULL)), _tmp10);
-	_tmp8 = (g_free (_tmp8), NULL);
+	self->priv->namespace_name = (_tmp10 = g_strconcat ((_tmp7 = g_utf8_strup ((_tmp6 = (_tmp5 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) (0))), g_strndup (_tmp5, g_utf8_offset_to_pointer (_tmp5, ((glong) (1))) - _tmp5))), -1)), (_tmp9 = (_tmp8 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) (1))), g_strndup (_tmp8, g_utf8_offset_to_pointer (_tmp8, g_utf8_strlen (namespace_name_str->str, -1) - 1) - _tmp8))), NULL), (self->priv->namespace_name = (g_free (self->priv->namespace_name), NULL)), _tmp10);
+	_tmp9 = (g_free (_tmp9), NULL);
 	_tmp7 = (g_free (_tmp7), NULL);
-	_tmp5 = (g_free (_tmp5), NULL);
+	_tmp6 = (g_free (_tmp6), NULL);
 	_tmp12 = NULL;
 	_tmp11 = NULL;
 	self->priv->make_name = (_tmp12 = (_tmp11 = make_name_str->str, (_tmp11 == NULL ? NULL : g_strdup (_tmp11))), (self->priv->make_name = (g_free (self->priv->make_name), NULL)), _tmp12);
 	_tmp13 = NULL;
 	self->priv->upper_case_make_name = (_tmp13 = g_utf8_strup (self->priv->make_name, -1), (self->priv->upper_case_make_name = (g_free (self->priv->upper_case_make_name), NULL)), _tmp13);
-	self->priv->project_type = ((ValaProjectType) gtk_combo_box_get_active (self->priv->project_type_combobox));
-	self->priv->project_license = ((ValaProjectLicense) gtk_combo_box_get_active (self->priv->license_combobox));
+	self->priv->project_type = ((ValaProjectType) (gtk_combo_box_get_active (self->priv->project_type_combobox)));
+	self->priv->project_license = ((ValaProjectLicense) (gtk_combo_box_get_active (self->priv->license_combobox)));
 	_tmp15 = NULL;
 	_tmp14 = NULL;
 	self->priv->real_name = (_tmp15 = (_tmp14 = gtk_entry_get_text (self->priv->name_entry), (_tmp14 == NULL ? NULL : g_strdup (_tmp14))), (self->priv->real_name = (g_free (self->priv->real_name), NULL)), _tmp15);
@@ -340,7 +346,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 			g_clear_error (&inner_error);
 		}
 		_tmp20 = NULL;
-		g_file_set_contents ((_tmp20 = g_strconcat (self->priv->project_path, "/NEWS", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp20 = g_strconcat (self->priv->project_path, "/NEWS", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -350,7 +356,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp20 = (g_free (_tmp20), NULL);
 		_tmp21 = NULL;
-		g_file_set_contents ((_tmp21 = g_strconcat (self->priv->project_path, "/README", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp21 = g_strconcat (self->priv->project_path, "/README", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -360,7 +366,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp21 = (g_free (_tmp21), NULL);
 		_tmp22 = NULL;
-		g_file_set_contents ((_tmp22 = g_strconcat (self->priv->project_path, "/ChangeLog", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp22 = g_strconcat (self->priv->project_path, "/ChangeLog", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -370,7 +376,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp23 = NULL;
-		g_file_set_contents ((_tmp23 = g_strconcat (self->priv->project_path, "/po/ChangeLog", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp23 = g_strconcat (self->priv->project_path, "/po/ChangeLog", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -385,13 +391,14 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 			char* install_filename;
 			install_filename = g_strconcat (automake_path, "/INSTALL", NULL);
 			if (g_file_test (install_filename, G_FILE_TEST_EXISTS)) {
+				char* _tmp26;
 				gboolean _tmp25;
 				char* _tmp24;
-				char* _tmp26;
+				char* _tmp27;
+				_tmp26 = NULL;
 				_tmp24 = NULL;
 				_tmp25 = g_file_get_contents (install_filename, &_tmp24, NULL, &inner_error);
-				(s = (g_free (s), NULL));
-				s = _tmp24;
+				s = (_tmp26 = _tmp24, (s = (g_free (s), NULL)), _tmp26);
 				_tmp25;
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
@@ -400,8 +407,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 					g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 					g_clear_error (&inner_error);
 				}
-				_tmp26 = NULL;
-				g_file_set_contents ((_tmp26 = g_strconcat (self->priv->project_path, "/INSTALL", NULL)), s, ((glong) -1), &inner_error);
+				_tmp27 = NULL;
+				g_file_set_contents ((_tmp27 = g_strconcat (self->priv->project_path, "/INSTALL", NULL)), s, ((glong) (-1)), &inner_error);
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
 						goto __catch0_g_file_error;
@@ -409,63 +416,64 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 					g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 					g_clear_error (&inner_error);
 				}
-				_tmp26 = (g_free (_tmp26), NULL);
+				_tmp27 = (g_free (_tmp27), NULL);
 			}
 			install_filename = (g_free (install_filename), NULL);
 		}
 		license_filename = NULL;
 		if (self->priv->project_license == VALA_PROJECT_LICENSE_GPL2) {
-			char* _tmp27;
-			_tmp27 = NULL;
-			license_filename = (_tmp27 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-2.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp27);
+			char* _tmp28;
+			_tmp28 = NULL;
+			license_filename = (_tmp28 = g_strdup (PACKAGE_DATADIR "/licenses/gpl-2.0.txt"), (license_filename = (g_free (license_filename), NULL)), _tmp28);
 			if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-				char* _tmp28;
-				_tmp28 = NULL;
-				license_filename = (_tmp28 = g_strdup ("/usr/share/common-licenses/GPL-2"), (license_filename = (g_free (license_filename), NULL)), _tmp28);
+				char* _tmp29;
+				_tmp29 = NULL;
+				license_filename = (_tmp29 = g_strdup ("/usr/share/common-licenses/GPL-2"), (license_filename = (g_free (license_filename), NULL)), _tmp29);
 			}
 		} else {
 			if (self->priv->project_license == VALA_PROJECT_LICENSE_LGPL2) {
-				char* _tmp29;
-				_tmp29 = NULL;
-				license_filename = (_tmp29 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-2.1.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp29);
+				char* _tmp30;
+				_tmp30 = NULL;
+				license_filename = (_tmp30 = g_strdup (PACKAGE_DATADIR "/licenses/lgpl-2.1.txt"), (license_filename = (g_free (license_filename), NULL)), _tmp30);
 				if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-					char* _tmp30;
-					_tmp30 = NULL;
-					license_filename = (_tmp30 = g_strdup ("/usr/share/common-licenses/LGPL-2.1"), (license_filename = (g_free (license_filename), NULL)), _tmp30);
+					char* _tmp31;
+					_tmp31 = NULL;
+					license_filename = (_tmp31 = g_strdup ("/usr/share/common-licenses/LGPL-2.1"), (license_filename = (g_free (license_filename), NULL)), _tmp31);
 				}
 			} else {
 				if (self->priv->project_license == VALA_PROJECT_LICENSE_GPL3) {
-					char* _tmp31;
-					_tmp31 = NULL;
-					license_filename = (_tmp31 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp31);
+					char* _tmp32;
+					_tmp32 = NULL;
+					license_filename = (_tmp32 = g_strdup (PACKAGE_DATADIR "/licenses/gpl-3.0.txt"), (license_filename = (g_free (license_filename), NULL)), _tmp32);
 					if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-						char* _tmp32;
-						_tmp32 = NULL;
-						license_filename = (_tmp32 = g_strdup ("/usr/share/common-licenses/GPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp32);
+						char* _tmp33;
+						_tmp33 = NULL;
+						license_filename = (_tmp33 = g_strdup ("/usr/share/common-licenses/GPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp33);
 					}
 				} else {
 					if (self->priv->project_license == VALA_PROJECT_LICENSE_LGPL3) {
-						char* _tmp33;
-						_tmp33 = NULL;
-						license_filename = (_tmp33 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp33);
+						char* _tmp34;
+						_tmp34 = NULL;
+						license_filename = (_tmp34 = g_strdup (PACKAGE_DATADIR "/licenses/lgpl-3.0.txt"), (license_filename = (g_free (license_filename), NULL)), _tmp34);
 						if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-							char* _tmp34;
-							_tmp34 = NULL;
-							license_filename = (_tmp34 = g_strdup ("/usr/share/common-licenses/LGPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp34);
+							char* _tmp35;
+							_tmp35 = NULL;
+							license_filename = (_tmp35 = g_strdup ("/usr/share/common-licenses/LGPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp35);
 						}
 					}
 				}
 			}
 		}
 		if (license_filename != NULL && g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-			gboolean _tmp36;
-			char* _tmp35;
-			char* _tmp37;
-			_tmp35 = NULL;
-			_tmp36 = g_file_get_contents (license_filename, &_tmp35, NULL, &inner_error);
-			(s = (g_free (s), NULL));
-			s = _tmp35;
-			_tmp36;
+			char* _tmp38;
+			gboolean _tmp37;
+			char* _tmp36;
+			char* _tmp39;
+			_tmp38 = NULL;
+			_tmp36 = NULL;
+			_tmp37 = g_file_get_contents (license_filename, &_tmp36, NULL, &inner_error);
+			s = (_tmp38 = _tmp36, (s = (g_free (s), NULL)), _tmp38);
+			_tmp37;
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
@@ -473,8 +481,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 				g_clear_error (&inner_error);
 			}
-			_tmp37 = NULL;
-			g_file_set_contents ((_tmp37 = g_strconcat (self->priv->project_path, "/COPYING", NULL)), s, ((glong) -1), &inner_error);
+			_tmp39 = NULL;
+			g_file_set_contents ((_tmp39 = g_strconcat (self->priv->project_path, "/COPYING", NULL)), s, ((glong) (-1)), &inner_error);
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
@@ -482,7 +490,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 				g_clear_error (&inner_error);
 			}
-			_tmp37 = (g_free (_tmp37), NULL);
+			_tmp39 = (g_free (_tmp39), NULL);
 		}
 		s = (g_free (s), NULL);
 		automake_path = (g_free (automake_path), NULL);
@@ -496,6 +504,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		inner_error = NULL;
 		{
 			g_critical ("valaprojectgenerator.vala:236: Error while creating project: %s", e->message);
+			(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 		}
 	}
 	__finally0:
@@ -521,9 +530,10 @@ static void vala_project_generator_write_autogen_sh (ValaProjectGenerator* self,
 	g_string_append_printf (s, "PKG_NAME=\"%s\"\n\n", self->priv->project_name);
 	g_string_append (s, ". gnome-autogen.sh\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/autogen.sh", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/autogen.sh", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -579,9 +589,10 @@ static void vala_project_generator_write_configure_ac (ValaProjectGenerator* sel
 	g_string_append (s, "\tpo/Makefile.in])\n\n");
 	g_string_append (s, "AC_OUTPUT\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/configure.ac", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/configure.ac", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -644,9 +655,10 @@ static void vala_project_generator_write_makefile_am (ValaProjectGenerator* self
 	g_string_append (s, "\tpo/.intltool-merge-cache \\\n");
 	g_string_append (s, "\t$(NULL)\n\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/Makefile.am", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/Makefile.am", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -673,7 +685,7 @@ static char* vala_project_generator_generate_source_file_header (ValaProjectGene
 	g_date_set_time_val (&d, &tv);
 	g_string_append_printf (s, "/* %s\n", filename);
 	g_string_append (s, " *\n");
-	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (&d), self->priv->real_name);
+	g_string_append_printf (s, " * Copyright (C) %d  %s\n", ((gint) (g_date_get_year (&d))), self->priv->real_name);
 	g_string_append (s, " *\n");
 	license_name = g_strdup ("");
 	license_version = NULL;
@@ -779,9 +791,10 @@ static void vala_project_generator_write_main_vala (ValaProjectGenerator* self,
 	g_string_append (s, "\n");
 	g_string_append (s, "}\n");
 	_tmp1 = NULL;
-	g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/src/main.vala", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/src/main.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp1 = (g_free (_tmp1), NULL);
@@ -890,9 +903,10 @@ static void vala_project_generator_write_mainwindow_vala (ValaProjectGenerator*
 	g_string_append (s, "\n");
 	g_string_append (s, "}\n");
 	_tmp2 = NULL;
-	g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/src/mainwindow.vala", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/src/mainwindow.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp2 = (g_free (_tmp2), NULL);
@@ -917,27 +931,30 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 		g_string_append (s, "src/main.vala\n");
 	}
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/POTFILES.in", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/POTFILES.in", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
 	if (use_gtk) {
 		char* _tmp1;
 		_tmp1 = NULL;
-		g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/mainwindow.c\n", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/mainwindow.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
+			(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 			return;
 		}
 		_tmp1 = (g_free (_tmp1), NULL);
 	} else {
 		char* _tmp2;
 		_tmp2 = NULL;
-		g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/main.c\n", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/main.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
+			(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 			return;
 		}
 		_tmp2 = (g_free (_tmp2), NULL);
@@ -954,9 +971,10 @@ static void vala_project_generator_write_linguas (ValaProjectGenerator* self, GE
 	inner_error = NULL;
 	s = g_strdup ("# please keep this list sorted alphabetically\n#\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/LINGUAS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/LINGUAS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -972,9 +990,10 @@ static void vala_project_generator_write_authors (ValaProjectGenerator* self, GE
 	inner_error = NULL;
 	s = g_strdup_printf ("%s <%s>\n", self->priv->real_name, self->priv->email_address);
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/AUTHORS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/AUTHORS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -990,9 +1009,10 @@ static void vala_project_generator_write_maintainers (ValaProjectGenerator* self
 	inner_error = NULL;
 	s = g_strdup_printf ("%s\nE-mail: %s\n", self->priv->real_name, self->priv->email_address);
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/MAINTAINERS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/MAINTAINERS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -1005,15 +1025,17 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 	gint automake_paths_length1;
 	char** _tmp0;
 	char** automake_paths;
-	gpointer _tmp4;
+	char* _tmp4;
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	automake_paths = (_tmp1 = (_tmp0 = g_new0 (char*, 3 + 1), _tmp0[0] = g_strdup ("/usr/share/automake"), _tmp0[1] = g_strdup ("/usr/share/automake-1.10"), _tmp0[2] = g_strdup ("/usr/share/automake-1.9"), _tmp0), automake_paths_length1 = 3, _tmp1);
 	{
 		char** automake_path_collection;
+		int automake_path_collection_length1;
 		int automake_path_it;
 		automake_path_collection = automake_paths;
+		automake_path_collection_length1 = automake_paths_length1;
 		for (automake_path_it = 0; (automake_paths_length1 != -1 && automake_path_it < automake_paths_length1) || (automake_paths_length1 == -1 && automake_path_collection[automake_path_it] != NULL); automake_path_it = automake_path_it + 1) {
 			const char* _tmp3;
 			char* automake_path;
@@ -1023,13 +1045,14 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 				if (g_file_test (automake_path, G_FILE_TEST_IS_DIR)) {
 					char* _tmp2;
 					_tmp2 = NULL;
-					return (_tmp2 = automake_path, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) g_free)), NULL)), _tmp2);
+					return (_tmp2 = automake_path, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) (g_free))), NULL)), _tmp2);
 				}
 				automake_path = (g_free (automake_path), NULL);
 			}
 		}
 	}
-	return (_tmp4 = NULL, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) g_free)), NULL)), _tmp4);
+	_tmp4 = NULL;
+	return (_tmp4 = NULL, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) (g_free))), NULL)), _tmp4);
 }
 
 
@@ -1086,7 +1109,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		const char* _tmp17;
 		GtkWidget* _tmp19;
 		GtkWidget* ok_button;
-		gtk_container_set_border_width (GTK_CONTAINER (self), ((guint) 12));
+		gtk_container_set_border_width (GTK_CONTAINER (self), ((guint) (12)));
 		gtk_dialog_set_has_separator (GTK_DIALOG (self), FALSE);
 		_tmp0 = NULL;
 		vbox = (_tmp0 = GTK_VBOX (GTK_DIALOG (self)->vbox), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
@@ -1095,48 +1118,48 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		hbox = NULL;
 		gtk_box_set_spacing (GTK_BOX (vbox), 6);
 		_tmp1 = NULL;
-		label = (_tmp1 = g_object_ref_sink (gtk_label_new ("<b>Project</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp1);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+		label = (_tmp1 = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("<b>Project</b>")))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp1);
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
-		g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 		gtk_widget_show (GTK_WIDGET (label));
 		_tmp3 = NULL;
 		hbox = (_tmp3 = vala_project_generator_create_hbox (self, "Project folder:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp3);
 		_tmp4 = NULL;
-		self->priv->project_folder_button = (_tmp4 = g_object_ref_sink (gtk_file_chooser_button_new ("Select a project folder", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)), (self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL))), _tmp4);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_folder_button), TRUE, TRUE, ((guint) 0));
+		self->priv->project_folder_button = (_tmp4 = g_object_ref_sink (((GtkFileChooserButton*) (gtk_file_chooser_button_new ("Select a project folder", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)))), (self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL))), _tmp4);
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_folder_button), TRUE, TRUE, ((guint) (0)));
 		gtk_widget_show (GTK_WIDGET (self->priv->project_folder_button));
 		_tmp5 = NULL;
 		hbox = (_tmp5 = vala_project_generator_create_hbox (self, "Project type:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp5);
 		_tmp6 = NULL;
-		self->priv->project_type_combobox = (_tmp6 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->project_type_combobox == NULL ? NULL : (self->priv->project_type_combobox = (g_object_unref (self->priv->project_type_combobox), NULL))), _tmp6);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_type_combobox), TRUE, TRUE, ((guint) 0));
+		self->priv->project_type_combobox = (_tmp6 = g_object_ref_sink (((GtkComboBox*) (gtk_combo_box_new_text ()))), (self->priv->project_type_combobox == NULL ? NULL : (self->priv->project_type_combobox = (g_object_unref (self->priv->project_type_combobox), NULL))), _tmp6);
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_type_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "Console Application");
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "GTK+ Application");
-		gtk_combo_box_set_active (self->priv->project_type_combobox, ((gint) VALA_PROJECT_TYPE_GTK_APPLICATION));
+		gtk_combo_box_set_active (self->priv->project_type_combobox, ((gint) (VALA_PROJECT_TYPE_GTK_APPLICATION)));
 		gtk_widget_show (GTK_WIDGET (self->priv->project_type_combobox));
 		_tmp7 = NULL;
 		hbox = (_tmp7 = vala_project_generator_create_hbox (self, "License:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp7);
 		_tmp8 = NULL;
-		self->priv->license_combobox = (_tmp8 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->license_combobox == NULL ? NULL : (self->priv->license_combobox = (g_object_unref (self->priv->license_combobox), NULL))), _tmp8);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->license_combobox), TRUE, TRUE, ((guint) 0));
+		self->priv->license_combobox = (_tmp8 = g_object_ref_sink (((GtkComboBox*) (gtk_combo_box_new_text ()))), (self->priv->license_combobox == NULL ? NULL : (self->priv->license_combobox = (g_object_unref (self->priv->license_combobox), NULL))), _tmp8);
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->license_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 2 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 3 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU Lesser General Public License, version 2.1 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU Lesser General Public License, version 3 or later");
-		gtk_combo_box_set_active (self->priv->license_combobox, ((gint) VALA_PROJECT_LICENSE_LGPL2));
+		gtk_combo_box_set_active (self->priv->license_combobox, ((gint) (VALA_PROJECT_LICENSE_LGPL2)));
 		gtk_widget_show (GTK_WIDGET (self->priv->license_combobox));
 		_tmp9 = NULL;
-		label = (_tmp9 = g_object_ref_sink (gtk_label_new ("<b>Author</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp9);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+		label = (_tmp9 = g_object_ref_sink (((GtkLabel*) (gtk_label_new ("<b>Author</b>")))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp9);
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
-		g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 		gtk_widget_show (GTK_WIDGET (label));
 		_tmp11 = NULL;
 		hbox = (_tmp11 = vala_project_generator_create_hbox (self, "Name:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp11);
 		_tmp12 = NULL;
-		self->priv->name_entry = (_tmp12 = g_object_ref_sink (gtk_entry_new ()), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp12);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->name_entry), TRUE, TRUE, ((guint) 0));
+		self->priv->name_entry = (_tmp12 = g_object_ref_sink (((GtkEntry*) (gtk_entry_new ()))), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp12);
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->name_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp14 = NULL;
 		_tmp13 = NULL;
 		self->priv->real_name = (_tmp14 = (_tmp13 = g_getenv ("REAL_NAME"), (_tmp13 == NULL ? NULL : g_strdup (_tmp13))), (self->priv->real_name = (g_free (self->priv->real_name), NULL)), _tmp14);
@@ -1147,8 +1170,8 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		_tmp15 = NULL;
 		hbox = (_tmp15 = vala_project_generator_create_hbox (self, "E-mail address:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp15);
 		_tmp16 = NULL;
-		self->priv->email_entry = (_tmp16 = g_object_ref_sink (gtk_entry_new ()), (self->priv->email_entry == NULL ? NULL : (self->priv->email_entry = (g_object_unref (self->priv->email_entry), NULL))), _tmp16);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->email_entry), TRUE, TRUE, ((guint) 0));
+		self->priv->email_entry = (_tmp16 = g_object_ref_sink (((GtkEntry*) (gtk_entry_new ()))), (self->priv->email_entry == NULL ? NULL : (self->priv->email_entry = (g_object_unref (self->priv->email_entry), NULL))), _tmp16);
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->email_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp18 = NULL;
 		_tmp17 = NULL;
 		self->priv->email_address = (_tmp18 = (_tmp17 = g_getenv ("EMAIL_ADDRESS"), (_tmp17 == NULL ? NULL : g_strdup (_tmp17))), (self->priv->email_address = (g_free (self->priv->email_address), NULL)), _tmp18);
@@ -1156,9 +1179,9 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 			gtk_entry_set_text (self->priv->email_entry, self->priv->email_address);
 		}
 		gtk_widget_show (GTK_WIDGET (self->priv->email_entry));
-		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) GTK_RESPONSE_CANCEL));
+		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) (GTK_RESPONSE_CANCEL)));
 		_tmp19 = NULL;
-		ok_button = (_tmp19 = gtk_dialog_add_button (GTK_DIALOG (self), "Create Project", ((gint) GTK_RESPONSE_OK)), (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
+		ok_button = (_tmp19 = gtk_dialog_add_button (GTK_DIALOG (self), "Create Project", ((gint) (GTK_RESPONSE_OK))), (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
 		gtk_widget_grab_default (ok_button);
 		(vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL)));
 		(size_group == NULL ? NULL : (size_group = (g_object_unref (size_group), NULL)));
@@ -1174,16 +1197,16 @@ static void vala_project_generator_class_init (ValaProjectGeneratorClass * klass
 	vala_project_generator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaProjectGeneratorPrivate));
 	G_OBJECT_CLASS (klass)->constructor = vala_project_generator_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_project_generator_dispose;
+	G_OBJECT_CLASS (klass)->finalize = vala_project_generator_finalize;
 }
 
 
-static void vala_project_generator_init (ValaProjectGenerator * self) {
+static void vala_project_generator_instance_init (ValaProjectGenerator * self) {
 	self->priv = VALA_PROJECT_GENERATOR_GET_PRIVATE (self);
 }
 
 
-static void vala_project_generator_dispose (GObject * obj) {
+static void vala_project_generator_finalize (GObject* obj) {
 	ValaProjectGenerator * self;
 	self = VALA_PROJECT_GENERATOR (obj);
 	(self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL)));
@@ -1198,14 +1221,14 @@ static void vala_project_generator_dispose (GObject * obj) {
 	self->priv->upper_case_make_name = (g_free (self->priv->upper_case_make_name), NULL);
 	self->priv->real_name = (g_free (self->priv->real_name), NULL);
 	self->priv->email_address = (g_free (self->priv->email_address), NULL);
-	G_OBJECT_CLASS (vala_project_generator_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_project_generator_parent_class)->finalize (obj);
 }
 
 
 static GType vala_project_generator_get_type (void) {
 	static GType vala_project_generator_type_id = 0;
-	if (G_UNLIKELY (vala_project_generator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaProjectGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_project_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProjectGenerator), 0, (GInstanceInitFunc) vala_project_generator_init };
+	if (vala_project_generator_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaProjectGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_project_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProjectGenerator), 0, (GInstanceInitFunc) vala_project_generator_instance_init, NULL };
 		vala_project_generator_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValaProjectGenerator", &g_define_type_info, 0);
 	}
 	return vala_project_generator_type_id;
@@ -1217,12 +1240,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
