@@ -26,6 +26,7 @@
 #include <gee/list.h>
 #include <vala/valasourcefile.h>
 #include <glib/gstdio.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -35,17 +36,23 @@ enum  {
 };
 static gboolean vala_ccode_compiler_package_exists (const char* package_name);
 static gpointer vala_ccode_compiler_parent_class = NULL;
+static void vala_ccode_compiler_finalize (ValaCCodeCompiler* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-ValaCCodeCompiler* vala_ccode_compiler_new (void) {
-	ValaCCodeCompiler * self;
-	self = g_object_newv (VALA_TYPE_CCODE_COMPILER, 0, NULL);
+ValaCCodeCompiler* vala_ccode_compiler_construct (GType object_type) {
+	ValaCCodeCompiler* self;
+	self = ((ValaCCodeCompiler*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaCCodeCompiler* vala_ccode_compiler_new (void) {
+	return vala_ccode_compiler_construct (VALA_TYPE_CCODE_COMPILER);
+}
+
+
 static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 	GError * inner_error;
 	char* pc;
@@ -137,7 +144,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 				pkg = (g_free (pkg), NULL);
 			}
 		}
-		(pkg_collection == NULL ? NULL : (pkg_collection = (g_object_unref (pkg_collection), NULL)));
+		(pkg_collection == NULL ? NULL : (pkg_collection = (gee_collection_object_unref (pkg_collection), NULL)));
 	}
 	pkgflags = NULL;
 	exit_status = 0;
@@ -257,7 +264,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 					_tmp21 = (g_free (_tmp21), NULL);
 					_tmp20 = (g_free (_tmp20), NULL);
 				}
-				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
+				(file == NULL ? NULL : (file = (vala_source_file_unref (file), NULL)));
 			}
 		}
 	}
@@ -366,37 +373,156 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 						_tmp35 = (g_free (_tmp35), NULL);
 					}
 				}
-				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
+				(file == NULL ? NULL : (file = (vala_source_file_unref (file), NULL)));
 			}
 		}
 	}
 	pc = (g_free (pc), NULL);
 	pkgflags = (g_free (pkgflags), NULL);
 	cmdline = (g_free (cmdline), NULL);
-	(source_files == NULL ? NULL : (source_files = (g_object_unref (source_files), NULL)));
-	(c_source_files == NULL ? NULL : (c_source_files = (g_object_unref (c_source_files), NULL)));
+	(source_files == NULL ? NULL : (source_files = (gee_collection_object_unref (source_files), NULL)));
+	(c_source_files == NULL ? NULL : (c_source_files = (gee_collection_object_unref (c_source_files), NULL)));
+}
+
+
+static void vala_value_ccode_compiler_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
+}
+
+
+static void vala_value_ccode_compiler_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_ccode_compiler_unref (value->data[0].v_pointer);
+	}
+}
+
+
+static void vala_value_ccode_compiler_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_ccode_compiler_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_ccode_compiler_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_ccode_compiler_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaCCodeCompiler* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_ccode_compiler_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaCCodeCompiler** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_ccode_compiler_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_ccode_compiler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecCCodeCompiler* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_CCODE_COMPILER), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_ccode_compiler (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CCODE_COMPILER), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_ccode_compiler (GValue* value, gpointer v_object) {
+	ValaCCodeCompiler* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_CCODE_COMPILER));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_CCODE_COMPILER));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_ccode_compiler_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_ccode_compiler_unref (old);
+	}
 }
 
 
 static void vala_ccode_compiler_class_init (ValaCCodeCompilerClass * klass) {
 	vala_ccode_compiler_parent_class = g_type_class_peek_parent (klass);
+	VALA_CCODE_COMPILER_CLASS (klass)->finalize = vala_ccode_compiler_finalize;
 }
 
 
 static void vala_ccode_compiler_instance_init (ValaCCodeCompiler * self) {
+	self->ref_count = 1;
+}
+
+
+static void vala_ccode_compiler_finalize (ValaCCodeCompiler* obj) {
+	ValaCCodeCompiler * self;
+	self = VALA_CCODE_COMPILER (obj);
 }
 
 
 GType vala_ccode_compiler_get_type (void) {
 	static GType vala_ccode_compiler_type_id = 0;
 	if (vala_ccode_compiler_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCompilerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_compiler_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCompiler), 0, (GInstanceInitFunc) vala_ccode_compiler_instance_init };
-		vala_ccode_compiler_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCCodeCompiler", &g_define_type_info, 0);
+		static const GTypeValueTable g_define_type_value_table = { vala_value_ccode_compiler_init, vala_value_ccode_compiler_free_value, vala_value_ccode_compiler_copy_value, vala_value_ccode_compiler_peek_pointer, "p", vala_value_ccode_compiler_collect_value, "p", vala_value_ccode_compiler_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCompilerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_compiler_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCompiler), 0, (GInstanceInitFunc) vala_ccode_compiler_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_ccode_compiler_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaCCodeCompiler", &g_define_type_info, &g_define_type_fundamental_info, 0);
 	}
 	return vala_ccode_compiler_type_id;
 }
 
 
+gpointer vala_ccode_compiler_ref (gpointer instance) {
+	ValaCCodeCompiler* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_ccode_compiler_unref (gpointer instance) {
+	ValaCCodeCompiler* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_CCODE_COMPILER_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
