@@ -56,7 +56,9 @@ struct _ValaCCodeDynamicSignalBindingClass {
 };
 
 
+ValaCCodeDynamicSignalBinding* vala_ccode_dynamic_signal_binding_construct (GType object_type, ValaCCodeGenerator* codegen, ValaDynamicSignal* node);
 ValaCCodeDynamicSignalBinding* vala_ccode_dynamic_signal_binding_new (ValaCCodeGenerator* codegen, ValaDynamicSignal* node);
+char* vala_ccode_dynamic_signal_binding_get_dynamic_cname (ValaCCodeDynamicSignalBinding* self);
 char* vala_ccode_dynamic_signal_binding_get_connect_wrapper_name (ValaCCodeDynamicSignalBinding* self);
 char* vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name (ValaCCodeDynamicSignalBinding* self);
 ValaSignal* vala_ccode_dynamic_signal_binding_get_node (ValaCCodeDynamicSignalBinding* self);
