@@ -54,7 +54,8 @@
 #include <ccode/valaccodestatement.h>
 #include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodeassignment.h>
-#include <gee/collection.h>
+#include <vala/valaobjecttypesymbol.h>
+#include <gee/list.h>
 #include <vala/valaproperty.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <vala/valasignal.h>
@@ -63,6 +64,7 @@
 #include <gobject/valaccodebinding.h>
 #include <gobject/valainterfaceregisterfunction.h>
 #include <gobject/valatyperegisterfunction.h>
+#include <gobject/valaccodetypesymbolbinding.h>
 
 
 
@@ -73,45 +75,49 @@ struct _ValaCCodeInterfaceBindingPrivate {
 
 #define VALA_CCODE_INTERFACE_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_INTERFACE_BINDING, ValaCCodeInterfaceBindingPrivate))
 enum  {
-	VALA_CCODE_INTERFACE_BINDING_DUMMY_PROPERTY,
-	VALA_CCODE_INTERFACE_BINDING_IFACE
+	VALA_CCODE_INTERFACE_BINDING_DUMMY_PROPERTY
 };
 static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base);
 static void vala_ccode_interface_binding_add_interface_base_init_function (ValaCCodeInterfaceBinding* self, ValaInterface* iface);
 static gpointer vala_ccode_interface_binding_parent_class = NULL;
-static void vala_ccode_interface_binding_dispose (GObject * obj);
+static void vala_ccode_interface_binding_finalize (ValaCodeBinding* obj);
 
 
 
-ValaCCodeInterfaceBinding* vala_ccode_interface_binding_new (ValaCCodeGenerator* codegen, ValaInterface* iface) {
-	ValaCCodeInterfaceBinding * self;
+ValaCCodeInterfaceBinding* vala_ccode_interface_binding_construct (GType object_type, ValaCCodeGenerator* codegen, ValaInterface* iface) {
+	ValaCCodeInterfaceBinding* self;
 	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
 	g_return_val_if_fail (VALA_IS_INTERFACE (iface), NULL);
-	self = g_object_newv (VALA_TYPE_CCODE_INTERFACE_BINDING, 0, NULL);
+	self = ((ValaCCodeInterfaceBinding*) (g_type_create_instance (object_type)));
 	vala_ccode_interface_binding_set_iface (self, iface);
 	vala_ccode_binding_set_codegen (VALA_CCODE_BINDING (self), codegen);
 	return self;
 }
 
 
+ValaCCodeInterfaceBinding* vala_ccode_interface_binding_new (ValaCCodeGenerator* codegen, ValaInterface* iface) {
+	return vala_ccode_interface_binding_construct (VALA_TYPE_CCODE_INTERFACE_BINDING, codegen, iface);
+}
+
+
 static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 	ValaCCodeInterfaceBinding * self;
 	ValaSymbol* _tmp1;
-	ValaInterface* _tmp0;
-	ValaTypesymbol* _tmp3;
-	ValaInterface* _tmp2;
+	ValaSymbol* _tmp0;
+	ValaTypeSymbol* _tmp3;
+	ValaTypeSymbol* _tmp2;
 	char* _tmp4;
 	gboolean _tmp5;
 	ValaCCodeFragment* decl_frag;
 	ValaCCodeFragment* def_frag;
-	ValaTypesymbol* _tmp55;
+	ValaTypeSymbol* _tmp55;
 	self = VALA_CCODE_INTERFACE_BINDING (base);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol = (_tmp1 = VALA_SYMBOL ((_tmp0 = self->priv->_iface, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol = (g_object_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol), NULL))), _tmp1);
+	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol = (_tmp1 = (_tmp0 = VALA_SYMBOL (self->priv->_iface), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol = (vala_code_node_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_symbol), NULL))), _tmp1);
 	_tmp3 = NULL;
 	_tmp2 = NULL;
-	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (_tmp3 = VALA_TYPESYMBOL ((_tmp2 = self->priv->_iface, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (g_object_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol), NULL))), _tmp3);
+	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (_tmp3 = (_tmp2 = VALA_TYPESYMBOL (self->priv->_iface), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (vala_code_node_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol), NULL))), _tmp3);
 	_tmp4 = NULL;
 	if ((_tmp5 = g_utf8_strlen ((_tmp4 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE)), -1) < 3, (_tmp4 = (g_free (_tmp4), NULL)), _tmp5)) {
 		char* _tmp7;
@@ -133,10 +139,10 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		ValaCCodeFragment* _tmp10;
 		_tmp9 = NULL;
 		_tmp8 = NULL;
-		decl_frag = (_tmp9 = (_tmp8 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->header_type_declaration, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8))), (decl_frag == NULL ? NULL : (decl_frag = (g_object_unref (decl_frag), NULL))), _tmp9);
+		decl_frag = (_tmp9 = (_tmp8 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->header_type_declaration, (_tmp8 == NULL ? NULL : vala_ccode_node_ref (_tmp8))), (decl_frag == NULL ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL))), _tmp9);
 		_tmp11 = NULL;
 		_tmp10 = NULL;
-		def_frag = (_tmp11 = (_tmp10 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->header_type_definition, (_tmp10 == NULL ? NULL : g_object_ref (_tmp10))), (def_frag == NULL ? NULL : (def_frag = (g_object_unref (def_frag), NULL))), _tmp11);
+		def_frag = (_tmp11 = (_tmp10 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->header_type_definition, (_tmp10 == NULL ? NULL : vala_ccode_node_ref (_tmp10))), (def_frag == NULL ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL))), _tmp11);
 	} else {
 		ValaCCodeFragment* _tmp13;
 		ValaCCodeFragment* _tmp12;
@@ -144,10 +150,10 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		ValaCCodeFragment* _tmp14;
 		_tmp13 = NULL;
 		_tmp12 = NULL;
-		decl_frag = (_tmp13 = (_tmp12 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_declaration, (_tmp12 == NULL ? NULL : g_object_ref (_tmp12))), (decl_frag == NULL ? NULL : (decl_frag = (g_object_unref (decl_frag), NULL))), _tmp13);
+		decl_frag = (_tmp13 = (_tmp12 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_declaration, (_tmp12 == NULL ? NULL : vala_ccode_node_ref (_tmp12))), (decl_frag == NULL ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL))), _tmp13);
 		_tmp15 = NULL;
 		_tmp14 = NULL;
-		def_frag = (_tmp15 = (_tmp14 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_definition, (_tmp14 == NULL ? NULL : g_object_ref (_tmp14))), (def_frag == NULL ? NULL : (def_frag = (g_object_unref (def_frag), NULL))), _tmp15);
+		def_frag = (_tmp15 = (_tmp14 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_definition, (_tmp14 == NULL ? NULL : vala_ccode_node_ref (_tmp14))), (def_frag == NULL ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL))), _tmp15);
 	}
 	if (!vala_interface_get_is_static (self->priv->_iface)) {
 		ValaCCodeStruct* _tmp18;
@@ -180,60 +186,60 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		_tmp18 = NULL;
 		_tmp17 = NULL;
 		_tmp16 = NULL;
-		vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct = (_tmp18 = vala_ccode_struct_new ((_tmp17 = g_strdup_printf ("_%s", (_tmp16 = vala_interface_get_type_cname (self->priv->_iface))))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct = (g_object_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct), NULL))), _tmp18);
+		vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct = (_tmp18 = vala_ccode_struct_new ((_tmp17 = g_strdup_printf ("_%s", (_tmp16 = vala_interface_get_type_cname (self->priv->_iface))))), (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct = (vala_ccode_node_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct), NULL))), _tmp18);
 		_tmp17 = (g_free (_tmp17), NULL);
 		_tmp16 = (g_free (_tmp16), NULL);
 		_tmp19 = NULL;
 		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp19 = vala_ccode_newline_new ())));
-		(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
+		(_tmp19 == NULL ? NULL : (_tmp19 = (vala_ccode_node_unref (_tmp19), NULL)));
 		_tmp20 = NULL;
 		_tmp21 = NULL;
 		macro = (_tmp21 = g_strdup_printf ("(%s_get_type ())", (_tmp20 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_iface), NULL))), (_tmp20 = (g_free (_tmp20), NULL)), _tmp21);
 		_tmp23 = NULL;
 		_tmp22 = NULL;
-		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp23 = vala_ccode_macro_replacement_new ((_tmp22 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), macro))));
-		(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
+		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp23 = vala_ccode_macro_replacement_new ((_tmp22 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), macro))));
+		(_tmp23 == NULL ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL)));
 		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp26 = NULL;
 		_tmp25 = NULL;
 		_tmp24 = NULL;
-		macro = (_tmp26 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", (_tmp24 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), (_tmp25 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE))), (macro = (g_free (macro), NULL)), _tmp26);
+		macro = (_tmp26 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", (_tmp24 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), (_tmp25 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE))), (macro = (g_free (macro), NULL)), _tmp26);
 		_tmp25 = (g_free (_tmp25), NULL);
 		_tmp24 = (g_free (_tmp24), NULL);
 		_tmp29 = NULL;
 		_tmp28 = NULL;
 		_tmp27 = NULL;
 		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp29 = vala_ccode_macro_replacement_new ((_tmp28 = g_strdup_printf ("%s(obj)", (_tmp27 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), NULL)))), macro))));
-		(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
+		(_tmp29 == NULL ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL)));
 		_tmp28 = (g_free (_tmp28), NULL);
 		_tmp27 = (g_free (_tmp27), NULL);
 		_tmp31 = NULL;
 		_tmp30 = NULL;
-		macro = (_tmp31 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", (_tmp30 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_"))), (macro = (g_free (macro), NULL)), _tmp31);
+		macro = (_tmp31 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", (_tmp30 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface)))), (macro = (g_free (macro), NULL)), _tmp31);
 		_tmp30 = (g_free (_tmp30), NULL);
 		_tmp34 = NULL;
 		_tmp33 = NULL;
 		_tmp32 = NULL;
-		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp34 = vala_ccode_macro_replacement_new ((_tmp33 = g_strdup_printf ("%s(obj)", (_tmp32 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "IS_")))), macro))));
-		(_tmp34 == NULL ? NULL : (_tmp34 = (g_object_unref (_tmp34), NULL)));
+		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp34 = vala_ccode_macro_replacement_new ((_tmp33 = g_strdup_printf ("%s(obj)", (_tmp32 = vala_ccode_generator_get_type_check_function (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_TYPESYMBOL (self->priv->_iface))))), macro))));
+		(_tmp34 == NULL ? NULL : (_tmp34 = (vala_ccode_node_unref (_tmp34), NULL)));
 		_tmp33 = (g_free (_tmp33), NULL);
 		_tmp32 = (g_free (_tmp32), NULL);
 		_tmp37 = NULL;
 		_tmp36 = NULL;
 		_tmp35 = NULL;
-		macro = (_tmp37 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", (_tmp35 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), (_tmp36 = vala_interface_get_type_cname (self->priv->_iface))), (macro = (g_free (macro), NULL)), _tmp37);
+		macro = (_tmp37 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", (_tmp35 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), (_tmp36 = vala_interface_get_type_cname (self->priv->_iface))), (macro = (g_free (macro), NULL)), _tmp37);
 		_tmp36 = (g_free (_tmp36), NULL);
 		_tmp35 = (g_free (_tmp35), NULL);
 		_tmp40 = NULL;
 		_tmp39 = NULL;
 		_tmp38 = NULL;
 		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp40 = vala_ccode_macro_replacement_new ((_tmp39 = g_strdup_printf ("%s_GET_INTERFACE(obj)", (_tmp38 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), NULL)))), macro))));
-		(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
+		(_tmp40 == NULL ? NULL : (_tmp40 = (vala_ccode_node_unref (_tmp40), NULL)));
 		_tmp39 = (g_free (_tmp39), NULL);
 		_tmp38 = (g_free (_tmp38), NULL);
 		_tmp41 = NULL;
 		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp41 = vala_ccode_newline_new ())));
-		(_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL)));
+		(_tmp41 == NULL ? NULL : (_tmp41 = (vala_ccode_node_unref (_tmp41), NULL)));
 		if (vala_source_file_get_cycle (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self->priv->_iface)))) == NULL) {
 			ValaCCodeTypeDefinition* _tmp46;
 			ValaCCodeVariableDeclarator* _tmp45;
@@ -250,8 +256,8 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 			_tmp43 = NULL;
 			_tmp42 = NULL;
 			vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp46 = vala_ccode_type_definition_new ((_tmp43 = g_strdup_printf ("struct _%s", (_tmp42 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE)))), VALA_CCODE_DECLARATOR ((_tmp45 = vala_ccode_variable_declarator_new ((_tmp44 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE)))))))));
-			(_tmp46 == NULL ? NULL : (_tmp46 = (g_object_unref (_tmp46), NULL)));
-			(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
+			(_tmp46 == NULL ? NULL : (_tmp46 = (vala_ccode_node_unref (_tmp46), NULL)));
+			(_tmp45 == NULL ? NULL : (_tmp45 = (vala_ccode_node_unref (_tmp45), NULL)));
 			_tmp44 = (g_free (_tmp44), NULL);
 			_tmp43 = (g_free (_tmp43), NULL);
 			_tmp42 = (g_free (_tmp42), NULL);
@@ -260,8 +266,8 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 			_tmp48 = NULL;
 			_tmp47 = NULL;
 			vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp50 = vala_ccode_type_definition_new ((_tmp47 = g_strdup_printf ("struct %s", vala_ccode_struct_get_name (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct))), VALA_CCODE_DECLARATOR ((_tmp49 = vala_ccode_variable_declarator_new ((_tmp48 = vala_interface_get_type_cname (self->priv->_iface)))))))));
-			(_tmp50 == NULL ? NULL : (_tmp50 = (g_object_unref (_tmp50), NULL)));
-			(_tmp49 == NULL ? NULL : (_tmp49 = (g_object_unref (_tmp49), NULL)));
+			(_tmp50 == NULL ? NULL : (_tmp50 = (vala_ccode_node_unref (_tmp50), NULL)));
+			(_tmp49 == NULL ? NULL : (_tmp49 = (vala_ccode_node_unref (_tmp49), NULL)));
 			_tmp48 = (g_free (_tmp48), NULL);
 			_tmp47 = (g_free (_tmp47), NULL);
 		}
@@ -270,7 +276,7 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 			ValaCCodeComment* _tmp51;
 			_tmp51 = NULL;
 			vala_ccode_fragment_append (def_frag, VALA_CCODE_NODE ((_tmp51 = vala_ccode_comment_new (vala_source_reference_get_comment (vala_code_node_get_source_reference (VALA_CODE_NODE (self->priv->_iface)))))));
-			(_tmp51 == NULL ? NULL : (_tmp51 = (g_object_unref (_tmp51), NULL)));
+			(_tmp51 == NULL ? NULL : (_tmp51 = (vala_ccode_node_unref (_tmp51), NULL)));
 		}
 		vala_ccode_fragment_append (def_frag, VALA_CCODE_NODE (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->type_struct));
 		macro = (g_free (macro), NULL);
@@ -280,28 +286,28 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		ValaInterfaceRegisterFunction* type_fun;
 		ValaCCodeFragment* _tmp54;
 		vala_ccode_interface_binding_add_interface_base_init_function (self, self->priv->_iface);
-		type_fun = vala_interface_register_function_new (self->priv->_iface);
+		type_fun = vala_interface_register_function_new (self->priv->_iface, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)));
 		vala_typeregister_function_init_from_type (VALA_TYPEREGISTER_FUNCTION (type_fun), FALSE);
 		if (vala_symbol_get_access (VALA_SYMBOL (self->priv->_iface)) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 			ValaCCodeFragment* _tmp52;
 			_tmp52 = NULL;
 			vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->header_type_member_declaration, VALA_CCODE_NODE ((_tmp52 = vala_typeregister_function_get_declaration (VALA_TYPEREGISTER_FUNCTION (type_fun)))));
-			(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
+			(_tmp52 == NULL ? NULL : (_tmp52 = (vala_ccode_node_unref (_tmp52), NULL)));
 		} else {
 			ValaCCodeFragment* _tmp53;
 			_tmp53 = NULL;
 			vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_declaration, VALA_CCODE_NODE ((_tmp53 = vala_typeregister_function_get_declaration (VALA_TYPEREGISTER_FUNCTION (type_fun)))));
-			(_tmp53 == NULL ? NULL : (_tmp53 = (g_object_unref (_tmp53), NULL)));
+			(_tmp53 == NULL ? NULL : (_tmp53 = (vala_ccode_node_unref (_tmp53), NULL)));
 		}
 		_tmp54 = NULL;
 		vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_definition, VALA_CCODE_NODE ((_tmp54 = vala_typeregister_function_get_definition (VALA_TYPEREGISTER_FUNCTION (type_fun)))));
-		(_tmp54 == NULL ? NULL : (_tmp54 = (g_object_unref (_tmp54), NULL)));
-		(type_fun == NULL ? NULL : (type_fun = (g_object_unref (type_fun), NULL)));
+		(_tmp54 == NULL ? NULL : (_tmp54 = (vala_ccode_node_unref (_tmp54), NULL)));
+		(type_fun == NULL ? NULL : (type_fun = (vala_typeregister_function_unref (type_fun), NULL)));
 	}
 	_tmp55 = NULL;
-	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (_tmp55 = NULL, (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (g_object_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol), NULL))), _tmp55);
-	(decl_frag == NULL ? NULL : (decl_frag = (g_object_unref (decl_frag), NULL)));
-	(def_frag == NULL ? NULL : (def_frag = (g_object_unref (def_frag), NULL)));
+	vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (_tmp55 = NULL, (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol == NULL ? NULL : (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol = (vala_code_node_unref (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol), NULL))), _tmp55);
+	(decl_frag == NULL ? NULL : (decl_frag = (vala_ccode_node_unref (decl_frag), NULL)));
+	(def_frag == NULL ? NULL : (def_frag = (vala_ccode_node_unref (def_frag), NULL)));
 }
 
 
@@ -328,7 +334,7 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 	ValaCCodeAssignment* _tmp16;
 	ValaCCodeConstant* _tmp15;
 	ValaCCodeIdentifier* _tmp14;
-	GeeCollection* props;
+	ValaCCodeFragment* _tmp29;
 	g_return_if_fail (VALA_IS_CCODE_INTERFACE_BINDING (self));
 	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	_tmp1 = NULL;
@@ -339,7 +345,7 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	vala_ccode_function_add_parameter (base_init, (_tmp5 = vala_ccode_formal_parameter_new ("iface", (_tmp4 = g_strdup_printf ("%sIface *", (_tmp3 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (iface), FALSE)))))));
-	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp3 = (g_free (_tmp3), NULL);
 	vala_ccode_function_set_modifiers (base_init, VALA_CCODE_MODIFIERS_STATIC);
@@ -347,7 +353,7 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 	/* make sure not to run the initialization code twice */
 	_tmp6 = NULL;
 	vala_ccode_function_set_block (base_init, (_tmp6 = vala_ccode_block_new ()));
-	(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+	(_tmp6 == NULL ? NULL : (_tmp6 = (vala_ccode_node_unref (_tmp6), NULL)));
 	_tmp7 = NULL;
 	_tmp8 = NULL;
 	decl = (_tmp8 = vala_ccode_declaration_new ((_tmp7 = vala_data_type_get_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->bool_type))), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
@@ -355,90 +361,91 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 	_tmp10 = NULL;
 	_tmp9 = NULL;
 	vala_ccode_declaration_add_declarator (decl, VALA_CCODE_DECLARATOR ((_tmp10 = vala_ccode_variable_declarator_new_with_initializer ("initialized", VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_constant_new ("FALSE")))))));
-	(_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL)));
-	(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+	(_tmp10 == NULL ? NULL : (_tmp10 = (vala_ccode_node_unref (_tmp10), NULL)));
+	(_tmp9 == NULL ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL)));
 	vala_ccode_block_add_statement (vala_ccode_function_get_block (base_init), VALA_CCODE_NODE (decl));
 	_tmp12 = NULL;
 	_tmp11 = NULL;
 	_tmp13 = NULL;
-	cif = (_tmp13 = vala_ccode_if_statement_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_LOGICAL_NEGATION, VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new ("initialized")))))), VALA_CCODE_STATEMENT (init_block), NULL), (_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL))), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp13);
+	cif = (_tmp13 = vala_ccode_if_statement_new (VALA_CCODE_EXPRESSION ((_tmp12 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_LOGICAL_NEGATION, VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new ("initialized")))))), VALA_CCODE_STATEMENT (init_block), NULL), (_tmp12 == NULL ? NULL : (_tmp12 = (vala_ccode_node_unref (_tmp12), NULL))), (_tmp11 == NULL ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL))), _tmp13);
 	vala_ccode_block_add_statement (vala_ccode_function_get_block (base_init), VALA_CCODE_NODE (cif));
 	_tmp17 = NULL;
 	_tmp16 = NULL;
 	_tmp15 = NULL;
 	_tmp14 = NULL;
 	vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp17 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION ((_tmp16 = vala_ccode_assignment_new (VALA_CCODE_EXPRESSION ((_tmp14 = vala_ccode_identifier_new ("initialized"))), VALA_CCODE_EXPRESSION ((_tmp15 = vala_ccode_constant_new ("TRUE"))), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)))))));
-	(_tmp17 == NULL ? NULL : (_tmp17 = (g_object_unref (_tmp17), NULL)));
-	(_tmp16 == NULL ? NULL : (_tmp16 = (g_object_unref (_tmp16), NULL)));
-	(_tmp15 == NULL ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL)));
-	(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
-	/* create properties */
-	props = vala_interface_get_properties (iface);
-	{
-		GeeCollection* prop_collection;
-		GeeIterator* prop_it;
-		prop_collection = props;
-		prop_it = gee_iterable_iterator (GEE_ITERABLE (prop_collection));
-		while (gee_iterator_next (prop_it)) {
-			ValaProperty* prop;
-			prop = ((ValaProperty*) gee_iterator_get (prop_it));
-			{
-				ValaCCodeIdentifier* _tmp18;
-				ValaCCodeFunctionCall* _tmp19;
-				ValaCCodeFunctionCall* cinst;
-				ValaCCodeIdentifier* _tmp20;
-				ValaCCodeFunctionCall* _tmp21;
-				ValaCCodeExpressionStatement* _tmp22;
-				_tmp18 = NULL;
-				_tmp19 = NULL;
-				cinst = (_tmp19 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_identifier_new ("g_object_interface_install_property")))), (_tmp18 == NULL ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL))), _tmp19);
-				_tmp20 = NULL;
-				vala_ccode_function_call_add_argument (cinst, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ("iface"))));
-				(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
-				_tmp21 = NULL;
-				vala_ccode_function_call_add_argument (cinst, VALA_CCODE_EXPRESSION ((_tmp21 = vala_ccode_typesymbol_binding_get_param_spec (VALA_CCODE_TYPESYMBOL_BINDING (self), prop))));
-				(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
-				_tmp22 = NULL;
-				vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp22 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (cinst)))));
-				(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
-				(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
-				(cinst == NULL ? NULL : (cinst = (g_object_unref (cinst), NULL)));
+	(_tmp17 == NULL ? NULL : (_tmp17 = (vala_ccode_node_unref (_tmp17), NULL)));
+	(_tmp16 == NULL ? NULL : (_tmp16 = (vala_ccode_node_unref (_tmp16), NULL)));
+	(_tmp15 == NULL ? NULL : (_tmp15 = (vala_ccode_node_unref (_tmp15), NULL)));
+	(_tmp14 == NULL ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL)));
+	if (vala_typesymbol_is_subtype_of (VALA_TYPESYMBOL (iface), vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->gobject_type)) {
+		GeeList* props;
+		/* create properties */
+		props = vala_object_type_symbol_get_properties (VALA_OBJECT_TYPE_SYMBOL (iface));
+		{
+			GeeList* prop_collection;
+			int prop_it;
+			prop_collection = props;
+			for (prop_it = 0; prop_it < gee_collection_get_size (GEE_COLLECTION (prop_collection)); prop_it = prop_it + 1) {
+				ValaProperty* prop;
+				prop = ((ValaProperty*) (gee_list_get (GEE_LIST (prop_collection), prop_it)));
+				{
+					if (vala_property_get_is_abstract (prop)) {
+						ValaCCodeIdentifier* _tmp18;
+						ValaCCodeFunctionCall* _tmp19;
+						ValaCCodeFunctionCall* cinst;
+						ValaCCodeIdentifier* _tmp20;
+						ValaCCodeFunctionCall* _tmp21;
+						ValaCCodeExpressionStatement* _tmp22;
+						_tmp18 = NULL;
+						_tmp19 = NULL;
+						cinst = (_tmp19 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_identifier_new ("g_object_interface_install_property")))), (_tmp18 == NULL ? NULL : (_tmp18 = (vala_ccode_node_unref (_tmp18), NULL))), _tmp19);
+						_tmp20 = NULL;
+						vala_ccode_function_call_add_argument (cinst, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ("iface"))));
+						(_tmp20 == NULL ? NULL : (_tmp20 = (vala_ccode_node_unref (_tmp20), NULL)));
+						_tmp21 = NULL;
+						vala_ccode_function_call_add_argument (cinst, VALA_CCODE_EXPRESSION ((_tmp21 = vala_ccode_type_symbol_binding_get_param_spec (VALA_CCODE_TYPE_SYMBOL_BINDING (self), prop))));
+						(_tmp21 == NULL ? NULL : (_tmp21 = (vala_ccode_node_unref (_tmp21), NULL)));
+						_tmp22 = NULL;
+						vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp22 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (cinst)))));
+						(_tmp22 == NULL ? NULL : (_tmp22 = (vala_ccode_node_unref (_tmp22), NULL)));
+						(cinst == NULL ? NULL : (cinst = (vala_ccode_node_unref (cinst), NULL)));
+					}
+					(prop == NULL ? NULL : (prop = (vala_code_node_unref (prop), NULL)));
+				}
 			}
 		}
-		(prop_it == NULL ? NULL : (prop_it = (g_object_unref (prop_it), NULL)));
+		(props == NULL ? NULL : (props = (gee_collection_object_unref (props), NULL)));
 	}
 	/* create signals */
 	{
-		GeeCollection* sig_collection;
-		GeeIterator* sig_it;
-		sig_collection = vala_interface_get_signals (iface);
-		sig_it = gee_iterable_iterator (GEE_ITERABLE (sig_collection));
-		while (gee_iterator_next (sig_it)) {
+		GeeList* sig_collection;
+		int sig_it;
+		sig_collection = vala_object_type_symbol_get_signals (VALA_OBJECT_TYPE_SYMBOL (iface));
+		for (sig_it = 0; sig_it < gee_collection_get_size (GEE_COLLECTION (sig_collection)); sig_it = sig_it + 1) {
 			ValaSignal* sig;
-			sig = ((ValaSignal*) gee_iterator_get (sig_it));
+			sig = ((ValaSignal*) (gee_list_get (GEE_LIST (sig_collection), sig_it)));
 			{
 				ValaCCodeExpressionStatement* _tmp24;
 				ValaCCodeFunctionCall* _tmp23;
 				_tmp24 = NULL;
 				_tmp23 = NULL;
-				vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp24 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_typesymbol_binding_get_signal_creation (VALA_CCODE_TYPESYMBOL_BINDING (self), sig, VALA_TYPESYMBOL (iface))))))));
-				(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
-				(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
-				(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
+				vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp24 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_type_symbol_binding_get_signal_creation (VALA_CCODE_TYPE_SYMBOL_BINDING (self), sig, VALA_TYPESYMBOL (iface))))))));
+				(_tmp24 == NULL ? NULL : (_tmp24 = (vala_ccode_node_unref (_tmp24), NULL)));
+				(_tmp23 == NULL ? NULL : (_tmp23 = (vala_ccode_node_unref (_tmp23), NULL)));
+				(sig == NULL ? NULL : (sig = (vala_code_node_unref (sig), NULL)));
 			}
 		}
-		(sig_collection == NULL ? NULL : (sig_collection = (g_object_unref (sig_collection), NULL)));
-		(sig_it == NULL ? NULL : (sig_it = (g_object_unref (sig_it), NULL)));
+		(sig_collection == NULL ? NULL : (sig_collection = (gee_collection_object_unref (sig_collection), NULL)));
 	}
 	/* connect default implementations*/
 	{
-		GeeCollection* m_collection;
-		GeeIterator* m_it;
-		m_collection = vala_interface_get_methods (iface);
-		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
-		while (gee_iterator_next (m_it)) {
+		GeeList* m_collection;
+		int m_it;
+		m_collection = vala_object_type_symbol_get_methods (VALA_OBJECT_TYPE_SYMBOL (iface));
+		for (m_it = 0; m_it < gee_collection_get_size (GEE_COLLECTION (m_collection)); m_it = m_it + 1) {
 			ValaMethod* m;
-			m = ((ValaMethod*) gee_iterator_get (m_it));
+			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				if (vala_method_get_is_virtual (m)) {
 					ValaCCodeIdentifier* ciface;
@@ -454,25 +461,26 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 					_tmp26 = NULL;
 					_tmp25 = NULL;
 					vala_ccode_block_add_statement (vala_ccode_function_get_block (base_init), VALA_CCODE_NODE ((_tmp28 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION ((_tmp27 = vala_ccode_assignment_new (VALA_CCODE_EXPRESSION ((_tmp25 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION (ciface), vala_method_get_vfunc_name (m)))), VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_identifier_new (cname))), VALA_CCODE_ASSIGNMENT_OPERATOR_SIMPLE)))))));
-					(_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL)));
-					(_tmp27 == NULL ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL)));
-					(_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL)));
-					(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
-					(ciface == NULL ? NULL : (ciface = (g_object_unref (ciface), NULL)));
+					(_tmp28 == NULL ? NULL : (_tmp28 = (vala_ccode_node_unref (_tmp28), NULL)));
+					(_tmp27 == NULL ? NULL : (_tmp27 = (vala_ccode_node_unref (_tmp27), NULL)));
+					(_tmp26 == NULL ? NULL : (_tmp26 = (vala_ccode_node_unref (_tmp26), NULL)));
+					(_tmp25 == NULL ? NULL : (_tmp25 = (vala_ccode_node_unref (_tmp25), NULL)));
+					(ciface == NULL ? NULL : (ciface = (vala_ccode_node_unref (ciface), NULL)));
 					cname = (g_free (cname), NULL);
 				}
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
-		(m_collection == NULL ? NULL : (m_collection = (g_object_unref (m_collection), NULL)));
-		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
+		(m_collection == NULL ? NULL : (m_collection = (gee_collection_object_unref (m_collection), NULL)));
 	}
+	_tmp29 = NULL;
+	vala_ccode_block_add_statement (init_block, VALA_CCODE_NODE ((_tmp29 = vala_ccode_object_type_symbol_binding_register_dbus_info (VALA_CCODE_OBJECT_TYPE_SYMBOL_BINDING (self), VALA_OBJECT_TYPE_SYMBOL (iface)))));
+	(_tmp29 == NULL ? NULL : (_tmp29 = (vala_ccode_node_unref (_tmp29), NULL)));
 	vala_ccode_fragment_append (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->source_type_member_definition, VALA_CCODE_NODE (base_init));
-	(base_init == NULL ? NULL : (base_init = (g_object_unref (base_init), NULL)));
-	(init_block == NULL ? NULL : (init_block = (g_object_unref (init_block), NULL)));
-	(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
-	(cif == NULL ? NULL : (cif = (g_object_unref (cif), NULL)));
-	(props == NULL ? NULL : (props = (g_object_unref (props), NULL)));
+	(base_init == NULL ? NULL : (base_init = (vala_ccode_node_unref (base_init), NULL)));
+	(init_block == NULL ? NULL : (init_block = (vala_ccode_node_unref (init_block), NULL)));
+	(decl == NULL ? NULL : (decl = (vala_ccode_node_unref (decl), NULL)));
+	(cif == NULL ? NULL : (cif = (vala_ccode_node_unref (cif), NULL)));
 }
 
 
@@ -488,67 +496,36 @@ void vala_ccode_interface_binding_set_iface (ValaCCodeInterfaceBinding* self, Va
 	g_return_if_fail (VALA_IS_CCODE_INTERFACE_BINDING (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_iface = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iface == NULL ? NULL : (self->priv->_iface = (g_object_unref (self->priv->_iface), NULL))), _tmp2);
-}
-
-
-static void vala_ccode_interface_binding_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCCodeInterfaceBinding * self;
-	self = VALA_CCODE_INTERFACE_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_INTERFACE_BINDING_IFACE:
-		g_value_set_object (value, vala_ccode_interface_binding_get_iface (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_ccode_interface_binding_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCCodeInterfaceBinding * self;
-	self = VALA_CCODE_INTERFACE_BINDING (object);
-	switch (property_id) {
-		case VALA_CCODE_INTERFACE_BINDING_IFACE:
-		vala_ccode_interface_binding_set_iface (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_iface = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_iface == NULL ? NULL : (self->priv->_iface = (vala_code_node_unref (self->priv->_iface), NULL))), _tmp2);
 }
 
 
 static void vala_ccode_interface_binding_class_init (ValaCCodeInterfaceBindingClass * klass) {
 	vala_ccode_interface_binding_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_BINDING_CLASS (klass)->finalize = vala_ccode_interface_binding_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCCodeInterfaceBindingPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_ccode_interface_binding_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_ccode_interface_binding_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_ccode_interface_binding_dispose;
 	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_interface_binding_real_emit;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_INTERFACE_BINDING_IFACE, g_param_spec_object ("iface", "iface", "iface", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_interface_binding_init (ValaCCodeInterfaceBinding * self) {
+static void vala_ccode_interface_binding_instance_init (ValaCCodeInterfaceBinding * self) {
 	self->priv = VALA_CCODE_INTERFACE_BINDING_GET_PRIVATE (self);
 }
 
 
-static void vala_ccode_interface_binding_dispose (GObject * obj) {
+static void vala_ccode_interface_binding_finalize (ValaCodeBinding* obj) {
 	ValaCCodeInterfaceBinding * self;
 	self = VALA_CCODE_INTERFACE_BINDING (obj);
-	(self->priv->_iface == NULL ? NULL : (self->priv->_iface = (g_object_unref (self->priv->_iface), NULL)));
-	G_OBJECT_CLASS (vala_ccode_interface_binding_parent_class)->dispose (obj);
+	(self->priv->_iface == NULL ? NULL : (self->priv->_iface = (vala_code_node_unref (self->priv->_iface), NULL)));
+	VALA_CODE_BINDING_CLASS (vala_ccode_interface_binding_parent_class)->finalize (obj);
 }
 
 
 GType vala_ccode_interface_binding_get_type (void) {
 	static GType vala_ccode_interface_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_interface_binding_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInterfaceBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_interface_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInterfaceBinding), 0, (GInstanceInitFunc) vala_ccode_interface_binding_init };
-		vala_ccode_interface_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_TYPESYMBOL_BINDING, "ValaCCodeInterfaceBinding", &g_define_type_info, 0);
+	if (vala_ccode_interface_binding_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInterfaceBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_interface_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInterfaceBinding), 0, (GInstanceInitFunc) vala_ccode_interface_binding_instance_init, NULL };
+		vala_ccode_interface_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_OBJECT_TYPE_SYMBOL_BINDING, "ValaCCodeInterfaceBinding", &g_define_type_info, 0);
 	}
 	return vala_ccode_interface_binding_type_id;
 }
