@@ -38,10 +38,9 @@ struct _ValaInterfaceRegisterFunctionPrivate {
 
 #define VALA_INTERFACE_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_REGISTER_FUNCTION, ValaInterfaceRegisterFunctionPrivate))
 enum  {
-	VALA_INTERFACE_REGISTER_FUNCTION_DUMMY_PROPERTY,
-	VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE
+	VALA_INTERFACE_REGISTER_FUNCTION_DUMMY_PROPERTY
 };
-static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
+static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
@@ -51,25 +50,32 @@ static char* vala_interface_register_function_real_get_parent_type_name (ValaTyp
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
 static ValaCCodeFragment* vala_interface_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
 static gpointer vala_interface_register_function_parent_class = NULL;
-static void vala_interface_register_function_dispose (GObject * obj);
+static void vala_interface_register_function_finalize (ValaTypeRegisterFunction* obj);
 
 
 
-ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface) {
-	ValaInterfaceRegisterFunction * self;
+ValaInterfaceRegisterFunction* vala_interface_register_function_construct (GType object_type, ValaInterface* iface, ValaCCodeGenerator* codegen) {
+	ValaInterfaceRegisterFunction* self;
 	g_return_val_if_fail (VALA_IS_INTERFACE (iface), NULL);
-	self = g_object_newv (VALA_TYPE_INTERFACE_REGISTER_FUNCTION, 0, NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
+	self = ((ValaInterfaceRegisterFunction*) (g_type_create_instance (object_type)));
 	vala_interface_register_function_set_interface_reference (self, iface);
+	vala_typeregister_function_set_codegen (VALA_TYPEREGISTER_FUNCTION (self), codegen);
 	return self;
 }
 
 
-static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
+ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface, ValaCCodeGenerator* codegen) {
+	return vala_interface_register_function_construct (VALA_TYPE_INTERFACE_REGISTER_FUNCTION, iface, codegen);
+}
+
+
+static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	ValaInterface* _tmp0;
+	ValaTypeSymbol* _tmp0;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
-	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_interface_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	return (_tmp0 = VALA_TYPESYMBOL (self->priv->_interface_reference), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 }
 
 
@@ -133,16 +139,15 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 	frag = vala_ccode_fragment_new ();
 	/* register all prerequisites */
 	{
-		GeeCollection* prereq_ref_collection;
-		GeeIterator* prereq_ref_it;
+		GeeList* prereq_ref_collection;
+		int prereq_ref_it;
 		prereq_ref_collection = vala_interface_get_prerequisites (self->priv->_interface_reference);
-		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
-		while (gee_iterator_next (prereq_ref_it)) {
+		for (prereq_ref_it = 0; prereq_ref_it < gee_collection_get_size (GEE_COLLECTION (prereq_ref_collection)); prereq_ref_it = prereq_ref_it + 1) {
 			ValaDataType* prereq_ref;
-			prereq_ref = ((ValaDataType*) gee_iterator_get (prereq_ref_it));
+			prereq_ref = ((ValaDataType*) (gee_list_get (GEE_LIST (prereq_ref_collection), prereq_ref_it)));
 			{
-				ValaTypesymbol* _tmp0;
-				ValaTypesymbol* prereq;
+				ValaTypeSymbol* _tmp0;
+				ValaTypeSymbol* prereq;
 				ValaCCodeIdentifier* _tmp1;
 				ValaCCodeFunctionCall* _tmp2;
 				ValaCCodeFunctionCall* func;
@@ -153,32 +158,31 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 				char* _tmp6;
 				ValaCCodeExpressionStatement* _tmp8;
 				_tmp0 = NULL;
-				prereq = (_tmp0 = vala_data_type_get_data_type (prereq_ref), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				prereq = (_tmp0 = vala_data_type_get_data_type (prereq_ref), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
-				func = (_tmp2 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite")))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
+				func = (_tmp2 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite")))), (_tmp1 == NULL ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL))), _tmp2);
 				_tmp5 = NULL;
 				_tmp4 = NULL;
 				_tmp3 = NULL;
 				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_interface_reference), NULL))))))));
-				(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+				(_tmp5 == NULL ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)));
 				_tmp4 = (g_free (_tmp4), NULL);
 				_tmp3 = (g_free (_tmp3), NULL);
 				_tmp7 = NULL;
 				_tmp6 = NULL;
 				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_type_id (prereq))))));
-				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+				(_tmp7 == NULL ? NULL : (_tmp7 = (vala_ccode_node_unref (_tmp7), NULL)));
 				_tmp6 = (g_free (_tmp6), NULL);
 				_tmp8 = NULL;
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((_tmp8 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (func)))));
-				(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
-				(prereq_ref == NULL ? NULL : (prereq_ref = (g_object_unref (prereq_ref), NULL)));
-				(prereq == NULL ? NULL : (prereq = (g_object_unref (prereq), NULL)));
-				(func == NULL ? NULL : (func = (g_object_unref (func), NULL)));
+				(_tmp8 == NULL ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL)));
+				(prereq_ref == NULL ? NULL : (prereq_ref = (vala_code_node_unref (prereq_ref), NULL)));
+				(prereq == NULL ? NULL : (prereq = (vala_code_node_unref (prereq), NULL)));
+				(func == NULL ? NULL : (func = (vala_ccode_node_unref (func), NULL)));
 			}
 		}
-		(prereq_ref_collection == NULL ? NULL : (prereq_ref_collection = (g_object_unref (prereq_ref_collection), NULL)));
-		(prereq_ref_it == NULL ? NULL : (prereq_ref_it = (g_object_unref (prereq_ref_it), NULL)));
+		(prereq_ref_collection == NULL ? NULL : (prereq_ref_collection = (gee_collection_object_unref (prereq_ref_collection), NULL)));
 	}
 	return frag;
 }
@@ -196,40 +200,10 @@ void vala_interface_register_function_set_interface_reference (ValaInterfaceRegi
 }
 
 
-static void vala_interface_register_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (object);
-	switch (property_id) {
-		case VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE:
-		g_value_set_object (value, vala_interface_register_function_get_interface_reference (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_interface_register_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (object);
-	switch (property_id) {
-		case VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE:
-		vala_interface_register_function_set_interface_reference (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_interface_register_function_class_init (ValaInterfaceRegisterFunctionClass * klass) {
 	vala_interface_register_function_parent_class = g_type_class_peek_parent (klass);
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->finalize = vala_interface_register_function_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInterfaceRegisterFunctionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_interface_register_function_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_interface_register_function_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_interface_register_function_dispose;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_interface_register_function_real_get_type_declaration;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_interface_register_function_real_get_type_struct_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_interface_register_function_real_get_base_init_func_name;
@@ -239,26 +213,25 @@ static void vala_interface_register_function_class_init (ValaInterfaceRegisterFu
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_interface_register_function_real_get_parent_type_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_interface_register_function_real_get_accessibility;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_interface_register_function_real_get_type_interface_init_statements;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE, g_param_spec_object ("interface-reference", "interface-reference", "interface-reference", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_interface_register_function_init (ValaInterfaceRegisterFunction * self) {
+static void vala_interface_register_function_instance_init (ValaInterfaceRegisterFunction * self) {
 	self->priv = VALA_INTERFACE_REGISTER_FUNCTION_GET_PRIVATE (self);
 }
 
 
-static void vala_interface_register_function_dispose (GObject * obj) {
+static void vala_interface_register_function_finalize (ValaTypeRegisterFunction* obj) {
 	ValaInterfaceRegisterFunction * self;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (obj);
-	G_OBJECT_CLASS (vala_interface_register_function_parent_class)->dispose (obj);
+	VALA_TYPEREGISTER_FUNCTION_CLASS (vala_interface_register_function_parent_class)->finalize (obj);
 }
 
 
 GType vala_interface_register_function_get_type (void) {
 	static GType vala_interface_register_function_type_id = 0;
-	if (G_UNLIKELY (vala_interface_register_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceRegisterFunction), 0, (GInstanceInitFunc) vala_interface_register_function_init };
+	if (vala_interface_register_function_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceRegisterFunction), 0, (GInstanceInitFunc) vala_interface_register_function_instance_init, NULL };
 		vala_interface_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaInterfaceRegisterFunction", &g_define_type_info, 0);
 	}
 	return vala_interface_register_function_type_id;
