@@ -43,10 +43,7 @@ struct _ValaArrayCreationExpressionPrivate {
 
 #define VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionPrivate))
 enum  {
-	VALA_ARRAY_CREATION_EXPRESSION_DUMMY_PROPERTY,
-	VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE,
-	VALA_ARRAY_CREATION_EXPRESSION_RANK,
-	VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST
+	VALA_ARRAY_CREATION_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_array_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -54,7 +51,7 @@ static gboolean vala_array_creation_expression_real_is_pure (ValaExpression* bas
 static void vala_array_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static ValaCodeBinding* vala_array_creation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_array_creation_expression_parent_class = NULL;
-static void vala_array_creation_expression_finalize (GObject * obj);
+static void vala_array_creation_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -73,36 +70,26 @@ void vala_array_creation_expression_append_size (ValaArrayCreationExpression* se
  */
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->sizes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->sizes));
+}
+
+
+ValaArrayCreationExpression* vala_array_creation_expression_construct (GType object_type, ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference) {
+	ValaArrayCreationExpression* self;
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
+	g_return_val_if_fail (initializer_list == NULL || VALA_IS_INITIALIZER_LIST (initializer_list), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = ((ValaArrayCreationExpression*) (g_type_create_instance (object_type)));
+	vala_array_creation_expression_set_element_type (self, element_type);
+	vala_array_creation_expression_set_rank (self, rank);
+	vala_array_creation_expression_set_initializer_list (self, initializer_list);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	return self;
 }
 
 
 ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaArrayCreationExpression * self;
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
-	g_return_val_if_fail (initializer_list == NULL || VALA_IS_INITIALIZER_LIST (initializer_list), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "rank";
-	g_value_init (&__params_it->value, G_TYPE_INT);
-	g_value_set_int (&__params_it->value, rank);
-	__params_it++;
-	__params_it->name = "initializer-list";
-	g_value_init (&__params_it->value, VALA_TYPE_INITIALIZER_LIST);
-	g_value_set_object (&__params_it->value, initializer_list);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_ARRAY_CREATION_EXPRESSION, __params_it - __params, __params);
-	vala_array_creation_expression_set_element_type (self, element_type);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_array_creation_expression_construct (VALA_TYPE_ARRAY_CREATION_EXPRESSION, element_type, rank, initializer_list, source_reference);
 }
 
 
@@ -122,7 +109,7 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 			e = ((ValaExpression*) (gee_list_get (GEE_LIST (e_collection), e_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (e), visitor);
-				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
+				(e == NULL ? NULL : (e = (vala_code_node_unref (e), NULL)));
 			}
 		}
 	}
@@ -179,9 +166,8 @@ void vala_array_creation_expression_set_element_type (ValaArrayCreationExpressio
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), _tmp2);
+	self->priv->_element_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_element_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "element-type");
 }
 
 
@@ -194,7 +180,6 @@ gint vala_array_creation_expression_get_rank (ValaArrayCreationExpression* self)
 void vala_array_creation_expression_set_rank (ValaArrayCreationExpression* self, gint value) {
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
 	self->priv->_rank = value;
-	g_object_notify (((GObject *) (self)), "rank");
 }
 
 
@@ -210,88 +195,42 @@ void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpre
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_initializer_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "initializer-list");
-}
-
-
-static void vala_array_creation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaArrayCreationExpression * self;
-	self = VALA_ARRAY_CREATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE:
-		g_value_set_object (value, vala_array_creation_expression_get_element_type (self));
-		break;
-		case VALA_ARRAY_CREATION_EXPRESSION_RANK:
-		g_value_set_int (value, vala_array_creation_expression_get_rank (self));
-		break;
-		case VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST:
-		g_value_set_object (value, vala_array_creation_expression_get_initializer_list (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_array_creation_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaArrayCreationExpression * self;
-	self = VALA_ARRAY_CREATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE:
-		vala_array_creation_expression_set_element_type (self, g_value_get_object (value));
-		break;
-		case VALA_ARRAY_CREATION_EXPRESSION_RANK:
-		vala_array_creation_expression_set_rank (self, g_value_get_int (value));
-		break;
-		case VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST:
-		vala_array_creation_expression_set_initializer_list (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_initializer_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (vala_code_node_unref (self->priv->_initializer_list), NULL))), _tmp2);
 }
 
 
 static void vala_array_creation_expression_class_init (ValaArrayCreationExpressionClass * klass) {
 	vala_array_creation_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_array_creation_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaArrayCreationExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_array_creation_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_array_creation_expression_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_array_creation_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_array_creation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_array_creation_expression_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_array_creation_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_array_creation_expression_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_array_creation_expression_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST, g_param_spec_object ("initializer-list", "initializer-list", "initializer-list", VALA_TYPE_INITIALIZER_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
 static void vala_array_creation_expression_instance_init (ValaArrayCreationExpression * self) {
 	self->priv = VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_array_creation_expression_finalize (GObject * obj) {
+static void vala_array_creation_expression_finalize (ValaCodeNode* obj) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (obj);
-	(self->priv->sizes == NULL ? NULL : (self->priv->sizes = (g_object_unref (self->priv->sizes), NULL)));
-	(self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL)));
-	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
-	G_OBJECT_CLASS (vala_array_creation_expression_parent_class)->finalize (obj);
+	(self->priv->sizes == NULL ? NULL : (self->priv->sizes = (gee_collection_object_unref (self->priv->sizes), NULL)));
+	(self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (vala_code_node_unref (self->priv->_initializer_list), NULL)));
+	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_array_creation_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_array_creation_expression_get_type (void) {
 	static GType vala_array_creation_expression_type_id = 0;
 	if (vala_array_creation_expression_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayCreationExpression), 0, (GInstanceInitFunc) vala_array_creation_expression_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayCreationExpression), 0, (GInstanceInitFunc) vala_array_creation_expression_instance_init, NULL };
 		vala_array_creation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaArrayCreationExpression", &g_define_type_info, 0);
 	}
 	return vala_array_creation_expression_type_id;
