@@ -39,10 +39,11 @@ static gpointer vala_array_move_method_parent_class = NULL;
  *
  * @return newly created method
  */
-ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference) {
-	ValaArrayMoveMethod * self;
+ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaArrayMoveMethod* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ARRAY_MOVE_METHOD, 0, NULL);
+	self = ((ValaArrayMoveMethod*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_METHOD (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), "move");
 	vala_symbol_set_external (VALA_SYMBOL (self), TRUE);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -50,6 +51,11 @@ ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_ref
 }
 
 
+ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference) {
+	return vala_array_move_method_construct (VALA_TYPE_ARRAY_MOVE_METHOD, source_reference);
+}
+
+
 static void vala_array_move_method_class_init (ValaArrayMoveMethodClass * klass) {
 	vala_array_move_method_parent_class = g_type_class_peek_parent (klass);
 }
@@ -62,7 +68,7 @@ static void vala_array_move_method_instance_init (ValaArrayMoveMethod * self) {
 GType vala_array_move_method_get_type (void) {
 	static GType vala_array_move_method_type_id = 0;
 	if (vala_array_move_method_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayMoveMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_move_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayMoveMethod), 0, (GInstanceInitFunc) vala_array_move_method_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayMoveMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_move_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayMoveMethod), 0, (GInstanceInitFunc) vala_array_move_method_instance_init, NULL };
 		vala_array_move_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaArrayMoveMethod", &g_define_type_info, 0);
 	}
 	return vala_array_move_method_type_id;
