@@ -30,7 +30,6 @@
 enum  {
 	VALA_ARRAY_RESIZE_METHOD_DUMMY_PROPERTY
 };
-static GObject * vala_array_resize_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_array_resize_method_parent_class = NULL;
 
 
@@ -40,36 +39,26 @@ static gpointer vala_array_resize_method_parent_class = NULL;
  *
  * @return newly created method
  */
-ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference) {
-	ValaArrayResizeMethod * self;
+ValaArrayResizeMethod* vala_array_resize_method_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaArrayResizeMethod* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ARRAY_RESIZE_METHOD, 0, NULL);
+	self = ((ValaArrayResizeMethod*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_METHOD (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), "resize");
 	vala_symbol_set_external (VALA_SYMBOL (self), TRUE);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_method_set_cinstance_parameter_position (VALA_METHOD (self), 0.1);
 	return self;
 }
 
 
-static GObject * vala_array_resize_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaArrayResizeMethodClass * klass;
-	GObjectClass * parent_class;
-	ValaArrayResizeMethod * self;
-	klass = VALA_ARRAY_RESIZE_METHOD_CLASS (g_type_class_peek (VALA_TYPE_ARRAY_RESIZE_METHOD));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_ARRAY_RESIZE_METHOD (obj);
-	{
-		vala_method_set_cinstance_parameter_position (VALA_METHOD (self), 0.1);
-	}
-	return obj;
+ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference) {
+	return vala_array_resize_method_construct (VALA_TYPE_ARRAY_RESIZE_METHOD, source_reference);
 }
 
 
 static void vala_array_resize_method_class_init (ValaArrayResizeMethodClass * klass) {
 	vala_array_resize_method_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->constructor = vala_array_resize_method_constructor;
 }
 
 
@@ -80,7 +69,7 @@ static void vala_array_resize_method_instance_init (ValaArrayResizeMethod * self
 GType vala_array_resize_method_get_type (void) {
 	static GType vala_array_resize_method_type_id = 0;
 	if (vala_array_resize_method_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayResizeMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_resize_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayResizeMethod), 0, (GInstanceInitFunc) vala_array_resize_method_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayResizeMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_resize_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayResizeMethod), 0, (GInstanceInitFunc) vala_array_resize_method_instance_init, NULL };
 		vala_array_resize_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaArrayResizeMethod", &g_define_type_info, 0);
 	}
 	return vala_array_resize_method_type_id;
