@@ -39,14 +39,13 @@ struct _ValaBlockPrivate {
 
 #define VALA_BLOCK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_BLOCK, ValaBlockPrivate))
 enum  {
-	VALA_BLOCK_DUMMY_PROPERTY,
-	VALA_BLOCK_CONTAINS_JUMP_STATEMENT
+	VALA_BLOCK_DUMMY_PROPERTY
 };
 static void vala_block_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_block_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_block_parent_class = NULL;
 static ValaStatementIface* vala_block_vala_statement_parent_iface = NULL;
-static void vala_block_dispose (GObject * obj);
+static void vala_block_finalize (ValaCodeNode* obj);
 
 
 
@@ -55,15 +54,21 @@ static void vala_block_dispose (GObject * obj);
  *
  * @param source reference to source code
  */
-ValaBlock* vala_block_new (ValaSourceReference* source_reference) {
-	ValaBlock * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_BLOCK, 0, NULL);
+ValaBlock* vala_block_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaBlock* self;
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = ((ValaBlock*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (self));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
+ValaBlock* vala_block_new (ValaSourceReference* source_reference) {
+	return vala_block_construct (VALA_TYPE_BLOCK, source_reference);
+}
+
+
 /**
  * Append a statement to this block.
  *
@@ -83,7 +88,7 @@ void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt) {
  */
 GeeList* vala_block_get_statements (ValaBlock* self) {
 	g_return_val_if_fail (VALA_IS_BLOCK (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->statement_list));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->statement_list));
 }
 
 
@@ -106,7 +111,7 @@ void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local) {
  */
 GeeList* vala_block_get_local_variables (ValaBlock* self) {
 	g_return_val_if_fail (VALA_IS_BLOCK (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->local_variables));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->local_variables));
 }
 
 
@@ -131,7 +136,7 @@ static void vala_block_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
 			stmt = ((ValaStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (stmt), visitor);
-				(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
+				(stmt == NULL ? NULL : (stmt = (vala_code_node_unref (stmt), NULL)));
 			}
 		}
 	}
@@ -150,43 +155,12 @@ void vala_block_set_contains_jump_statement (ValaBlock* self, gboolean value) {
 }
 
 
-static void vala_block_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaBlock * self;
-	self = VALA_BLOCK (object);
-	switch (property_id) {
-		case VALA_BLOCK_CONTAINS_JUMP_STATEMENT:
-		g_value_set_boolean (value, vala_block_get_contains_jump_statement (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_block_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaBlock * self;
-	self = VALA_BLOCK (object);
-	switch (property_id) {
-		case VALA_BLOCK_CONTAINS_JUMP_STATEMENT:
-		vala_block_set_contains_jump_statement (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_block_class_init (ValaBlockClass * klass) {
 	vala_block_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_block_finalize;
 	g_type_class_add_private (klass, sizeof (ValaBlockPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_block_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_block_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_block_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_block_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_block_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_BLOCK_CONTAINS_JUMP_STATEMENT, g_param_spec_boolean ("contains-jump-statement", "contains-jump-statement", "contains-jump-statement", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -197,24 +171,24 @@ static void vala_block_vala_statement_interface_init (ValaStatementIface * iface
 
 static void vala_block_instance_init (ValaBlock * self) {
 	self->priv = VALA_BLOCK_GET_PRIVATE (self);
-	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_block_dispose (GObject * obj) {
+static void vala_block_finalize (ValaCodeNode* obj) {
 	ValaBlock * self;
 	self = VALA_BLOCK (obj);
-	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
-	(self->priv->local_variables == NULL ? NULL : (self->priv->local_variables = (g_object_unref (self->priv->local_variables), NULL)));
-	G_OBJECT_CLASS (vala_block_parent_class)->dispose (obj);
+	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (gee_collection_object_unref (self->priv->statement_list), NULL)));
+	(self->priv->local_variables == NULL ? NULL : (self->priv->local_variables = (gee_collection_object_unref (self->priv->local_variables), NULL)));
+	VALA_CODE_NODE_CLASS (vala_block_parent_class)->finalize (obj);
 }
 
 
 GType vala_block_get_type (void) {
 	static GType vala_block_type_id = 0;
-	if (G_UNLIKELY (vala_block_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBlock), 0, (GInstanceInitFunc) vala_block_instance_init };
+	if (vala_block_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBlock), 0, (GInstanceInitFunc) vala_block_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_block_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_block_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaBlock", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_block_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
