@@ -40,18 +40,13 @@ struct _ValaCatchClausePrivate {
 
 #define VALA_CATCH_CLAUSE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CATCH_CLAUSE, ValaCatchClausePrivate))
 enum  {
-	VALA_CATCH_CLAUSE_DUMMY_PROPERTY,
-	VALA_CATCH_CLAUSE_ERROR_TYPE,
-	VALA_CATCH_CLAUSE_VARIABLE_NAME,
-	VALA_CATCH_CLAUSE_BODY,
-	VALA_CATCH_CLAUSE_ERROR_VARIABLE,
-	VALA_CATCH_CLAUSE_CLABEL_NAME
+	VALA_CATCH_CLAUSE_DUMMY_PROPERTY
 };
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_catch_clause_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_catch_clause_parent_class = NULL;
-static void vala_catch_clause_finalize (GObject * obj);
+static void vala_catch_clause_finalize (ValaCodeNode* obj);
 
 
 
@@ -64,12 +59,12 @@ static void vala_catch_clause_finalize (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created catch clause
  */
-ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
-	ValaCatchClause * self;
+ValaCatchClause* vala_catch_clause_construct (GType object_type, ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
+	ValaCatchClause* self;
 	g_return_val_if_fail (error_type == NULL || VALA_IS_DATA_TYPE (error_type), NULL);
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_CATCH_CLAUSE, 0, NULL);
+	self = ((ValaCatchClause*) (g_type_create_instance (object_type)));
 	vala_catch_clause_set_error_type (self, error_type);
 	vala_catch_clause_set_variable_name (self, variable_name);
 	vala_catch_clause_set_body (self, body);
@@ -78,6 +73,11 @@ ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* va
 }
 
 
+ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
+	return vala_catch_clause_construct (VALA_TYPE_CATCH_CLAUSE, error_type, variable_name, body, source_reference);
+}
+
+
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (base);
@@ -120,11 +120,10 @@ void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* valu
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	if (self->priv->_data_type != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 	}
-	g_object_notify (((GObject *) (self)), "error-type");
 }
 
 
@@ -141,7 +140,6 @@ void vala_catch_clause_set_variable_name (ValaCatchClause* self, const char* val
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_variable_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "variable-name");
 }
 
 
@@ -157,8 +155,7 @@ void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value) {
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "body");
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -174,8 +171,7 @@ void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVaria
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_error_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (g_object_unref (self->priv->_error_variable), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "error-variable");
+	self->priv->_error_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL))), _tmp2);
 }
 
 
@@ -192,76 +188,16 @@ void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_clabel_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "clabel-name");
-}
-
-
-static void vala_catch_clause_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaCatchClause * self;
-	self = VALA_CATCH_CLAUSE (object);
-	switch (property_id) {
-		case VALA_CATCH_CLAUSE_ERROR_TYPE:
-		g_value_set_object (value, vala_catch_clause_get_error_type (self));
-		break;
-		case VALA_CATCH_CLAUSE_VARIABLE_NAME:
-		g_value_set_string (value, vala_catch_clause_get_variable_name (self));
-		break;
-		case VALA_CATCH_CLAUSE_BODY:
-		g_value_set_object (value, vala_catch_clause_get_body (self));
-		break;
-		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
-		g_value_set_object (value, vala_catch_clause_get_error_variable (self));
-		break;
-		case VALA_CATCH_CLAUSE_CLABEL_NAME:
-		g_value_set_string (value, vala_catch_clause_get_clabel_name (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_catch_clause_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaCatchClause * self;
-	self = VALA_CATCH_CLAUSE (object);
-	switch (property_id) {
-		case VALA_CATCH_CLAUSE_ERROR_TYPE:
-		vala_catch_clause_set_error_type (self, g_value_get_object (value));
-		break;
-		case VALA_CATCH_CLAUSE_VARIABLE_NAME:
-		vala_catch_clause_set_variable_name (self, g_value_get_string (value));
-		break;
-		case VALA_CATCH_CLAUSE_BODY:
-		vala_catch_clause_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
-		vala_catch_clause_set_error_variable (self, g_value_get_object (value));
-		break;
-		case VALA_CATCH_CLAUSE_CLABEL_NAME:
-		vala_catch_clause_set_clabel_name (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_catch_clause_class_init (ValaCatchClauseClass * klass) {
 	vala_catch_clause_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_catch_clause_finalize;
 	g_type_class_add_private (klass, sizeof (ValaCatchClausePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_catch_clause_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_catch_clause_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_catch_clause_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_catch_clause_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_catch_clause_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_catch_clause_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_ERROR_TYPE, g_param_spec_object ("error-type", "error-type", "error-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_VARIABLE_NAME, g_param_spec_string ("variable-name", "variable-name", "variable-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_ERROR_VARIABLE, g_param_spec_object ("error-variable", "error-variable", "error-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_CLABEL_NAME, g_param_spec_string ("clabel-name", "clabel-name", "clabel-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -270,22 +206,22 @@ static void vala_catch_clause_instance_init (ValaCatchClause * self) {
 }
 
 
-static void vala_catch_clause_finalize (GObject * obj) {
+static void vala_catch_clause_finalize (ValaCodeNode* obj) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (obj);
 	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (g_object_unref (self->priv->_error_variable), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	(self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL)));
 	self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL);
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_catch_clause_parent_class)->finalize (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_catch_clause_parent_class)->finalize (obj);
 }
 
 
 GType vala_catch_clause_get_type (void) {
 	static GType vala_catch_clause_type_id = 0;
 	if (vala_catch_clause_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCatchClauseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_catch_clause_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCatchClause), 0, (GInstanceInitFunc) vala_catch_clause_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCatchClauseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_catch_clause_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCatchClause), 0, (GInstanceInitFunc) vala_catch_clause_instance_init, NULL };
 		vala_catch_clause_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaCatchClause", &g_define_type_info, 0);
 	}
 	return vala_catch_clause_type_id;
