@@ -32,6 +32,7 @@
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valamethod.h>
 #include <vala/valaproperty.h>
 #include <vala/valapropertyaccessor.h>
@@ -72,10 +73,13 @@ struct _ValaCFGBuilder {
 	ValaCodeVisitor parent_instance;
 	ValaCFGBuilderPrivate * priv;
 };
+
 struct _ValaCFGBuilderClass {
 	ValaCodeVisitorClass parent_class;
 };
 
+
+ValaCFGBuilder* vala_cfg_builder_construct (GType object_type);
 ValaCFGBuilder* vala_cfg_builder_new (void);
 void vala_cfg_builder_build_cfg (ValaCFGBuilder* self, ValaCodeContext* context);
 GType vala_cfg_builder_get_type (void);
