@@ -41,20 +41,29 @@ G_BEGIN_DECLS
 #define VALA_CODE_CONTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_CONTEXT, ValaCodeContextClass))
 
 typedef struct _ValaCodeContextPrivate ValaCodeContextPrivate;
+typedef struct _ValaParamSpecCodeContext ValaParamSpecCodeContext;
 
 /**
  * The root of the code tree.
  */
 struct _ValaCodeContext {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeContextPrivate * priv;
 };
 
 struct _ValaCodeContextClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeContext *self);
+};
+
+struct _ValaParamSpecCodeContext {
+	GParamSpec parent_instance;
 };
 
 
+gboolean vala_code_context_require_glib_version (ValaCodeContext* self, gint major, gint minor);
+ValaCodeContext* vala_code_context_construct (GType object_type);
 ValaCodeContext* vala_code_context_new (void);
 GeeList* vala_code_context_get_source_files (ValaCodeContext* self);
 GeeList* vala_code_context_get_c_source_files (ValaCodeContext* self);
@@ -100,12 +109,21 @@ ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self);
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value);
 gboolean vala_code_context_get_save_temps (ValaCodeContext* self);
 void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value);
+gint vala_code_context_get_target_glib_major (ValaCodeContext* self);
+void vala_code_context_set_target_glib_major (ValaCodeContext* self, gint value);
+gint vala_code_context_get_target_glib_minor (ValaCodeContext* self);
+void vala_code_context_set_target_glib_minor (ValaCodeContext* self, gint value);
 gboolean vala_code_context_get_save_csources (ValaCodeContext* self);
 gboolean vala_code_context_get_save_cheaders (ValaCodeContext* self);
 ValaNamespace* vala_code_context_get_root (ValaCodeContext* self);
 ValaCodeGenerator* vala_code_context_get_codegen (ValaCodeContext* self);
 void vala_code_context_set_codegen (ValaCodeContext* self, ValaCodeGenerator* value);
+GParamSpec* vala_param_spec_code_context (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_context (const GValue* value);
+void vala_value_set_code_context (GValue* value, gpointer v_object);
 GType vala_code_context_get_type (void);
+gpointer vala_code_context_ref (gpointer instance);
+void vala_code_context_unref (gpointer instance);
 
 
 G_END_DECLS
