@@ -68,6 +68,7 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_creation_method_binding) (ValaCodeGenerator* self, ValaCreationMethod* node);
 	ValaCodeBinding* (*create_formal_parameter_binding) (ValaCodeGenerator* self, ValaFormalParameter* node);
 	ValaCodeBinding* (*create_property_binding) (ValaCodeGenerator* self, ValaProperty* node);
+	ValaCodeBinding* (*create_dynamic_property_binding) (ValaCodeGenerator* self, ValaDynamicProperty* node);
 	ValaCodeBinding* (*create_property_accessor_binding) (ValaCodeGenerator* self, ValaPropertyAccessor* node);
 	ValaCodeBinding* (*create_signal_binding) (ValaCodeGenerator* self, ValaSignal* node);
 	ValaCodeBinding* (*create_dynamic_signal_binding) (ValaCodeGenerator* self, ValaDynamicSignal* node);
@@ -142,6 +143,7 @@ ValaCodeBinding* vala_code_generator_create_dynamic_method_binding (ValaCodeGene
 ValaCodeBinding* vala_code_generator_create_creation_method_binding (ValaCodeGenerator* self, ValaCreationMethod* node);
 ValaCodeBinding* vala_code_generator_create_formal_parameter_binding (ValaCodeGenerator* self, ValaFormalParameter* node);
 ValaCodeBinding* vala_code_generator_create_property_binding (ValaCodeGenerator* self, ValaProperty* node);
+ValaCodeBinding* vala_code_generator_create_dynamic_property_binding (ValaCodeGenerator* self, ValaDynamicProperty* node);
 ValaCodeBinding* vala_code_generator_create_property_accessor_binding (ValaCodeGenerator* self, ValaPropertyAccessor* node);
 ValaCodeBinding* vala_code_generator_create_signal_binding (ValaCodeGenerator* self, ValaSignal* node);
 ValaCodeBinding* vala_code_generator_create_dynamic_signal_binding (ValaCodeGenerator* self, ValaDynamicSignal* node);
@@ -196,6 +198,7 @@ ValaCodeBinding* vala_code_generator_create_type_check_binding (ValaCodeGenerato
 ValaCodeBinding* vala_code_generator_create_conditional_expression_binding (ValaCodeGenerator* self, ValaConditionalExpression* node);
 ValaCodeBinding* vala_code_generator_create_lambda_expression_binding (ValaCodeGenerator* self, ValaLambdaExpression* node);
 ValaCodeBinding* vala_code_generator_create_assignment_binding (ValaCodeGenerator* self, ValaAssignment* node);
+ValaCodeGenerator* vala_code_generator_construct (GType object_type);
 ValaCodeGenerator* vala_code_generator_new (void);
 GType vala_code_generator_get_type (void);
 
