@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -38,24 +39,22 @@ typedef struct _ValaExpression ValaExpression;
 typedef struct _ValaExpressionClass ValaExpressionClass;
 typedef struct _ValaCodeNode ValaCodeNode;
 typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
+typedef struct _ValaDataType ValaDataType;
+typedef struct _ValaDataTypeClass ValaDataTypeClass;
 typedef struct _ValaCodeVisitor ValaCodeVisitor;
 typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
-typedef struct _ValaSymbol ValaSymbol;
-typedef struct _ValaSymbolClass ValaSymbolClass;
-typedef struct _ValaScope ValaScope;
-typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaMember ValaMember;
 typedef struct _ValaMemberClass ValaMemberClass;
-typedef struct _ValaDataType ValaDataType;
-typedef struct _ValaDataTypeClass ValaDataTypeClass;
-typedef struct _ValaTypeParameter ValaTypeParameter;
-typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
+typedef struct _ValaSymbol ValaSymbol;
+typedef struct _ValaSymbolClass ValaSymbolClass;
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaFormalParameter ValaFormalParameter;
@@ -66,6 +65,8 @@ typedef struct _ValaNamespace ValaNamespace;
 typedef struct _ValaNamespaceClass ValaNamespaceClass;
 typedef struct _ValaClass ValaClass;
 typedef struct _ValaClassClass ValaClassClass;
+typedef struct _ValaTypeParameter ValaTypeParameter;
+typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
 typedef struct _ValaConstant ValaConstant;
 typedef struct _ValaConstantClass ValaConstantClass;
 typedef struct _ValaField ValaField;
@@ -108,6 +109,8 @@ typedef struct _ValaInvocationExpression ValaInvocationExpression;
 typedef struct _ValaInvocationExpressionClass ValaInvocationExpressionClass;
 typedef struct _ValaCreationMethod ValaCreationMethod;
 typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+typedef struct _ValaDynamicProperty ValaDynamicProperty;
+typedef struct _ValaDynamicPropertyClass ValaDynamicPropertyClass;
 typedef struct _ValaDynamicSignal ValaDynamicSignal;
 typedef struct _ValaDynamicSignalClass ValaDynamicSignalClass;
 typedef struct _ValaEmptyStatement ValaEmptyStatement;
@@ -202,8 +205,8 @@ typedef struct _ValaLambdaExpression ValaLambdaExpression;
 typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
 typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
-typedef struct _ValaNamespaceReference ValaNamespaceReference;
-typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
+typedef struct _ValaUsingDirective ValaUsingDirective;
+typedef struct _ValaUsingDirectiveClass ValaUsingDirectiveClass;
 typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
 typedef struct _ValaSourceFileCycleClass ValaSourceFileCycleClass;
 typedef struct _ValaNamedArgument ValaNamedArgument;
@@ -219,6 +222,7 @@ typedef struct _ValaAttributeClass ValaAttributeClass;
 #define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
 
 typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
+typedef struct _ValaParamSpecCodeNode ValaParamSpecCodeNode;
 
 /**
  * Represents a part of the parsed source code.
@@ -227,12 +231,15 @@ typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
  * compilation process.
  */
 struct _ValaCodeNode {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeNodePrivate * priv;
 	GList* attributes;
 };
+
 struct _ValaCodeNodeClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeNode *self);
 	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
 	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
 	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
@@ -241,6 +248,14 @@ struct _ValaCodeNodeClass {
 	ValaCodeBinding* (*create_code_binding) (ValaCodeNode* self, ValaCodeGenerator* codegen);
 };
 
+struct _ValaParamSpecCodeNode {
+	GParamSpec parent_instance;
+};
+
+
+GeeList* vala_code_node_get_error_types (ValaCodeNode* self);
+void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
+void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
@@ -249,7 +264,6 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 char* vala_code_node_to_string (ValaCodeNode* self);
 ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
 ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
-ValaCodeNode* vala_code_node_new (void);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
@@ -259,8 +273,12 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
-void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value);
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_node (const GValue* value);
+void vala_value_set_code_node (GValue* value, gpointer v_object);
 GType vala_code_node_get_type (void);
+gpointer vala_code_node_ref (gpointer instance);
+void vala_code_node_unref (gpointer instance);
 
 
 G_END_DECLS
