@@ -39,17 +39,20 @@ G_BEGIN_DECLS
 #define VALA_CODE_VISITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
 
 typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;
+typedef struct _ValaParamSpecCodeVisitor ValaParamSpecCodeVisitor;
 
 /**
  * Abstract code node visitor for traversing source code tree.
  */
 struct _ValaCodeVisitor {
-	GObject parent_instance;
+	GTypeInstance parent_instance;
+	volatile int ref_count;
 	ValaCodeVisitorPrivate * priv;
 };
 
 struct _ValaCodeVisitorClass {
-	GObjectClass parent_class;
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeVisitor *self);
 	void (*visit_source_file) (ValaCodeVisitor* self, ValaSourceFile* source_file);
 	void (*visit_namespace) (ValaCodeVisitor* self, ValaNamespace* ns);
 	void (*visit_class) (ValaCodeVisitor* self, ValaClass* cl);
@@ -73,7 +76,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_destructor) (ValaCodeVisitor* self, ValaDestructor* d);
 	void (*visit_named_argument) (ValaCodeVisitor* self, ValaNamedArgument* n);
 	void (*visit_type_parameter) (ValaCodeVisitor* self, ValaTypeParameter* p);
-	void (*visit_namespace_reference) (ValaCodeVisitor* self, ValaNamespaceReference* ns);
+	void (*visit_using_directive) (ValaCodeVisitor* self, ValaUsingDirective* ns);
 	void (*visit_data_type) (ValaCodeVisitor* self, ValaDataType* type);
 	void (*visit_block) (ValaCodeVisitor* self, ValaBlock* b);
 	void (*visit_empty_statement) (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
@@ -127,6 +130,10 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
+struct _ValaParamSpecCodeVisitor {
+	GParamSpec parent_instance;
+};
+
 
 void vala_code_visitor_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
 void vala_code_visitor_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
@@ -151,7 +158,7 @@ void vala_code_visitor_visit_constructor (ValaCodeVisitor* self, ValaConstructor
 void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d);
 void vala_code_visitor_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n);
 void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
-void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
+void vala_code_visitor_visit_using_directive (ValaCodeVisitor* self, ValaUsingDirective* ns);
 void vala_code_visitor_visit_data_type (ValaCodeVisitor* self, ValaDataType* type);
 void vala_code_visitor_visit_block (ValaCodeVisitor* self, ValaBlock* b);
 void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
@@ -203,7 +210,12 @@ void vala_code_visitor_visit_conditional_expression (ValaCodeVisitor* self, Vala
 void vala_code_visitor_visit_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr);
 void vala_code_visitor_visit_assignment (ValaCodeVisitor* self, ValaAssignment* a);
 void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr);
+GParamSpec* vala_param_spec_code_visitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+gpointer vala_value_get_code_visitor (const GValue* value);
+void vala_value_set_code_visitor (GValue* value, gpointer v_object);
 GType vala_code_visitor_get_type (void);
+gpointer vala_code_visitor_ref (gpointer instance);
+void vala_code_visitor_unref (gpointer instance);
 
 
 G_END_DECLS
