@@ -40,9 +40,7 @@ struct _ValaConstantPrivate {
 
 #define VALA_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTANT, ValaConstantPrivate))
 enum  {
-	VALA_CONSTANT_DUMMY_PROPERTY,
-	VALA_CONSTANT_TYPE_REFERENCE,
-	VALA_CONSTANT_INITIALIZER
+	VALA_CONSTANT_DUMMY_PROPERTY
 };
 static void vala_constant_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -52,7 +50,7 @@ static void vala_constant_real_replace_type (ValaCodeNode* base, ValaDataType* o
 static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttribute* a);
 static gpointer vala_constant_parent_class = NULL;
 static ValaLockableIface* vala_constant_vala_lockable_parent_iface = NULL;
-static void vala_constant_finalize (GObject * obj);
+static void vala_constant_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -67,13 +65,14 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created constant
  */
-ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
-	ValaConstant * self;
+ValaConstant* vala_constant_construct (GType object_type, const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	ValaConstant* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_CONSTANT, 0, NULL);
+	self = ((ValaConstant*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_MEMBER (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_constant_set_type_reference (self, type_reference);
 	vala_constant_set_initializer (self, initializer);
@@ -82,6 +81,11 @@ ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference,
 }
 
 
+ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	return vala_constant_construct (VALA_TYPE_CONSTANT, name, type_reference, initializer, source_reference);
+}
+
+
 static void vala_constant_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (base);
@@ -217,12 +221,12 @@ void vala_constant_process_attributes (ValaConstant* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_constant_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -241,9 +245,8 @@ void vala_constant_set_type_reference (ValaConstant* self, ValaDataType* value)
 	g_return_if_fail (VALA_IS_CONSTANT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "type-reference");
 }
 
 
@@ -259,59 +262,20 @@ void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value) {
 	g_return_if_fail (VALA_IS_CONSTANT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL))), _tmp2);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_initializer), VALA_CODE_NODE (self));
 	}
-	g_object_notify (((GObject *) (self)), "initializer");
-}
-
-
-static void vala_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaConstant * self;
-	self = VALA_CONSTANT (object);
-	switch (property_id) {
-		case VALA_CONSTANT_TYPE_REFERENCE:
-		g_value_set_object (value, vala_constant_get_type_reference (self));
-		break;
-		case VALA_CONSTANT_INITIALIZER:
-		g_value_set_object (value, vala_constant_get_initializer (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaConstant * self;
-	self = VALA_CONSTANT (object);
-	switch (property_id) {
-		case VALA_CONSTANT_TYPE_REFERENCE:
-		vala_constant_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_CONSTANT_INITIALIZER:
-		vala_constant_set_initializer (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_constant_class_init (ValaConstantClass * klass) {
 	vala_constant_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_constant_finalize;
 	g_type_class_add_private (klass, sizeof (ValaConstantPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_constant_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_constant_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_constant_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_constant_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_constant_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_constant_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTANT_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTANT_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -328,20 +292,20 @@ static void vala_constant_instance_init (ValaConstant * self) {
 }
 
 
-static void vala_constant_finalize (GObject * obj) {
+static void vala_constant_finalize (ValaCodeNode* obj) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (obj);
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
-	G_OBJECT_CLASS (vala_constant_parent_class)->finalize (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)));
+	VALA_CODE_NODE_CLASS (vala_constant_parent_class)->finalize (obj);
 }
 
 
 GType vala_constant_get_type (void) {
 	static GType vala_constant_type_id = 0;
 	if (vala_constant_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstant), 0, (GInstanceInitFunc) vala_constant_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstant), 0, (GInstanceInitFunc) vala_constant_instance_init, NULL };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_constant_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_constant_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaConstant", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_constant_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
