@@ -34,13 +34,12 @@ struct _ValaDeclarationStatementPrivate {
 
 #define VALA_DECLARATION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementPrivate))
 enum  {
-	VALA_DECLARATION_STATEMENT_DUMMY_PROPERTY,
-	VALA_DECLARATION_STATEMENT_DECLARATION
+	VALA_DECLARATION_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_declaration_statement_parent_class = NULL;
 static ValaStatementIface* vala_declaration_statement_vala_statement_parent_iface = NULL;
-static void vala_declaration_statement_dispose (GObject * obj);
+static void vala_declaration_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -51,29 +50,22 @@ static void vala_declaration_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created declaration statement
  */
-ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaDeclarationStatement * self;
+ValaDeclarationStatement* vala_declaration_statement_construct (GType object_type, ValaSymbol* declaration, ValaSourceReference* source_reference) {
+	ValaDeclarationStatement* self;
 	g_return_val_if_fail (VALA_IS_SYMBOL (declaration), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "declaration";
-	g_value_init (&__params_it->value, VALA_TYPE_SYMBOL);
-	g_value_set_object (&__params_it->value, declaration);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_DECLARATION_STATEMENT, __params_it - __params, __params);
+	self = ((ValaDeclarationStatement*) (g_type_create_instance (object_type)));
+	vala_declaration_statement_set_declaration (self, declaration);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference) {
+	return vala_declaration_statement_construct (VALA_TYPE_DECLARATION_STATEMENT, declaration, source_reference);
+}
+
+
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (base);
@@ -95,46 +87,15 @@ void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self,
 	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_declaration = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), _tmp2);
-}
-
-
-static void vala_declaration_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDeclarationStatement * self;
-	self = VALA_DECLARATION_STATEMENT (object);
-	switch (property_id) {
-		case VALA_DECLARATION_STATEMENT_DECLARATION:
-		g_value_set_object (value, vala_declaration_statement_get_declaration (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_declaration_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDeclarationStatement * self;
-	self = VALA_DECLARATION_STATEMENT (object);
-	switch (property_id) {
-		case VALA_DECLARATION_STATEMENT_DECLARATION:
-		vala_declaration_statement_set_declaration (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_declaration = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL))), _tmp2);
 }
 
 
 static void vala_declaration_statement_class_init (ValaDeclarationStatementClass * klass) {
 	vala_declaration_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_declaration_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDeclarationStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_declaration_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "declaration", "declaration", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -148,18 +109,18 @@ static void vala_declaration_statement_instance_init (ValaDeclarationStatement *
 }
 
 
-static void vala_declaration_statement_dispose (GObject * obj) {
+static void vala_declaration_statement_finalize (ValaCodeNode* obj) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (obj);
-	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL)));
-	G_OBJECT_CLASS (vala_declaration_statement_parent_class)->dispose (obj);
+	(self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL)));
+	VALA_CODE_NODE_CLASS (vala_declaration_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_declaration_statement_get_type (void) {
 	static GType vala_declaration_statement_type_id = 0;
-	if (G_UNLIKELY (vala_declaration_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_instance_init };
+	if (vala_declaration_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDeclarationStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_declaration_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDeclarationStatement), 0, (GInstanceInitFunc) vala_declaration_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_declaration_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_declaration_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDeclarationStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_declaration_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
