@@ -36,16 +36,14 @@ struct _ValaDoStatementPrivate {
 
 #define VALA_DO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DO_STATEMENT, ValaDoStatementPrivate))
 enum  {
-	VALA_DO_STATEMENT_DUMMY_PROPERTY,
-	VALA_DO_STATEMENT_BODY,
-	VALA_DO_STATEMENT_CONDITION
+	VALA_DO_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_do_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_do_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_do_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_do_statement_parent_class = NULL;
 static ValaStatementIface* vala_do_statement_vala_statement_parent_iface = NULL;
-static void vala_do_statement_dispose (GObject * obj);
+static void vala_do_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -57,31 +55,24 @@ static void vala_do_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created do statement
  */
-ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* condition, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaDoStatement * self;
+ValaDoStatement* vala_do_statement_construct (GType object_type, ValaBlock* body, ValaExpression* condition, ValaSourceReference* source_reference) {
+	ValaDoStatement* self;
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "condition";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, condition);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_DO_STATEMENT, __params_it - __params, __params);
+	self = ((ValaDoStatement*) (g_type_create_instance (object_type)));
+	vala_do_statement_set_condition (self, condition);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_do_statement_set_body (self, body);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* condition, ValaSourceReference* source_reference) {
+	return vala_do_statement_construct (VALA_TYPE_DO_STATEMENT, body, condition, source_reference);
+}
+
+
 static void vala_do_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (base);
@@ -123,7 +114,7 @@ void vala_do_statement_set_body (ValaDoStatement* self, ValaBlock* value) {
 	g_return_if_fail (VALA_IS_DO_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
 }
 
@@ -140,56 +131,18 @@ void vala_do_statement_set_condition (ValaDoStatement* self, ValaExpression* val
 	g_return_if_fail (VALA_IS_DO_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 }
 
 
-static void vala_do_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaDoStatement * self;
-	self = VALA_DO_STATEMENT (object);
-	switch (property_id) {
-		case VALA_DO_STATEMENT_BODY:
-		g_value_set_object (value, vala_do_statement_get_body (self));
-		break;
-		case VALA_DO_STATEMENT_CONDITION:
-		g_value_set_object (value, vala_do_statement_get_condition (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_do_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaDoStatement * self;
-	self = VALA_DO_STATEMENT (object);
-	switch (property_id) {
-		case VALA_DO_STATEMENT_BODY:
-		vala_do_statement_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_DO_STATEMENT_CONDITION:
-		vala_do_statement_set_condition (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_do_statement_class_init (ValaDoStatementClass * klass) {
 	vala_do_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_do_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaDoStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_do_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_do_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_do_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_do_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_do_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_do_statement_real_replace_expression;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DO_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DO_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -198,24 +151,24 @@ static void vala_do_statement_vala_statement_interface_init (ValaStatementIface
 }
 
 
-static void vala_do_statement_init (ValaDoStatement * self) {
+static void vala_do_statement_instance_init (ValaDoStatement * self) {
 	self->priv = VALA_DO_STATEMENT_GET_PRIVATE (self);
 }
 
 
-static void vala_do_statement_dispose (GObject * obj) {
+static void vala_do_statement_finalize (ValaCodeNode* obj) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (obj);
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_do_statement_parent_class)->dispose (obj);
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	VALA_CODE_NODE_CLASS (vala_do_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_do_statement_get_type (void) {
 	static GType vala_do_statement_type_id = 0;
-	if (G_UNLIKELY (vala_do_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDoStatement), 0, (GInstanceInitFunc) vala_do_statement_init };
+	if (vala_do_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDoStatement), 0, (GInstanceInitFunc) vala_do_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_do_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_do_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDoStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_do_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
