@@ -39,8 +39,7 @@ struct _ValaElementAccessPrivate {
 
 #define VALA_ELEMENT_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ELEMENT_ACCESS, ValaElementAccessPrivate))
 enum  {
-	VALA_ELEMENT_ACCESS_DUMMY_PROPERTY,
-	VALA_ELEMENT_ACCESS_CONTAINER
+	VALA_ELEMENT_ACCESS_DUMMY_PROPERTY
 };
 static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_element_access_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -48,7 +47,7 @@ static void vala_element_access_real_replace_expression (ValaCodeNode* base, Val
 static gboolean vala_element_access_real_is_pure (ValaExpression* base);
 static ValaCodeBinding* vala_element_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_element_access_parent_class = NULL;
-static void vala_element_access_finalize (GObject * obj);
+static void vala_element_access_finalize (ValaCodeNode* obj);
 
 
 
@@ -62,18 +61,23 @@ void vala_element_access_append_index (ValaElementAccess* self, ValaExpression*
 
 GeeList* vala_element_access_get_indices (ValaElementAccess* self) {
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->indices));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->indices));
+}
+
+
+ValaElementAccess* vala_element_access_construct (GType object_type, ValaExpression* container, ValaSourceReference* source_reference) {
+	ValaElementAccess* self;
+	g_return_val_if_fail (VALA_IS_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = ((ValaElementAccess*) (g_type_create_instance (object_type)));
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_element_access_set_container (self, container);
+	return self;
 }
 
 
 ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourceReference* source_reference) {
-	ValaElementAccess * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (container), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ELEMENT_ACCESS, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	vala_element_access_set_container (self, container);
-	return self;
+	return vala_element_access_construct (VALA_TYPE_ELEMENT_ACCESS, container, source_reference);
 }
 
 
@@ -100,7 +104,7 @@ static void vala_element_access_real_accept_children (ValaCodeNode* base, ValaCo
 			e = ((ValaExpression*) (gee_list_get (GEE_LIST (e_collection), e_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (e), visitor);
-				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
+				(e == NULL ? NULL : (e = (vala_code_node_unref (e), NULL)));
 			}
 		}
 	}
@@ -137,9 +141,9 @@ static gboolean vala_element_access_real_is_pure (ValaExpression* base) {
 			{
 				if (!vala_expression_is_pure (index)) {
 					gboolean _tmp0;
-					return (_tmp0 = FALSE, (index == NULL ? NULL : (index = (g_object_unref (index), NULL))), _tmp0);
+					return (_tmp0 = FALSE, (index == NULL ? NULL : (index = (vala_code_node_unref (index), NULL))), _tmp0);
 				}
-				(index == NULL ? NULL : (index = (g_object_unref (index), NULL)));
+				(index == NULL ? NULL : (index = (vala_code_node_unref (index), NULL)));
 			}
 		}
 	}
@@ -167,73 +171,41 @@ void vala_element_access_set_container (ValaElementAccess* self, ValaExpression*
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "container");
-}
-
-
-static void vala_element_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaElementAccess * self;
-	self = VALA_ELEMENT_ACCESS (object);
-	switch (property_id) {
-		case VALA_ELEMENT_ACCESS_CONTAINER:
-		g_value_set_object (value, vala_element_access_get_container (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_element_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaElementAccess * self;
-	self = VALA_ELEMENT_ACCESS (object);
-	switch (property_id) {
-		case VALA_ELEMENT_ACCESS_CONTAINER:
-		vala_element_access_set_container (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_code_node_unref (self->priv->_container), NULL))), _tmp2);
 }
 
 
 static void vala_element_access_class_init (ValaElementAccessClass * klass) {
 	vala_element_access_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_element_access_finalize;
 	g_type_class_add_private (klass, sizeof (ValaElementAccessPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_element_access_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_element_access_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_element_access_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_element_access_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_element_access_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_element_access_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_element_access_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_element_access_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "container", "container", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_element_access_instance_init (ValaElementAccess * self) {
 	self->priv = VALA_ELEMENT_ACCESS_GET_PRIVATE (self);
-	self->priv->indices = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->indices = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_element_access_finalize (GObject * obj) {
+static void vala_element_access_finalize (ValaCodeNode* obj) {
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (obj);
-	(self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL)));
-	(self->priv->indices == NULL ? NULL : (self->priv->indices = (g_object_unref (self->priv->indices), NULL)));
-	G_OBJECT_CLASS (vala_element_access_parent_class)->finalize (obj);
+	(self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_code_node_unref (self->priv->_container), NULL)));
+	(self->priv->indices == NULL ? NULL : (self->priv->indices = (gee_collection_object_unref (self->priv->indices), NULL)));
+	VALA_CODE_NODE_CLASS (vala_element_access_parent_class)->finalize (obj);
 }
 
 
 GType vala_element_access_get_type (void) {
 	static GType vala_element_access_type_id = 0;
 	if (vala_element_access_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaElementAccess), 0, (GInstanceInitFunc) vala_element_access_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaElementAccess), 0, (GInstanceInitFunc) vala_element_access_instance_init, NULL };
 		vala_element_access_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaElementAccess", &g_define_type_info, 0);
 	}
 	return vala_element_access_type_id;
