@@ -69,7 +69,7 @@ static char* vala_error_domain_real_get_marshaller_type_name (ValaTypeSymbol* ba
 static char* vala_error_domain_real_get_get_value_function (ValaTypeSymbol* base);
 static char* vala_error_domain_real_get_set_value_function (ValaTypeSymbol* base);
 static gpointer vala_error_domain_parent_class = NULL;
-static void vala_error_domain_finalize (GObject * obj);
+static void vala_error_domain_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -82,17 +82,23 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source_reference reference to source code
  * @return                 newly created error domain
  */
-ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
-	ValaErrorDomain * self;
+ValaErrorDomain* vala_error_domain_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaErrorDomain* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_ERROR_DOMAIN, 0, NULL);
+	self = ((ValaErrorDomain*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_TYPESYMBOL (self)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_error_domain_construct (VALA_TYPE_ERROR_DOMAIN, name, source_reference);
+}
+
+
 /**
  * Appends the specified code to the list of error codes.
  *
@@ -125,8 +131,8 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_value_type_new (VALA_TYPESYMBOL (self)))), NULL)));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
@@ -141,7 +147,7 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
  */
 GeeList* vala_error_domain_get_codes (ValaErrorDomain* self) {
 	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->codes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->codes));
 }
 
 
@@ -152,7 +158,7 @@ GeeList* vala_error_domain_get_codes (ValaErrorDomain* self) {
  */
 GeeList* vala_error_domain_get_methods (ValaErrorDomain* self) {
 	g_return_val_if_fail (VALA_IS_ERROR_DOMAIN (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->methods));
 }
 
 
@@ -177,7 +183,7 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 			ecode = ((ValaErrorCode*) (gee_list_get (GEE_LIST (ecode_collection), ecode_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ecode), visitor);
-				(ecode == NULL ? NULL : (ecode = (g_object_unref (ecode), NULL)));
+				(ecode == NULL ? NULL : (ecode = (vala_code_node_unref (ecode), NULL)));
 			}
 		}
 	}
@@ -190,7 +196,7 @@ static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCode
 			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
 	}
@@ -387,12 +393,12 @@ void vala_error_domain_process_attributes (ValaErrorDomain* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_error_domain_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -429,8 +435,8 @@ static char* vala_error_domain_real_get_set_value_function (ValaTypeSymbol* base
 
 static void vala_error_domain_class_init (ValaErrorDomainClass * klass) {
 	vala_error_domain_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_error_domain_finalize;
 	g_type_class_add_private (klass, sizeof (ValaErrorDomainPrivate));
-	G_OBJECT_CLASS (klass)->finalize = vala_error_domain_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_error_domain_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_error_domain_real_accept_children;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_error_domain_real_get_cname;
@@ -447,28 +453,28 @@ static void vala_error_domain_class_init (ValaErrorDomainClass * klass) {
 
 static void vala_error_domain_instance_init (ValaErrorDomain * self) {
 	self->priv = VALA_ERROR_DOMAIN_GET_PRIVATE (self);
-	self->priv->codes = GEE_LIST (gee_array_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->codes = GEE_LIST (gee_array_list_new (VALA_TYPE_ERROR_CODE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_error_domain_finalize (GObject * obj) {
+static void vala_error_domain_finalize (ValaCodeNode* obj) {
 	ValaErrorDomain * self;
 	self = VALA_ERROR_DOMAIN (obj);
-	(self->priv->codes == NULL ? NULL : (self->priv->codes = (g_object_unref (self->priv->codes), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
+	(self->priv->codes == NULL ? NULL : (self->priv->codes = (gee_collection_object_unref (self->priv->codes), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->cprefix = (g_free (self->priv->cprefix), NULL);
 	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
-	G_OBJECT_CLASS (vala_error_domain_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_error_domain_parent_class)->finalize (obj);
 }
 
 
 GType vala_error_domain_get_type (void) {
 	static GType vala_error_domain_type_id = 0;
 	if (vala_error_domain_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorDomainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_domain_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorDomain), 0, (GInstanceInitFunc) vala_error_domain_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorDomainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_domain_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorDomain), 0, (GInstanceInitFunc) vala_error_domain_instance_init, NULL };
 		vala_error_domain_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaErrorDomain", &g_define_type_info, 0);
 	}
 	return vala_error_domain_type_id;
