@@ -27,28 +27,25 @@
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valanamedargument.h>
+#include <vala/valastringliteral.h>
 
 
 
 
 struct _ValaFieldPrivate {
-	ValaExpression* _initializer;
 	MemberBinding _binding;
 	gboolean _is_volatile;
 	gboolean _no_array_length;
 	char* cname;
 	gboolean lock_used;
+	ValaExpression* _initializer;
 	ValaDataType* _data_type;
 };
 
 #define VALA_FIELD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FIELD, ValaFieldPrivate))
 enum  {
-	VALA_FIELD_DUMMY_PROPERTY,
-	VALA_FIELD_TYPE_REFERENCE,
-	VALA_FIELD_INITIALIZER,
-	VALA_FIELD_BINDING,
-	VALA_FIELD_IS_VOLATILE,
-	VALA_FIELD_NO_ARRAY_LENGTH
+	VALA_FIELD_DUMMY_PROPERTY
 };
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -58,7 +55,7 @@ static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_field_parent_class = NULL;
 static ValaLockableIface* vala_field_vala_lockable_parent_iface = NULL;
-static void vala_field_dispose (GObject * obj);
+static void vala_field_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -73,21 +70,27 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source reference to source code
  * @return       newly created field
  */
-ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
-	ValaField * self;
+ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	ValaField* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (field_type), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_FIELD, 0, NULL);
-	vala_field_set_type_reference (self, type_reference);
+	self = ((ValaField*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_MEMBER (self)));
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_field_set_field_type (self, field_type);
 	vala_field_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	return vala_field_construct (VALA_TYPE_FIELD, name, field_type, initializer, source_reference);
+}
+
+
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
 	self = VALA_FIELD (base);
@@ -101,9 +104,9 @@ static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
 	ValaField * self;
 	self = VALA_FIELD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
-	if (self->priv->_initializer != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_field_type (self)), visitor);
+	if (vala_field_get_initializer (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_field_get_initializer (self)), visitor);
 	}
 }
 
@@ -177,8 +180,8 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
 			char** filename_collection;
-			char** filename_it;
 			int filename_collection_length1;
+			char** filename_it;
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
@@ -191,7 +194,7 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 					filename = (g_free (filename), NULL);
 				}
 			}
-			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) (g_free))), NULL);
 		}
 		val = (g_free (val), NULL);
 	}
@@ -211,7 +214,7 @@ void vala_field_process_attributes (ValaField* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_field_process_ccode_attribute (self, a);
@@ -220,7 +223,7 @@ void vala_field_process_attributes (ValaField* self) {
 						vala_field_set_no_array_length (self, TRUE);
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -246,25 +249,67 @@ static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_
 	self = VALA_FIELD (base);
 	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
 	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
-	if (vala_field_get_type_reference (self) == old_type) {
-		vala_field_set_type_reference (self, new_type);
+	if (vala_field_get_field_type (self) == old_type) {
+		vala_field_set_field_type (self, new_type);
 	}
 }
 
 
-ValaDataType* vala_field_get_type_reference (ValaField* self) {
+char* vala_field_get_ctype (ValaField* self) {
+	ValaAttribute* attr;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
+	attr = vala_code_node_get_attribute (VALA_CODE_NODE (self), "CCode");
+	if (attr == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = NULL, (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = vala_attribute_get_string (attr, "type"), (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp1);
+}
+
+
+void vala_field_set_ctype (ValaField* self, const char* ctype) {
+	ValaAttribute* attr;
+	ValaNamedArgument* _tmp4;
+	ValaStringLiteral* _tmp3;
+	char* _tmp2;
+	g_return_if_fail (VALA_IS_FIELD (self));
+	g_return_if_fail (ctype != NULL);
+	attr = vala_code_node_get_attribute (VALA_CODE_NODE (self), "CCode");
+	if (attr == NULL) {
+		ValaAttribute* _tmp0;
+		ValaAttribute* _tmp1;
+		_tmp0 = NULL;
+		attr = (_tmp0 = vala_attribute_new ("CCode", NULL), (attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL))), _tmp0);
+		_tmp1 = NULL;
+		VALA_CODE_NODE (self)->attributes = g_list_append (VALA_CODE_NODE (self)->attributes, (_tmp1 = attr, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))));
+	}
+	_tmp4 = NULL;
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	vala_attribute_add_argument (attr, (_tmp4 = vala_named_argument_new ("type", VALA_EXPRESSION ((_tmp3 = vala_string_literal_new ((_tmp2 = g_strdup_printf ("\"%s\"", ctype)), NULL))), NULL)));
+	(_tmp4 == NULL ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)));
+	(_tmp3 == NULL ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL)));
+	_tmp2 = (g_free (_tmp2), NULL);
+	(attr == NULL ? NULL : (attr = (vala_code_node_unref (attr), NULL)));
+}
+
+
+ValaDataType* vala_field_get_field_type (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_field_set_type_reference (ValaField* self, ValaDataType* value) {
+void vala_field_set_field_type (ValaField* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
@@ -281,7 +326,10 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL))), _tmp2);
+	if (self->priv->_initializer != NULL) {
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_initializer), VALA_CODE_NODE (self));
+	}
 }
 
 
@@ -321,72 +369,13 @@ void vala_field_set_no_array_length (ValaField* self, gboolean value) {
 }
 
 
-static void vala_field_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaField * self;
-	self = VALA_FIELD (object);
-	switch (property_id) {
-		case VALA_FIELD_TYPE_REFERENCE:
-		g_value_set_object (value, vala_field_get_type_reference (self));
-		break;
-		case VALA_FIELD_INITIALIZER:
-		g_value_set_object (value, vala_field_get_initializer (self));
-		break;
-		case VALA_FIELD_BINDING:
-		g_value_set_enum (value, vala_field_get_binding (self));
-		break;
-		case VALA_FIELD_IS_VOLATILE:
-		g_value_set_boolean (value, vala_field_get_is_volatile (self));
-		break;
-		case VALA_FIELD_NO_ARRAY_LENGTH:
-		g_value_set_boolean (value, vala_field_get_no_array_length (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_field_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaField * self;
-	self = VALA_FIELD (object);
-	switch (property_id) {
-		case VALA_FIELD_TYPE_REFERENCE:
-		vala_field_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_FIELD_INITIALIZER:
-		vala_field_set_initializer (self, g_value_get_object (value));
-		break;
-		case VALA_FIELD_BINDING:
-		vala_field_set_binding (self, g_value_get_enum (value));
-		break;
-		case VALA_FIELD_IS_VOLATILE:
-		vala_field_set_is_volatile (self, g_value_get_boolean (value));
-		break;
-		case VALA_FIELD_NO_ARRAY_LENGTH:
-		vala_field_set_no_array_length (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_field_class_init (ValaFieldClass * klass) {
 	vala_field_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_field_finalize;
 	g_type_class_add_private (klass, sizeof (ValaFieldPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_field_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_field_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_field_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_field_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_IS_VOLATILE, g_param_spec_boolean ("is-volatile", "is-volatile", "is-volatile", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -397,27 +386,27 @@ static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface)
 }
 
 
-static void vala_field_init (ValaField * self) {
+static void vala_field_instance_init (ValaField * self) {
 	self->priv = VALA_FIELD_GET_PRIVATE (self);
 	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->lock_used = FALSE;
 }
 
 
-static void vala_field_dispose (GObject * obj) {
+static void vala_field_finalize (ValaCodeNode* obj) {
 	ValaField * self;
 	self = VALA_FIELD (obj);
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_field_parent_class)->dispose (obj);
+	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_field_parent_class)->finalize (obj);
 }
 
 
 GType vala_field_get_type (void) {
 	static GType vala_field_type_id = 0;
-	if (G_UNLIKELY (vala_field_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_init };
+	if (vala_field_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_instance_init, NULL };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_field_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_field_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaField", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_field_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
@@ -431,12 +420,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
