@@ -25,6 +25,7 @@
 #include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 
 
@@ -42,21 +43,14 @@ struct _ValaForeachStatementPrivate {
 
 #define VALA_FOREACH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatementPrivate))
 enum  {
-	VALA_FOREACH_STATEMENT_DUMMY_PROPERTY,
-	VALA_FOREACH_STATEMENT_TYPE_REFERENCE,
-	VALA_FOREACH_STATEMENT_VARIABLE_NAME,
-	VALA_FOREACH_STATEMENT_COLLECTION,
-	VALA_FOREACH_STATEMENT_BODY,
-	VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE,
-	VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE,
-	VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE
+	VALA_FOREACH_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_foreach_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_foreach_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static void vala_foreach_statement_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_foreach_statement_parent_class = NULL;
-static void vala_foreach_statement_finalize (GObject * obj);
+static void vala_foreach_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -69,38 +63,29 @@ static void vala_foreach_statement_finalize (GObject * obj);
  * @param source reference to source code
  * @return       newly created foreach statement
  */
-ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaForeachStatement * self;
+ValaForeachStatement* vala_foreach_statement_construct (GType object_type, ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference) {
+	ValaForeachStatement* self;
 	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (variable_name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (collection), NULL);
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	__params_it->name = "variable-name";
-	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, variable_name);
-	__params_it++;
-	__params_it->name = "collection";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, collection);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_FOREACH_STATEMENT, __params_it - __params, __params);
+	self = ((ValaForeachStatement*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_BLOCK (self)));
+	vala_foreach_statement_set_variable_name (self, variable_name);
+	vala_foreach_statement_set_collection (self, collection);
 	vala_foreach_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_foreach_statement_set_type_reference (self, type_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference) {
+	return vala_foreach_statement_construct (VALA_TYPE_FOREACH_STATEMENT, type_reference, variable_name, collection, body, source_reference);
+}
+
+
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
@@ -156,11 +141,10 @@ void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, Vala
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	if (self->priv->_data_type != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 	}
-	g_object_notify (((GObject *) (self)), "type-reference");
 }
 
 
@@ -177,7 +161,6 @@ void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_variable_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "variable-name");
 }
 
 
@@ -193,9 +176,8 @@ void vala_foreach_statement_set_collection (ValaForeachStatement* self, ValaExpr
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_collection = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), _tmp2);
+	self->priv->_collection = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (vala_code_node_unref (self->priv->_collection), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_collection), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "collection");
 }
 
 
@@ -211,9 +193,8 @@ void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaBlock* val
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "body");
 }
 
 
@@ -229,8 +210,7 @@ void vala_foreach_statement_set_element_variable (ValaForeachStatement* self, Va
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_element_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (g_object_unref (self->priv->_element_variable), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "element-variable");
+	self->priv->_element_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (vala_code_node_unref (self->priv->_element_variable), NULL))), _tmp2);
 }
 
 
@@ -246,8 +226,7 @@ void vala_foreach_statement_set_collection_variable (ValaForeachStatement* self,
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_collection_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (g_object_unref (self->priv->_collection_variable), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "collection-variable");
+	self->priv->_collection_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (vala_code_node_unref (self->priv->_collection_variable), NULL))), _tmp2);
 }
 
 
@@ -263,92 +242,18 @@ void vala_foreach_statement_set_iterator_variable (ValaForeachStatement* self, V
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_iterator_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (g_object_unref (self->priv->_iterator_variable), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "iterator-variable");
-}
-
-
-static void vala_foreach_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaForeachStatement * self;
-	self = VALA_FOREACH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_FOREACH_STATEMENT_TYPE_REFERENCE:
-		g_value_set_object (value, vala_foreach_statement_get_type_reference (self));
-		break;
-		case VALA_FOREACH_STATEMENT_VARIABLE_NAME:
-		g_value_set_string (value, vala_foreach_statement_get_variable_name (self));
-		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION:
-		g_value_set_object (value, vala_foreach_statement_get_collection (self));
-		break;
-		case VALA_FOREACH_STATEMENT_BODY:
-		g_value_set_object (value, vala_foreach_statement_get_body (self));
-		break;
-		case VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE:
-		g_value_set_object (value, vala_foreach_statement_get_element_variable (self));
-		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE:
-		g_value_set_object (value, vala_foreach_statement_get_collection_variable (self));
-		break;
-		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE:
-		g_value_set_object (value, vala_foreach_statement_get_iterator_variable (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_foreach_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaForeachStatement * self;
-	self = VALA_FOREACH_STATEMENT (object);
-	switch (property_id) {
-		case VALA_FOREACH_STATEMENT_TYPE_REFERENCE:
-		vala_foreach_statement_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_FOREACH_STATEMENT_VARIABLE_NAME:
-		vala_foreach_statement_set_variable_name (self, g_value_get_string (value));
-		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION:
-		vala_foreach_statement_set_collection (self, g_value_get_object (value));
-		break;
-		case VALA_FOREACH_STATEMENT_BODY:
-		vala_foreach_statement_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE:
-		vala_foreach_statement_set_element_variable (self, g_value_get_object (value));
-		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE:
-		vala_foreach_statement_set_collection_variable (self, g_value_get_object (value));
-		break;
-		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE:
-		vala_foreach_statement_set_iterator_variable (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_iterator_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (vala_code_node_unref (self->priv->_iterator_variable), NULL))), _tmp2);
 }
 
 
 static void vala_foreach_statement_class_init (ValaForeachStatementClass * klass) {
 	vala_foreach_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_foreach_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaForeachStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_foreach_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_foreach_statement_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_foreach_statement_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_foreach_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_foreach_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_foreach_statement_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_foreach_statement_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_VARIABLE_NAME, g_param_spec_string ("variable-name", "variable-name", "variable-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION, g_param_spec_object ("collection", "collection", "collection", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE, g_param_spec_object ("element-variable", "element-variable", "element-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE, g_param_spec_object ("collection-variable", "collection-variable", "collection-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE, g_param_spec_object ("iterator-variable", "iterator-variable", "iterator-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -357,24 +262,24 @@ static void vala_foreach_statement_instance_init (ValaForeachStatement * self) {
 }
 
 
-static void vala_foreach_statement_finalize (GObject * obj) {
+static void vala_foreach_statement_finalize (ValaCodeNode* obj) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (obj);
 	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
-	(self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (g_object_unref (self->priv->_element_variable), NULL)));
-	(self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (g_object_unref (self->priv->_collection_variable), NULL)));
-	(self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (g_object_unref (self->priv->_iterator_variable), NULL)));
-	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_foreach_statement_parent_class)->finalize (obj);
+	(self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (vala_code_node_unref (self->priv->_element_variable), NULL)));
+	(self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (vala_code_node_unref (self->priv->_collection_variable), NULL)));
+	(self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (vala_code_node_unref (self->priv->_iterator_variable), NULL)));
+	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (vala_code_node_unref (self->priv->_collection), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_foreach_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_foreach_statement_get_type (void) {
 	static GType vala_foreach_statement_type_id = 0;
 	if (vala_foreach_statement_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaForeachStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_foreach_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForeachStatement), 0, (GInstanceInitFunc) vala_foreach_statement_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaForeachStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_foreach_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForeachStatement), 0, (GInstanceInitFunc) vala_foreach_statement_instance_init, NULL };
 		vala_foreach_statement_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaForeachStatement", &g_define_type_info, 0);
 	}
 	return vala_foreach_statement_type_id;
