@@ -40,29 +40,20 @@ struct _ValaFormalParameterPrivate {
 	double _cparameter_position;
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
+	char* _ctype;
 	ValaDataType* _data_type;
 };
 
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
-	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY,
-	VALA_FORMAL_PARAMETER_TYPE_REFERENCE,
-	VALA_FORMAL_PARAMETER_DIRECTION,
-	VALA_FORMAL_PARAMETER_ELLIPSIS,
-	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
-	VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH,
-	VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER,
-	VALA_FORMAL_PARAMETER_CPARAMETER_POSITION,
-	VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION,
-	VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION
+	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a);
-static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
-static void vala_formal_parameter_dispose (GObject * obj);
+static void vala_formal_parameter_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -75,33 +66,47 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source reference to source code
  * @return       newly created formal parameter
  */
-ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source) {
-	ValaFormalParameter * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), _name);
-	vala_formal_parameter_set_type_reference (self, type);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+ValaFormalParameter* vala_formal_parameter_construct (GType object_type, const char* name, ValaDataType* parameter_type, ValaSourceReference* source_reference) {
+	ValaFormalParameter* self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (parameter_type), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = ((ValaFormalParameter*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (self));
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_formal_parameter_set_parameter_type (self, parameter_type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	return self;
 }
 
 
+ValaFormalParameter* vala_formal_parameter_new (const char* name, ValaDataType* parameter_type, ValaSourceReference* source_reference) {
+	return vala_formal_parameter_construct (VALA_TYPE_FORMAL_PARAMETER, name, parameter_type, source_reference);
+}
+
+
 /**
  * Creates a new ellipsis parameter representing an indefinite number of
  * parameters.
  */
-ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source) {
-	ValaFormalParameter * self;
+ValaFormalParameter* vala_formal_parameter_construct_with_ellipsis (GType object_type, ValaSourceReference* source) {
+	ValaFormalParameter* self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
+	self = ((ValaFormalParameter*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (self));
 	vala_formal_parameter_set_ellipsis (self, TRUE);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	return self;
 }
 
 
+ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source) {
+	return vala_formal_parameter_construct_with_ellipsis (VALA_TYPE_FORMAL_PARAMETER, source);
+}
+
+
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
@@ -115,7 +120,7 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (!self->priv->_ellipsis) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
+		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_parameter_type (self)), visitor);
 		if (self->priv->_default_expression != NULL) {
 			vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 		}
@@ -128,8 +133,8 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
 	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
-	if (vala_formal_parameter_get_type_reference (self) == old_type) {
-		vala_formal_parameter_set_type_reference (self, new_type);
+	if (vala_formal_parameter_get_parameter_type (self) == old_type) {
+		vala_formal_parameter_set_parameter_type (self, new_type);
 	}
 }
 
@@ -137,6 +142,12 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
+	if (vala_attribute_has_argument (a, "type")) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_formal_parameter_set_ctype (self, (_tmp0 = vala_attribute_get_string (a, "type")));
+		_tmp0 = (g_free (_tmp0), NULL);
+	}
 	if (vala_attribute_has_argument (a, "array_length_pos")) {
 		vala_formal_parameter_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
 	}
@@ -159,12 +170,12 @@ void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_formal_parameter_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -175,7 +186,7 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	if (!self->priv->_ellipsis) {
 		ValaFormalParameter* result;
-		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_type_reference (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_parameter_type (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 		return result;
 	} else {
 		return vala_formal_parameter_new_with_ellipsis (NULL);
@@ -183,19 +194,19 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 }
 
 
-ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
+ValaDataType* vala_formal_parameter_get_parameter_type (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDataType* value) {
+void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
@@ -236,7 +247,7 @@ void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, Va
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL))), _tmp2);
 }
 
 
@@ -300,139 +311,52 @@ void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalPa
 }
 
 
-static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaFormalParameterClass * klass;
-	GObjectClass * parent_class;
-	ValaFormalParameter * self;
-	klass = VALA_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_FORMAL_PARAMETER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_FORMAL_PARAMETER (obj);
-	{
-		vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-	}
-	return obj;
+const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
+	return self->priv->_ctype;
 }
 
 
-static void vala_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaFormalParameter * self;
-	self = VALA_FORMAL_PARAMETER (object);
-	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
-		g_value_set_object (value, vala_formal_parameter_get_type_reference (self));
-		break;
-		case VALA_FORMAL_PARAMETER_DIRECTION:
-		g_value_set_enum (value, vala_formal_parameter_get_direction (self));
-		break;
-		case VALA_FORMAL_PARAMETER_ELLIPSIS:
-		g_value_set_boolean (value, vala_formal_parameter_get_ellipsis (self));
-		break;
-		case VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION:
-		g_value_set_object (value, vala_formal_parameter_get_default_expression (self));
-		break;
-		case VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH:
-		g_value_set_boolean (value, vala_formal_parameter_get_no_array_length (self));
-		break;
-		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
-		g_value_set_boolean (value, vala_formal_parameter_get_construct_parameter (self));
-		break;
-		case VALA_FORMAL_PARAMETER_CPARAMETER_POSITION:
-		g_value_set_double (value, vala_formal_parameter_get_cparameter_position (self));
-		break;
-		case VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION:
-		g_value_set_double (value, vala_formal_parameter_get_carray_length_parameter_position (self));
-		break;
-		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
-		g_value_set_double (value, vala_formal_parameter_get_cdelegate_target_parameter_position (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_formal_parameter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaFormalParameter * self;
-	self = VALA_FORMAL_PARAMETER (object);
-	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
-		vala_formal_parameter_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_FORMAL_PARAMETER_DIRECTION:
-		vala_formal_parameter_set_direction (self, g_value_get_enum (value));
-		break;
-		case VALA_FORMAL_PARAMETER_ELLIPSIS:
-		vala_formal_parameter_set_ellipsis (self, g_value_get_boolean (value));
-		break;
-		case VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION:
-		vala_formal_parameter_set_default_expression (self, g_value_get_object (value));
-		break;
-		case VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH:
-		vala_formal_parameter_set_no_array_length (self, g_value_get_boolean (value));
-		break;
-		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
-		vala_formal_parameter_set_construct_parameter (self, g_value_get_boolean (value));
-		break;
-		case VALA_FORMAL_PARAMETER_CPARAMETER_POSITION:
-		vala_formal_parameter_set_cparameter_position (self, g_value_get_double (value));
-		break;
-		case VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION:
-		vala_formal_parameter_set_carray_length_parameter_position (self, g_value_get_double (value));
-		break;
-		case VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION:
-		vala_formal_parameter_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_ctype = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_ctype = (g_free (self->priv->_ctype), NULL)), _tmp2);
 }
 
 
 static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass) {
 	vala_formal_parameter_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_formal_parameter_finalize;
 	g_type_class_add_private (klass, sizeof (ValaFormalParameterPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_formal_parameter_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_formal_parameter_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_formal_parameter_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DIRECTION, g_param_spec_enum ("direction", "direction", "direction", VALA_TYPE_PARAMETER_DIRECTION, VALA_PARAMETER_DIRECTION_IN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "ellipsis", "ellipsis", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER, g_param_spec_boolean ("construct-parameter", "construct-parameter", "construct-parameter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CPARAMETER_POSITION, g_param_spec_double ("cparameter-position", "cparameter-position", "cparameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_formal_parameter_init (ValaFormalParameter * self) {
+static void vala_formal_parameter_instance_init (ValaFormalParameter * self) {
 	self->priv = VALA_FORMAL_PARAMETER_GET_PRIVATE (self);
 	self->priv->_direction = VALA_PARAMETER_DIRECTION_IN;
 }
 
 
-static void vala_formal_parameter_dispose (GObject * obj) {
+static void vala_formal_parameter_finalize (ValaCodeNode* obj) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_formal_parameter_parent_class)->dispose (obj);
+	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)));
+	self->priv->_ctype = (g_free (self->priv->_ctype), NULL);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_formal_parameter_parent_class)->finalize (obj);
 }
 
 
 GType vala_formal_parameter_get_type (void) {
 	static GType vala_formal_parameter_type_id = 0;
-	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_init };
+	if (vala_formal_parameter_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_instance_init, NULL };
 		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
 	}
 	return vala_formal_parameter_type_id;
