@@ -22,8 +22,8 @@
 
 #include <vala/valaforstatement.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valaexpression.h>
 #include <vala/valablock.h>
 #include <vala/valasourcereference.h>
@@ -41,16 +41,14 @@ struct _ValaForStatementPrivate {
 
 #define VALA_FOR_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FOR_STATEMENT, ValaForStatementPrivate))
 enum  {
-	VALA_FOR_STATEMENT_DUMMY_PROPERTY,
-	VALA_FOR_STATEMENT_CONDITION,
-	VALA_FOR_STATEMENT_BODY
+	VALA_FOR_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_for_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gpointer vala_for_statement_parent_class = NULL;
 static ValaStatementIface* vala_for_statement_vala_statement_parent_iface = NULL;
-static void vala_for_statement_dispose (GObject * obj);
+static void vala_for_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -62,31 +60,24 @@ static void vala_for_statement_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created for statement
  */
-ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaForStatement * self;
+ValaForStatement* vala_for_statement_construct (GType object_type, ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
+	ValaForStatement* self;
 	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "condition";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, condition);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_FOR_STATEMENT, __params_it - __params, __params);
+	self = ((ValaForStatement*) (g_type_create_instance (object_type)));
+	vala_for_statement_set_condition (self, condition);
 	vala_for_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
+ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
+	return vala_for_statement_construct (VALA_TYPE_FOR_STATEMENT, condition, body, source_reference);
+}
+
+
 /**
  * Appends the specified expression to the list of initializers.
  *
@@ -105,9 +96,9 @@ void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression*
  *
  * @return initializer list
  */
-GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self) {
+GeeList* vala_for_statement_get_initializer (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->initializer)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->initializer));
 }
 
 
@@ -129,9 +120,9 @@ void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* it
  *
  * @return iterator
  */
-GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self) {
+GeeList* vala_for_statement_get_iterator (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->iterator)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->iterator));
 }
 
 
@@ -149,19 +140,17 @@ static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCod
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* init_expr_collection;
-		GeeIterator* init_expr_it;
+		int init_expr_it;
 		init_expr_collection = self->priv->initializer;
-		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
-		while (gee_iterator_next (init_expr_it)) {
+		for (init_expr_it = 0; init_expr_it < gee_collection_get_size (GEE_COLLECTION (init_expr_collection)); init_expr_it = init_expr_it + 1) {
 			ValaExpression* init_expr;
-			init_expr = ((ValaExpression*) gee_iterator_get (init_expr_it));
+			init_expr = ((ValaExpression*) (gee_list_get (GEE_LIST (init_expr_collection), init_expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (init_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, init_expr);
-				(init_expr == NULL ? NULL : (init_expr = (g_object_unref (init_expr), NULL)));
+				(init_expr == NULL ? NULL : (init_expr = (vala_code_node_unref (init_expr), NULL)));
 			}
 		}
-		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
 	if (vala_for_statement_get_condition (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_condition (self)), visitor);
@@ -169,19 +158,17 @@ static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCod
 	}
 	{
 		GeeList* it_expr_collection;
-		GeeIterator* it_expr_it;
+		int it_expr_it;
 		it_expr_collection = self->priv->iterator;
-		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
-		while (gee_iterator_next (it_expr_it)) {
+		for (it_expr_it = 0; it_expr_it < gee_collection_get_size (GEE_COLLECTION (it_expr_collection)); it_expr_it = it_expr_it + 1) {
 			ValaExpression* it_expr;
-			it_expr = ((ValaExpression*) gee_iterator_get (it_expr_it));
+			it_expr = ((ValaExpression*) (gee_list_get (GEE_LIST (it_expr_collection), it_expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (it_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, it_expr);
-				(it_expr == NULL ? NULL : (it_expr = (g_object_unref (it_expr), NULL)));
+				(it_expr == NULL ? NULL : (it_expr = (vala_code_node_unref (it_expr), NULL)));
 			}
 		}
-		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_body (self)), visitor);
 }
@@ -203,8 +190,8 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaExpression*) gee_list_get (((GeeList*) self->priv->initializer), i))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
-				gee_list_set (((GeeList*) self->priv->initializer), i, new_node);
+			if ((_tmp1 = (_tmp0 = ((ValaExpression*) (gee_list_get (((GeeList*) (self->priv->initializer)), i)))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
+				gee_list_set (((GeeList*) (self->priv->initializer)), i, new_node);
 				return;
 			}
 		}
@@ -216,8 +203,8 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 			ValaExpression* _tmp2;
 			gboolean _tmp3;
 			_tmp2 = NULL;
-			if ((_tmp3 = (_tmp2 = ((ValaExpression*) gee_list_get (((GeeList*) self->priv->iterator), i))) == old_node, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
-				gee_list_set (((GeeList*) self->priv->iterator), i, new_node);
+			if ((_tmp3 = (_tmp2 = ((ValaExpression*) (gee_list_get (((GeeList*) (self->priv->iterator)), i)))) == old_node, (_tmp2 == NULL ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL))), _tmp3)) {
+				gee_list_set (((GeeList*) (self->priv->iterator)), i, new_node);
 				return;
 			}
 		}
@@ -237,7 +224,7 @@ void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* v
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL))), _tmp2);
 	if (self->priv->_condition != NULL) {
 		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 	}
@@ -256,56 +243,18 @@ void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value) {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
 }
 
 
-static void vala_for_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaForStatement * self;
-	self = VALA_FOR_STATEMENT (object);
-	switch (property_id) {
-		case VALA_FOR_STATEMENT_CONDITION:
-		g_value_set_object (value, vala_for_statement_get_condition (self));
-		break;
-		case VALA_FOR_STATEMENT_BODY:
-		g_value_set_object (value, vala_for_statement_get_body (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_for_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaForStatement * self;
-	self = VALA_FOR_STATEMENT (object);
-	switch (property_id) {
-		case VALA_FOR_STATEMENT_CONDITION:
-		vala_for_statement_set_condition (self, g_value_get_object (value));
-		break;
-		case VALA_FOR_STATEMENT_BODY:
-		vala_for_statement_set_body (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_for_statement_class_init (ValaForStatementClass * klass) {
 	vala_for_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_for_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaForStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_for_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_for_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_for_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_for_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_for_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_for_statement_real_replace_expression;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -314,28 +263,28 @@ static void vala_for_statement_vala_statement_interface_init (ValaStatementIface
 }
 
 
-static void vala_for_statement_init (ValaForStatement * self) {
+static void vala_for_statement_instance_init (ValaForStatement * self) {
 	self->priv = VALA_FOR_STATEMENT_GET_PRIVATE (self);
-	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_for_statement_dispose (GObject * obj) {
+static void vala_for_statement_finalize (ValaCodeNode* obj) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (obj);
-	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_object_unref (self->priv->initializer), NULL)));
-	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_object_unref (self->priv->iterator), NULL)));
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	G_OBJECT_CLASS (vala_for_statement_parent_class)->dispose (obj);
+	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (gee_collection_object_unref (self->priv->initializer), NULL)));
+	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (gee_collection_object_unref (self->priv->iterator), NULL)));
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	VALA_CODE_NODE_CLASS (vala_for_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_for_statement_get_type (void) {
 	static GType vala_for_statement_type_id = 0;
-	if (G_UNLIKELY (vala_for_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForStatement), 0, (GInstanceInitFunc) vala_for_statement_init };
+	if (vala_for_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForStatement), 0, (GInstanceInitFunc) vala_for_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_for_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_for_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaForStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_for_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
