@@ -24,6 +24,7 @@
 #include <vala/valageniescanner.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -46,9 +47,7 @@ struct _ValaGenieScannerPrivate {
 
 #define VALA_GENIE_SCANNER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_GENIE_TYPE_SCANNER, ValaGenieScannerPrivate))
 enum  {
-	VALA_GENIE_SCANNER_DUMMY_PROPERTY,
-	VALA_GENIE_SCANNER_SOURCE_FILE,
-	VALA_GENIE_SCANNER_INDENT_SPACES
+	VALA_GENIE_SCANNER_DUMMY_PROPERTY
 };
 static gboolean vala_genie_scanner_is_ident_char (ValaGenieScanner* self, gchar c);
 static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGenieScanner* self, gchar* begin, gint len);
@@ -58,33 +57,38 @@ static gboolean vala_genie_scanner_whitespace (ValaGenieScanner* self);
 static inline gboolean vala_genie_scanner_newline (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_skip_newlines (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_comment (ValaGenieScanner* self);
+static gboolean vala_genie_scanner_skip_tabs (ValaGenieScanner* self);
+static void vala_genie_scanner_skip_space_tabs (ValaGenieScanner* self);
 static void vala_genie_scanner_space (ValaGenieScanner* self);
 static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, gboolean file_comment);
 static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSourceFile* value);
-static GObject * vala_genie_scanner_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_genie_scanner_parent_class = NULL;
-static void vala_genie_scanner_dispose (GObject * obj);
+static void vala_genie_scanner_finalize (ValaGenieScanner* obj);
 
 
 
+ValaGenieScanner* vala_genie_scanner_construct (GType object_type, ValaSourceFile* source_file) {
+	ValaGenieScanner* self;
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (source_file), NULL);
+	self = ((ValaGenieScanner*) (g_type_create_instance (object_type)));
+	vala_genie_scanner_set_source_file (self, source_file);
+	self->priv->begin = vala_source_file_get_mapped_contents (source_file);
+	self->priv->end = self->priv->begin + vala_source_file_get_mapped_length (source_file);
+	self->priv->current = self->priv->begin;
+	self->priv->_indent_spaces = 0;
+	self->priv->line = 1;
+	self->priv->column = 1;
+	self->priv->current_indent_level = 0;
+	self->priv->indent_level = 0;
+	self->priv->pending_dedents = 0;
+	self->priv->parse_started = FALSE;
+	self->priv->last_token = VALA_GENIE_TOKEN_TYPE_NONE;
+	return self;
+}
+
+
 ValaGenieScanner* vala_genie_scanner_new (ValaSourceFile* source_file) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaGenieScanner * self;
-	g_return_val_if_fail (VALA_IS_SOURCE_FILE (source_file), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "source-file";
-	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, source_file);
-	__params_it++;
-	self = g_object_newv (VALA_GENIE_TYPE_SCANNER, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_genie_scanner_construct (VALA_GENIE_TYPE_SCANNER, source_file);
 }
 
 
@@ -95,10 +99,10 @@ static gboolean vala_genie_scanner_is_ident_char (ValaGenieScanner* self, gchar
 
 
 static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGenieScanner* self, gchar* begin, gint len) {
-	gint _tmp104;
+	gint _tmp107;
 	g_return_val_if_fail (VALA_GENIE_IS_SCANNER (self), 0);
-	_tmp104 = len;
-	if (_tmp104 == 2)
+	_tmp107 = len;
+	if (_tmp107 == 2)
 	do {
 		gchar _tmp9;
 		_tmp9 = begin[0];
@@ -146,7 +150,7 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 3)
+	} while (0); else if (_tmp107 == 3)
 	do {
 		gchar _tmp23;
 		_tmp23 = begin[0];
@@ -230,27 +234,33 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 4)
+	} while (0); else if (_tmp107 == 4)
 	do {
-		gchar _tmp41;
-		_tmp41 = begin[0];
-		if (_tmp41 == 'c')
+		gchar _tmp44;
+		_tmp44 = begin[0];
+		if (_tmp44 == 'c')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "case")) {
 				return VALA_GENIE_TOKEN_TYPE_CASE;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'e')
+		} while (0); else if (_tmp44 == 'd')
 		do {
-			gchar _tmp27;
-			_tmp27 = begin[1];
-			if (_tmp27 == 'l')
+			if (vala_genie_scanner_matches (self, begin, "dict")) {
+				return VALA_GENIE_TOKEN_TYPE_DICT;
+			}
+			break;
+		} while (0); else if (_tmp44 == 'e')
+		do {
+			gchar _tmp28;
+			_tmp28 = begin[1];
+			if (_tmp28 == 'l')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "else")) {
 					return VALA_GENIE_TOKEN_TYPE_ELSE;
 				}
 				break;
-			} while (0); else if (_tmp27 == 'n')
+			} while (0); else if (_tmp28 == 'n')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "enum")) {
 					return VALA_GENIE_TOKEN_TYPE_ENUM;
@@ -258,35 +268,47 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp41 == 'i')
+		} while (0); else if (_tmp44 == 'i')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "init")) {
 				return VALA_GENIE_TOKEN_TYPE_INIT;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'l')
+		} while (0); else if (_tmp44 == 'l')
 		do {
-			if (vala_genie_scanner_matches (self, begin, "lock")) {
-				return VALA_GENIE_TOKEN_TYPE_LOCK;
-			}
+			gchar _tmp32;
+			_tmp32 = begin[1];
+			if (_tmp32 == 'i')
+			do {
+				if (vala_genie_scanner_matches (self, begin, "list")) {
+					return VALA_GENIE_TOKEN_TYPE_LIST;
+				}
+				break;
+			} while (0); else if (_tmp32 == 'o')
+			do {
+				if (vala_genie_scanner_matches (self, begin, "lock")) {
+					return VALA_GENIE_TOKEN_TYPE_LOCK;
+				}
+				break;
+			} while (0);
 			break;
-		} while (0); else if (_tmp41 == 'n')
+		} while (0); else if (_tmp44 == 'n')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "null")) {
 				return VALA_GENIE_TOKEN_TYPE_NULL;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'p')
+		} while (0); else if (_tmp44 == 'p')
 		do {
-			gchar _tmp33;
-			_tmp33 = begin[1];
-			if (_tmp33 == 'a')
+			gchar _tmp36;
+			_tmp36 = begin[1];
+			if (_tmp36 == 'a')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "pass")) {
 					return VALA_GENIE_TOKEN_TYPE_PASS;
 				}
 				break;
-			} while (0); else if (_tmp33 == 'r')
+			} while (0); else if (_tmp36 == 'r')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "prop")) {
 					return VALA_GENIE_TOKEN_TYPE_PROP;
@@ -294,41 +316,41 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp41 == 's')
+		} while (0); else if (_tmp44 == 's')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "self")) {
 				return VALA_GENIE_TOKEN_TYPE_THIS;
 			}
 			break;
-		} while (0); else if (_tmp41 == 't')
+		} while (0); else if (_tmp44 == 't')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "true")) {
 				return VALA_GENIE_TOKEN_TYPE_TRUE;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'u')
+		} while (0); else if (_tmp44 == 'u')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "uses")) {
 				return VALA_GENIE_TOKEN_TYPE_USES;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'v')
+		} while (0); else if (_tmp44 == 'v')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "void")) {
 				return VALA_GENIE_TOKEN_TYPE_VOID;
 			}
 			break;
-		} while (0); else if (_tmp41 == 'w')
+		} while (0); else if (_tmp44 == 'w')
 		do {
-			gchar _tmp40;
-			_tmp40 = begin[1];
-			if (_tmp40 == 'e')
+			gchar _tmp43;
+			_tmp43 = begin[1];
+			if (_tmp43 == 'e')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "weak")) {
 					return VALA_GENIE_TOKEN_TYPE_WEAK;
 				}
 				break;
-			} while (0); else if (_tmp40 == 'h')
+			} while (0); else if (_tmp43 == 'h')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "when")) {
 					return VALA_GENIE_TOKEN_TYPE_WHEN;
@@ -338,33 +360,33 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 5)
+	} while (0); else if (_tmp107 == 5)
 	do {
-		gchar _tmp55;
-		_tmp55 = begin[0];
-		if (_tmp55 == 'a')
+		gchar _tmp58;
+		_tmp58 = begin[0];
+		if (_tmp58 == 'a')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "array")) {
 				return VALA_GENIE_TOKEN_TYPE_ARRAY;
 			}
 			break;
-		} while (0); else if (_tmp55 == 'b')
+		} while (0); else if (_tmp58 == 'b')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "break")) {
 				return VALA_GENIE_TOKEN_TYPE_BREAK;
 			}
 			break;
-		} while (0); else if (_tmp55 == 'c')
+		} while (0); else if (_tmp58 == 'c')
 		do {
-			gchar _tmp46;
-			_tmp46 = begin[1];
-			if (_tmp46 == 'l')
+			gchar _tmp49;
+			_tmp49 = begin[1];
+			if (_tmp49 == 'l')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "class")) {
 					return VALA_GENIE_TOKEN_TYPE_CLASS;
 				}
 				break;
-			} while (0); else if (_tmp46 == 'o')
+			} while (0); else if (_tmp49 == 'o')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "const")) {
 					return VALA_GENIE_TOKEN_TYPE_CONST;
@@ -372,23 +394,23 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp55 == 'e')
+		} while (0); else if (_tmp58 == 'e')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "event")) {
 				return VALA_GENIE_TOKEN_TYPE_EVENT;
 			}
 			break;
-		} while (0); else if (_tmp55 == 'f')
+		} while (0); else if (_tmp58 == 'f')
 		do {
-			gchar _tmp50;
-			_tmp50 = begin[1];
-			if (_tmp50 == 'a')
+			gchar _tmp53;
+			_tmp53 = begin[1];
+			if (_tmp53 == 'a')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "false")) {
 					return VALA_GENIE_TOKEN_TYPE_FALSE;
 				}
 				break;
-			} while (0); else if (_tmp50 == 'i')
+			} while (0); else if (_tmp53 == 'i')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "final")) {
 					return VALA_GENIE_TOKEN_TYPE_FINAL;
@@ -396,25 +418,25 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp55 == 'p')
+		} while (0); else if (_tmp58 == 'p')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "print")) {
 				return VALA_GENIE_TOKEN_TYPE_PRINT;
 			}
 			break;
-		} while (0); else if (_tmp55 == 's')
+		} while (0); else if (_tmp58 == 's')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "super")) {
 				return VALA_GENIE_TOKEN_TYPE_SUPER;
 			}
 			break;
-		} while (0); else if (_tmp55 == 'r')
+		} while (0); else if (_tmp58 == 'r')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "raise")) {
 				return VALA_GENIE_TOKEN_TYPE_RAISE;
 			}
 			break;
-		} while (0); else if (_tmp55 == 'w')
+		} while (0); else if (_tmp58 == 'w')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "while")) {
 				return VALA_GENIE_TOKEN_TYPE_WHILE;
@@ -422,27 +444,27 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 6)
+	} while (0); else if (_tmp107 == 6)
 	do {
-		gchar _tmp75;
-		_tmp75 = begin[0];
-		if (_tmp75 == 'a')
+		gchar _tmp78;
+		_tmp78 = begin[0];
+		if (_tmp78 == 'a')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "assert")) {
 				return VALA_GENIE_TOKEN_TYPE_ASSERT;
 			}
 			break;
-		} while (0); else if (_tmp75 == 'd')
+		} while (0); else if (_tmp78 == 'd')
 		do {
-			gchar _tmp59;
-			_tmp59 = begin[1];
-			if (_tmp59 == 'e')
+			gchar _tmp62;
+			_tmp62 = begin[1];
+			if (_tmp62 == 'e')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "delete")) {
 					return VALA_GENIE_TOKEN_TYPE_DELETE;
 				}
 				break;
-			} while (0); else if (_tmp59 == 'o')
+			} while (0); else if (_tmp62 == 'o')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "downto")) {
 					return VALA_GENIE_TOKEN_TYPE_DOWNTO;
@@ -450,21 +472,21 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp75 == 'e')
+		} while (0); else if (_tmp78 == 'e')
 		do {
-			gchar _tmp63;
-			_tmp63 = begin[1];
-			if (_tmp63 == 'x')
+			gchar _tmp66;
+			_tmp66 = begin[1];
+			if (_tmp66 == 'x')
 			do {
-				gchar _tmp62;
-				_tmp62 = begin[2];
-				if (_tmp62 == 'c')
+				gchar _tmp65;
+				_tmp65 = begin[2];
+				if (_tmp65 == 'c')
 				do {
 					if (vala_genie_scanner_matches (self, begin, "except")) {
 						return VALA_GENIE_TOKEN_TYPE_EXCEPT;
 					}
 					break;
-				} while (0); else if (_tmp62 == 't')
+				} while (0); else if (_tmp65 == 't')
 				do {
 					if (vala_genie_scanner_matches (self, begin, "extern")) {
 						return VALA_GENIE_TOKEN_TYPE_EXTERN;
@@ -474,29 +496,29 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp75 == 'i')
+		} while (0); else if (_tmp78 == 'i')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "inline")) {
 				return VALA_GENIE_TOKEN_TYPE_INLINE;
 			}
 			break;
-		} while (0); else if (_tmp75 == 'p')
+		} while (0); else if (_tmp78 == 'p')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "public")) {
 				return VALA_GENIE_TOKEN_TYPE_PUBLIC;
 			}
 			break;
-		} while (0); else if (_tmp75 == 'r')
+		} while (0); else if (_tmp78 == 'r')
 		do {
-			gchar _tmp68;
-			_tmp68 = begin[1];
-			if (_tmp68 == 'a')
+			gchar _tmp71;
+			_tmp71 = begin[1];
+			if (_tmp71 == 'a')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "raises")) {
 					return VALA_GENIE_TOKEN_TYPE_RAISES;
 				}
 				break;
-			} while (0); else if (_tmp68 == 'e')
+			} while (0); else if (_tmp71 == 'e')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "return")) {
 					return VALA_GENIE_TOKEN_TYPE_RETURN;
@@ -504,27 +526,27 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp75 == 's')
+		} while (0); else if (_tmp78 == 's')
 		do {
-			gchar _tmp73;
-			_tmp73 = begin[1];
-			if (_tmp73 == 'i')
+			gchar _tmp76;
+			_tmp76 = begin[1];
+			if (_tmp76 == 'i')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "sizeof")) {
 					return VALA_GENIE_TOKEN_TYPE_SIZEOF;
 				}
 				break;
-			} while (0); else if (_tmp73 == 't')
+			} while (0); else if (_tmp76 == 't')
 			do {
-				gchar _tmp72;
-				_tmp72 = begin[2];
-				if (_tmp72 == 'a')
+				gchar _tmp75;
+				_tmp75 = begin[2];
+				if (_tmp75 == 'a')
 				do {
 					if (vala_genie_scanner_matches (self, begin, "static")) {
 						return VALA_GENIE_TOKEN_TYPE_STATIC;
 					}
 					break;
-				} while (0); else if (_tmp72 == 'r')
+				} while (0); else if (_tmp75 == 'r')
 				do {
 					if (vala_genie_scanner_matches (self, begin, "struct")) {
 						return VALA_GENIE_TOKEN_TYPE_STRUCT;
@@ -534,7 +556,7 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp75 == 't')
+		} while (0); else if (_tmp78 == 't')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "typeof")) {
 				return VALA_GENIE_TOKEN_TYPE_TYPEOF;
@@ -542,21 +564,21 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 7)
+	} while (0); else if (_tmp107 == 7)
 	do {
-		gchar _tmp85;
-		_tmp85 = begin[0];
-		if (_tmp85 == 'd')
+		gchar _tmp88;
+		_tmp88 = begin[0];
+		if (_tmp88 == 'd')
 		do {
-			gchar _tmp78;
-			_tmp78 = begin[1];
-			if (_tmp78 == 'e')
+			gchar _tmp81;
+			_tmp81 = begin[1];
+			if (_tmp81 == 'e')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "default")) {
 					return VALA_GENIE_TOKEN_TYPE_DEFAULT;
 				}
 				break;
-			} while (0); else if (_tmp78 == 'y')
+			} while (0); else if (_tmp81 == 'y')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "dynamic")) {
 					return VALA_GENIE_TOKEN_TYPE_DYNAMIC;
@@ -564,23 +586,23 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp85 == 'e')
+		} while (0); else if (_tmp88 == 'e')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "ensures")) {
 				return VALA_GENIE_TOKEN_TYPE_ENSURES;
 			}
 			break;
-		} while (0); else if (_tmp85 == 'f')
+		} while (0); else if (_tmp88 == 'f')
 		do {
-			gchar _tmp82;
-			_tmp82 = begin[1];
-			if (_tmp82 == 'i')
+			gchar _tmp85;
+			_tmp85 = begin[1];
+			if (_tmp85 == 'i')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "finally")) {
 					return VALA_GENIE_TOKEN_TYPE_FINALLY;
 				}
 				break;
-			} while (0); else if (_tmp82 == 'o')
+			} while (0); else if (_tmp85 == 'o')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "foreach")) {
 					return VALA_GENIE_TOKEN_TYPE_FOREACH;
@@ -588,13 +610,13 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp85 == 'p')
+		} while (0); else if (_tmp88 == 'p')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "private")) {
 				return VALA_GENIE_TOKEN_TYPE_PRIVATE;
 			}
 			break;
-		} while (0); else if (_tmp85 == 'v')
+		} while (0); else if (_tmp88 == 'v')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "virtual")) {
 				return VALA_GENIE_TOKEN_TYPE_VIRTUAL;
@@ -602,45 +624,45 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 8)
+	} while (0); else if (_tmp107 == 8)
 	do {
-		gchar _tmp94;
-		_tmp94 = begin[0];
-		if (_tmp94 == 'a')
+		gchar _tmp97;
+		_tmp97 = begin[0];
+		if (_tmp97 == 'a')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "abstract")) {
 				return VALA_GENIE_TOKEN_TYPE_ABSTRACT;
 			}
 			break;
-		} while (0); else if (_tmp94 == 'c')
+		} while (0); else if (_tmp97 == 'c')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "continue")) {
 				return VALA_GENIE_TOKEN_TYPE_CONTINUE;
 			}
 			break;
-		} while (0); else if (_tmp94 == 'd')
+		} while (0); else if (_tmp97 == 'd')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "delegate")) {
 				return VALA_GENIE_TOKEN_TYPE_DELEGATE;
 			}
 			break;
-		} while (0); else if (_tmp94 == 'o')
+		} while (0); else if (_tmp97 == 'o')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "override")) {
 				return VALA_GENIE_TOKEN_TYPE_OVERRIDE;
 			}
 			break;
-		} while (0); else if (_tmp94 == 'r')
+		} while (0); else if (_tmp97 == 'r')
 		do {
-			gchar _tmp92;
-			_tmp92 = begin[2];
-			if (_tmp92 == 'a')
+			gchar _tmp95;
+			_tmp95 = begin[2];
+			if (_tmp95 == 'a')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "readonly")) {
 					return VALA_GENIE_TOKEN_TYPE_READONLY;
 				}
 				break;
-			} while (0); else if (_tmp92 == 'q')
+			} while (0); else if (_tmp95 == 'q')
 			do {
 				if (vala_genie_scanner_matches (self, begin, "requires")) {
 					return VALA_GENIE_TOKEN_TYPE_REQUIRES;
@@ -648,7 +670,7 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 				break;
 			} while (0);
 			break;
-		} while (0); else if (_tmp94 == 'v')
+		} while (0); else if (_tmp97 == 'v')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "volatile")) {
 				return VALA_GENIE_TOKEN_TYPE_VOLATILE;
@@ -656,41 +678,41 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 9)
+	} while (0); else if (_tmp107 == 9)
 	do {
-		gchar _tmp101;
-		_tmp101 = begin[0];
-		if (_tmp101 == 'c')
+		gchar _tmp104;
+		_tmp104 = begin[0];
+		if (_tmp104 == 'c')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "construct")) {
 				return VALA_GENIE_TOKEN_TYPE_CONSTRUCT;
 			}
 			break;
-		} while (0); else if (_tmp101 == 'e')
+		} while (0); else if (_tmp104 == 'e')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "exception")) {
 				return VALA_GENIE_TOKEN_TYPE_ERRORDOMAIN;
 			}
 			break;
-		} while (0); else if (_tmp101 == 'i')
+		} while (0); else if (_tmp104 == 'i')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "interface")) {
 				return VALA_GENIE_TOKEN_TYPE_INTERFACE;
 			}
 			break;
-		} while (0); else if (_tmp101 == 'n')
+		} while (0); else if (_tmp104 == 'n')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "namespace")) {
 				return VALA_GENIE_TOKEN_TYPE_NAMESPACE;
 			}
 			break;
-		} while (0); else if (_tmp101 == 'p')
+		} while (0); else if (_tmp104 == 'p')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "protected")) {
 				return VALA_GENIE_TOKEN_TYPE_PROTECTED;
 			}
 			break;
-		} while (0); else if (_tmp101 == 'w')
+		} while (0); else if (_tmp104 == 'w')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "writeonly")) {
 				return VALA_GENIE_TOKEN_TYPE_WRITEONLY;
@@ -698,11 +720,11 @@ static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGeni
 			break;
 		} while (0);
 		break;
-	} while (0); else if (_tmp104 == 10)
+	} while (0); else if (_tmp107 == 10)
 	do {
-		gchar _tmp103;
-		_tmp103 = begin[0];
-		if (_tmp103 == 'i')
+		gchar _tmp106;
+		_tmp106 = begin[0];
+		if (_tmp106 == 'i')
 		do {
 			if (vala_genie_scanner_matches (self, begin, "implements")) {
 				return VALA_GENIE_TOKEN_TYPE_IMPLEMENTS;
@@ -739,6 +761,8 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 	}
 	while (self->priv->current < self->priv->end && self->priv->current[0] == '\\' && self->priv->current[1] == '\n') {
 		self->priv->current = self->priv->current + (2);
+		self->priv->line++;
+		vala_genie_scanner_skip_space_tabs (self);
 	}
 	/* handle non-consecutive new line once parsing is underway - EOL */
 	if (vala_genie_scanner_newline (self) && self->priv->parse_started && self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL && self->priv->last_token != VALA_GENIE_TOKEN_TYPE_SEMICOLON) {
@@ -841,7 +865,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 								}
 							}
 						} else {
-							if (self->priv->current < self->priv->end && self->priv->current[0] == '.') {
+							if (self->priv->current < self->priv->end - 1 && self->priv->current[0] == '.' && g_ascii_isdigit (self->priv->current[1])) {
 								self->priv->current++;
 								while (self->priv->current < self->priv->end && g_ascii_isdigit (self->priv->current[0])) {
 									self->priv->current++;
@@ -1172,7 +1196,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										ValaSourceReference* _tmp10;
 										_tmp10 = NULL;
 										vala_report_error ((_tmp10 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), "invalid UTF-8 character");
-										(_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL)));
+										(_tmp10 == NULL ? NULL : (_tmp10 = (vala_source_reference_unref (_tmp10), NULL)));
 									}
 								}
 							}
@@ -1184,9 +1208,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 							ValaSourceReference* _tmp11;
 							_tmp12 = NULL;
 							_tmp11 = NULL;
-							vala_report_error ((_tmp11 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), (_tmp12 = g_strdup_printf ("syntax error, expected %c", begin[0])));
+							vala_report_error ((_tmp11 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), (_tmp12 = g_strdup_printf ("syntax error, expected %c", ((gint) (begin[0])))));
 							_tmp12 = (g_free (_tmp12), NULL);
-							(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
+							(_tmp11 == NULL ? NULL : (_tmp11 = (vala_source_reference_unref (_tmp11), NULL)));
 						}
 						break;
 					} while (0); else
@@ -1198,13 +1222,13 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 							self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
 							_tmp13 = NULL;
 							vala_report_error ((_tmp13 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "syntax error, unexpected character");
-							(_tmp13 == NULL ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL)));
+							(_tmp13 == NULL ? NULL : (_tmp13 = (vala_source_reference_unref (_tmp13), NULL)));
 						} else {
 							ValaSourceReference* _tmp14;
 							self->priv->current++;
 							_tmp14 = NULL;
 							vala_report_error ((_tmp14 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "invalid UTF-8 character");
-							(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
+							(_tmp14 == NULL ? NULL : (_tmp14 = (vala_source_reference_unref (_tmp14), NULL)));
 						}
 						self->priv->column++;
 						self->priv->last_token = VALA_GENIE_TOKEN_TYPE_STRING_LITERAL;
@@ -1356,7 +1380,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			ValaSourceReference* _tmp2;
 			_tmp2 = NULL;
 			vala_report_error ((_tmp2 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "syntax error, expected */");
-			(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+			(_tmp2 == NULL ? NULL : (_tmp2 = (vala_source_reference_unref (_tmp2), NULL)));
 			return TRUE;
 		}
 		_tmp4 = NULL;
@@ -1369,6 +1393,26 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 }
 
 
+static gboolean vala_genie_scanner_skip_tabs (ValaGenieScanner* self) {
+	gboolean found;
+	g_return_val_if_fail (VALA_GENIE_IS_SCANNER (self), FALSE);
+	found = FALSE;
+	while (self->priv->current < self->priv->end && self->priv->current[0] == '\t') {
+		self->priv->current++;
+		self->priv->column++;
+		found = TRUE;
+	}
+	return found;
+}
+
+
+static void vala_genie_scanner_skip_space_tabs (ValaGenieScanner* self) {
+	g_return_if_fail (VALA_GENIE_IS_SCANNER (self));
+	while (vala_genie_scanner_whitespace (self) || vala_genie_scanner_skip_tabs (self) || vala_genie_scanner_comment (self)) {
+	}
+}
+
+
 static void vala_genie_scanner_space (ValaGenieScanner* self) {
 	g_return_if_fail (VALA_GENIE_IS_SCANNER (self));
 	while (vala_genie_scanner_whitespace (self) || vala_genie_scanner_comment (self)) {
@@ -1439,7 +1483,7 @@ static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSour
 	g_return_if_fail (VALA_GENIE_IS_SCANNER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_source_file = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL))), _tmp2);
+	self->priv->_source_file = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL))), _tmp2);
 }
 
 
@@ -1455,101 +1499,147 @@ void vala_genie_scanner_set_indent_spaces (ValaGenieScanner* self, gint value) {
 }
 
 
-static GObject * vala_genie_scanner_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaGenieScannerClass * klass;
-	GObjectClass * parent_class;
-	ValaGenieScanner * self;
-	klass = VALA_GENIE_SCANNER_CLASS (g_type_class_peek (VALA_GENIE_TYPE_SCANNER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_GENIE_SCANNER (obj);
-	{
-		self->priv->begin = vala_source_file_get_mapped_contents (self->priv->_source_file);
-		self->priv->end = self->priv->begin + vala_source_file_get_mapped_length (self->priv->_source_file);
-		self->priv->current = self->priv->begin;
-		self->priv->_indent_spaces = 0;
-		self->priv->line = 1;
-		self->priv->column = 1;
-		self->priv->current_indent_level = 0;
-		self->priv->indent_level = 0;
-		self->priv->pending_dedents = 0;
-		self->priv->parse_started = FALSE;
-		self->priv->last_token = VALA_GENIE_TOKEN_TYPE_NONE;
-	}
-	return obj;
+static void vala_genie_value_scanner_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
 }
 
 
-static void vala_genie_scanner_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaGenieScanner * self;
-	self = VALA_GENIE_SCANNER (object);
-	switch (property_id) {
-		case VALA_GENIE_SCANNER_SOURCE_FILE:
-		g_value_set_object (value, vala_genie_scanner_get_source_file (self));
-		break;
-		case VALA_GENIE_SCANNER_INDENT_SPACES:
-		g_value_set_int (value, vala_genie_scanner_get_indent_spaces (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_genie_value_scanner_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_genie_scanner_unref (value->data[0].v_pointer);
 	}
 }
 
 
-static void vala_genie_scanner_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaGenieScanner * self;
-	self = VALA_GENIE_SCANNER (object);
-	switch (property_id) {
-		case VALA_GENIE_SCANNER_SOURCE_FILE:
-		vala_genie_scanner_set_source_file (self, g_value_get_object (value));
-		break;
-		case VALA_GENIE_SCANNER_INDENT_SPACES:
-		vala_genie_scanner_set_indent_spaces (self, g_value_get_int (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_genie_value_scanner_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_genie_scanner_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_genie_value_scanner_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_genie_value_scanner_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaGenieScanner* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_genie_value_scanner_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaGenieScanner** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_genie_scanner_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_genie_param_spec_scanner (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaGenieParamSpecScanner* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_GENIE_TYPE_SCANNER), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_genie_value_get_scanner (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_GENIE_TYPE_SCANNER), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_genie_value_set_scanner (GValue* value, gpointer v_object) {
+	ValaGenieScanner* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_GENIE_TYPE_SCANNER));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_GENIE_TYPE_SCANNER));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_genie_scanner_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_genie_scanner_unref (old);
 	}
 }
 
 
 static void vala_genie_scanner_class_init (ValaGenieScannerClass * klass) {
 	vala_genie_scanner_parent_class = g_type_class_peek_parent (klass);
+	VALA_GENIE_SCANNER_CLASS (klass)->finalize = vala_genie_scanner_finalize;
 	g_type_class_add_private (klass, sizeof (ValaGenieScannerPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_genie_scanner_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_genie_scanner_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_genie_scanner_constructor;
-	G_OBJECT_CLASS (klass)->dispose = vala_genie_scanner_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_GENIE_SCANNER_SOURCE_FILE, g_param_spec_object ("source-file", "source-file", "source-file", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_GENIE_SCANNER_INDENT_SPACES, g_param_spec_int ("indent-spaces", "indent-spaces", "indent-spaces", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_genie_scanner_instance_init (ValaGenieScanner * self) {
 	self->priv = VALA_GENIE_SCANNER_GET_PRIVATE (self);
+	self->ref_count = 1;
 }
 
 
-static void vala_genie_scanner_dispose (GObject * obj) {
+static void vala_genie_scanner_finalize (ValaGenieScanner* obj) {
 	ValaGenieScanner * self;
 	self = VALA_GENIE_SCANNER (obj);
-	(self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL)));
+	(self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL)));
 	self->priv->_comment = (g_free (self->priv->_comment), NULL);
-	G_OBJECT_CLASS (vala_genie_scanner_parent_class)->dispose (obj);
 }
 
 
 GType vala_genie_scanner_get_type (void) {
 	static GType vala_genie_scanner_type_id = 0;
-	if (G_UNLIKELY (vala_genie_scanner_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaGenieScannerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_genie_scanner_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGenieScanner), 0, (GInstanceInitFunc) vala_genie_scanner_instance_init };
-		vala_genie_scanner_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaGenieScanner", &g_define_type_info, 0);
+	if (vala_genie_scanner_type_id == 0) {
+		static const GTypeValueTable g_define_type_value_table = { vala_genie_value_scanner_init, vala_genie_value_scanner_free_value, vala_genie_value_scanner_copy_value, vala_genie_value_scanner_peek_pointer, "p", vala_genie_value_scanner_collect_value, "p", vala_genie_value_scanner_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaGenieScannerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_genie_scanner_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGenieScanner), 0, (GInstanceInitFunc) vala_genie_scanner_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_genie_scanner_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaGenieScanner", &g_define_type_info, &g_define_type_fundamental_info, 0);
 	}
 	return vala_genie_scanner_type_id;
 }
 
 
+gpointer vala_genie_scanner_ref (gpointer instance) {
+	ValaGenieScanner* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_genie_scanner_unref (gpointer instance) {
+	ValaGenieScanner* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_GENIE_SCANNER_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 
 
