@@ -23,6 +23,7 @@
 #include <vala/valaintegerliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaexpression.h>
 
 
 
@@ -33,14 +34,13 @@ struct _ValaIntegerLiteralPrivate {
 
 #define VALA_INTEGER_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteralPrivate))
 enum  {
-	VALA_INTEGER_LITERAL_DUMMY_PROPERTY,
-	VALA_INTEGER_LITERAL_VALUE
+	VALA_INTEGER_LITERAL_DUMMY_PROPERTY
 };
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_integer_literal_real_to_string (ValaCodeNode* base);
 static gboolean vala_integer_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_integer_literal_parent_class = NULL;
-static void vala_integer_literal_dispose (GObject * obj);
+static void vala_integer_literal_finalize (ValaCodeNode* obj);
 
 
 
@@ -51,22 +51,28 @@ static void vala_integer_literal_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created integer literal
  */
-ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source) {
-	ValaIntegerLiteral * self;
+ValaIntegerLiteral* vala_integer_literal_construct (GType object_type, const char* i, ValaSourceReference* source) {
+	ValaIntegerLiteral* self;
 	g_return_val_if_fail (i != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_INTEGER_LITERAL, 0, NULL);
+	self = ((ValaIntegerLiteral*) (g_type_create_instance (object_type)));
 	vala_integer_literal_set_value (self, i);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source) {
+	return vala_integer_literal_construct (VALA_TYPE_INTEGER_LITERAL, i, source);
+}
+
+
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_integer_literal (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -98,14 +104,14 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
 		char* _tmp1;
 		l++;
 		_tmp1 = NULL;
-		number = (_tmp1 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp1);
+		number = (_tmp1 = g_strndup (number, ((gulong) (strlen (number) - 1))), (number = (g_free (number), NULL)), _tmp1);
 	}
 	u = FALSE;
 	if (g_str_has_suffix (number, "u") || g_str_has_suffix (number, "U")) {
 		char* _tmp2;
 		u = TRUE;
 		_tmp2 = NULL;
-		number = (_tmp2 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp2);
+		number = (_tmp2 = g_strndup (number, ((gulong) (strlen (number) - 1))), (number = (g_free (number), NULL)), _tmp2);
 	}
 	n = g_ascii_strtoll (number, NULL, 0);
 	if (!u && n > 0x7fffffff) {
@@ -161,7 +167,7 @@ static gboolean vala_integer_literal_real_is_pure (ValaExpression* base) {
 }
 
 
-char* vala_integer_literal_get_value (ValaIntegerLiteral* self) {
+const char* vala_integer_literal_get_value (ValaIntegerLiteral* self) {
 	g_return_val_if_fail (VALA_IS_INTEGER_LITERAL (self), NULL);
 	return self->priv->_value;
 }
@@ -177,64 +183,33 @@ void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value
 }
 
 
-static void vala_integer_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaIntegerLiteral * self;
-	self = VALA_INTEGER_LITERAL (object);
-	switch (property_id) {
-		case VALA_INTEGER_LITERAL_VALUE:
-		g_value_set_string (value, vala_integer_literal_get_value (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_integer_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaIntegerLiteral * self;
-	self = VALA_INTEGER_LITERAL (object);
-	switch (property_id) {
-		case VALA_INTEGER_LITERAL_VALUE:
-		vala_integer_literal_set_value (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_integer_literal_class_init (ValaIntegerLiteralClass * klass) {
 	vala_integer_literal_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_integer_literal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaIntegerLiteralPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_integer_literal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_integer_literal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_integer_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_integer_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_integer_literal_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_integer_literal_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTEGER_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_integer_literal_init (ValaIntegerLiteral * self) {
+static void vala_integer_literal_instance_init (ValaIntegerLiteral * self) {
 	self->priv = VALA_INTEGER_LITERAL_GET_PRIVATE (self);
 }
 
 
-static void vala_integer_literal_dispose (GObject * obj) {
+static void vala_integer_literal_finalize (ValaCodeNode* obj) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_integer_literal_parent_class)->dispose (obj);
+	VALA_CODE_NODE_CLASS (vala_integer_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_integer_literal_get_type (void) {
 	static GType vala_integer_literal_type_id = 0;
-	if (G_UNLIKELY (vala_integer_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerLiteral), 0, (GInstanceInitFunc) vala_integer_literal_init };
+	if (vala_integer_literal_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerLiteral), 0, (GInstanceInitFunc) vala_integer_literal_instance_init, NULL };
 		vala_integer_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaIntegerLiteral", &g_define_type_info, 0);
 	}
 	return vala_integer_literal_type_id;
