@@ -22,8 +22,8 @@
 
 #include <vala/valainterface.h>
 #include <gee/arraylist.h>
-#include <gee/collection.h>
 #include <gee/readonlylist.h>
+#include <gee/collection.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valadatatype.h>
 #include <vala/valamethod.h>
@@ -72,8 +72,7 @@ struct _ValaInterfacePrivate {
 
 #define VALA_INTERFACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE, ValaInterfacePrivate))
 enum  {
-	VALA_INTERFACE_DUMMY_PROPERTY,
-	VALA_INTERFACE_IS_STATIC
+	VALA_INTERFACE_DUMMY_PROPERTY
 };
 static GeeList* vala_interface_real_get_methods (ValaObjectTypeSymbol* base);
 static GeeList* vala_interface_real_get_properties (ValaObjectTypeSymbol* base);
@@ -97,13 +96,58 @@ static char* vala_interface_real_get_type_id (ValaTypeSymbol* base);
 static gint vala_interface_real_get_type_parameter_index (ValaTypeSymbol* base, const char* name);
 static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static ValaCodeBinding* vala_interface_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
+static char* vala_interface_real_get_param_spec_function (ValaTypeSymbol* base);
 static gpointer vala_interface_parent_class = NULL;
-static void vala_interface_dispose (GObject * obj);
+static void vala_interface_finalize (ValaCodeNode* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+/**
+ * Returns a copy of the list of classes.
+ *
+ * @return list of classes
+ */
+GeeList* vala_interface_get_classes (ValaInterface* self) {
+	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CLASS, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->classes));
+}
+
+
+/**
+ * Returns a copy of the list of structs.
+ *
+ * @return list of structs
+ */
+GeeList* vala_interface_get_structs (ValaInterface* self) {
+	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->structs));
+}
+
+
+/**
+ * Returns a copy of the list of enums.
+ *
+ * @return list of enums
+ */
+GeeList* vala_interface_get_enums (ValaInterface* self) {
+	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->enums));
+}
+
+
+/**
+ * Returns a copy of the list of delegates.
+ *
+ * @return list of delegates
+ */
+GeeList* vala_interface_get_delegates (ValaInterface* self) {
+	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->delegates));
+}
+
+
 /**
  * Creates a new interface.
  *
@@ -111,17 +155,23 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source reference to source code
  * @return       newly created interface
  */
-ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference) {
-	ValaInterface * self;
+ValaInterface* vala_interface_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+	ValaInterface* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_INTERFACE, 0, NULL);
+	self = ((ValaInterface*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_OBJECT_TYPE_SYMBOL (self)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference) {
+	return vala_interface_construct (VALA_TYPE_INTERFACE, name, source_reference);
+}
+
+
 /**
  * Appends the specified parameter to the list of type parameters.
  *
@@ -143,7 +193,7 @@ void vala_interface_add_type_parameter (ValaInterface* self, ValaTypeParameter*
  */
 GeeList* vala_interface_get_type_parameters (ValaInterface* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->type_parameters));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->type_parameters));
 }
 
 
@@ -181,7 +231,7 @@ void vala_interface_prepend_prerequisite (ValaInterface* self, ValaDataType* typ
  */
 GeeList* vala_interface_get_prerequisites (ValaInterface* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->prerequisites));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->prerequisites));
 }
 
 
@@ -206,19 +256,19 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_object_type_new (VALA_OBJECT_TYPE_SYMBOL (self)))), NULL)));
-		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
 	_tmp2 = NULL;
-	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size (GEE_COLLECTION ((_tmp2 = vala_method_get_postconditions (m)))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
+	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size (GEE_COLLECTION ((_tmp2 = vala_method_get_postconditions (m)))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL))), _tmp3)) {
 		ValaLocalVariable* _tmp5;
 		ValaDataType* _tmp4;
 		_tmp5 = NULL;
 		_tmp4 = NULL;
 		vala_method_set_result_var (m, (_tmp5 = vala_local_variable_new ((_tmp4 = vala_data_type_copy (vala_method_get_return_type (m))), "result", NULL, NULL)));
-		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
@@ -234,7 +284,7 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 static GeeList* vala_interface_real_get_methods (ValaObjectTypeSymbol* base) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->methods));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->methods));
 }
 
 
@@ -259,7 +309,7 @@ void vala_interface_add_field (ValaInterface* self, ValaField* f) {
  */
 GeeList* vala_interface_get_fields (ValaInterface* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->fields));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->fields));
 }
 
 
@@ -278,8 +328,8 @@ void vala_interface_add_property (ValaInterface* self, ValaProperty* prop) {
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	vala_property_set_this_parameter (prop, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_object_type_new (VALA_OBJECT_TYPE_SYMBOL (self)))), NULL)));
-	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	(_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL)));
+	(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (prop)), vala_symbol_get_name (VALA_SYMBOL (vala_property_get_this_parameter (prop))), VALA_SYMBOL (vala_property_get_this_parameter (prop)));
 }
 
@@ -292,7 +342,7 @@ void vala_interface_add_property (ValaInterface* self, ValaProperty* prop) {
 static GeeList* vala_interface_real_get_properties (ValaObjectTypeSymbol* base) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_PROPERTY, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->properties));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_PROPERTY, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->properties));
 }
 
 
@@ -317,7 +367,7 @@ void vala_interface_add_signal (ValaInterface* self, ValaSignal* sig) {
 static GeeList* vala_interface_real_get_signals (ValaObjectTypeSymbol* base) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SIGNAL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->signals));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SIGNAL, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->signals));
 }
 
 
@@ -521,7 +571,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			type = ((ValaDataType*) (gee_list_get (GEE_LIST (type_collection), type_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type), visitor);
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
 			}
 		}
 	}
@@ -534,7 +584,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			p = ((ValaTypeParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
-				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
+				(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
 			}
 		}
 	}
@@ -548,7 +598,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			en = ((ValaEnum*) (gee_list_get (GEE_LIST (en_collection), en_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (en), visitor);
-				(en == NULL ? NULL : (en = (g_object_unref (en), NULL)));
+				(en == NULL ? NULL : (en = (vala_code_node_unref (en), NULL)));
 			}
 		}
 	}
@@ -561,7 +611,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
-				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				(m == NULL ? NULL : (m = (vala_code_node_unref (m), NULL)));
 			}
 		}
 	}
@@ -574,7 +624,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			f = ((ValaField*) (gee_list_get (GEE_LIST (f_collection), f_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
-				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
+				(f == NULL ? NULL : (f = (vala_code_node_unref (f), NULL)));
 			}
 		}
 	}
@@ -587,7 +637,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			prop = ((ValaProperty*) (gee_list_get (GEE_LIST (prop_collection), prop_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (prop), visitor);
-				(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
+				(prop == NULL ? NULL : (prop = (vala_code_node_unref (prop), NULL)));
 			}
 		}
 	}
@@ -600,7 +650,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			sig = ((ValaSignal*) (gee_list_get (GEE_LIST (sig_collection), sig_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (sig), visitor);
-				(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
+				(sig == NULL ? NULL : (sig = (vala_code_node_unref (sig), NULL)));
 			}
 		}
 	}
@@ -613,7 +663,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			cl = ((ValaClass*) (gee_list_get (GEE_LIST (cl_collection), cl_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (cl), visitor);
-				(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+				(cl == NULL ? NULL : (cl = (vala_code_node_unref (cl), NULL)));
 			}
 		}
 	}
@@ -626,7 +676,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			st = ((ValaStruct*) (gee_list_get (GEE_LIST (st_collection), st_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
-				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				(st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL)));
 			}
 		}
 	}
@@ -639,7 +689,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 			d = ((ValaDelegate*) (gee_list_get (GEE_LIST (d_collection), d_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (d), visitor);
-				(d == NULL ? NULL : (d = (g_object_unref (d), NULL)));
+				(d == NULL ? NULL : (d = (vala_code_node_unref (d), NULL)));
 			}
 		}
 	}
@@ -676,9 +726,9 @@ static char* vala_interface_real_get_ref_function (ValaTypeSymbol* base) {
 				if (ref_func != NULL) {
 					char* _tmp0;
 					_tmp0 = NULL;
-					return (_tmp0 = ref_func, (prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL))), _tmp0);
+					return (_tmp0 = ref_func, (prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL))), _tmp0);
 				}
-				(prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL)));
+				(prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL)));
 				ref_func = (g_free (ref_func), NULL);
 			}
 		}
@@ -703,9 +753,9 @@ static char* vala_interface_real_get_unref_function (ValaTypeSymbol* base) {
 				if (unref_func != NULL) {
 					char* _tmp0;
 					_tmp0 = NULL;
-					return (_tmp0 = unref_func, (prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL))), _tmp0);
+					return (_tmp0 = unref_func, (prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL))), _tmp0);
 				}
-				(prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL)));
+				(prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL)));
 				unref_func = (g_free (unref_func), NULL);
 			}
 		}
@@ -731,9 +781,9 @@ static gboolean vala_interface_real_is_subtype_of (ValaTypeSymbol* base, ValaTyp
 			{
 				if (vala_data_type_get_data_type (prerequisite) != NULL && vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (prerequisite), t)) {
 					gboolean _tmp1;
-					return (_tmp1 = TRUE, (prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL))), _tmp1);
+					return (_tmp1 = TRUE, (prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL))), _tmp1);
 				}
-				(prerequisite == NULL ? NULL : (prerequisite = (g_object_unref (prerequisite), NULL)));
+				(prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL)));
 			}
 		}
 	}
@@ -794,12 +844,12 @@ void vala_interface_process_attributes (ValaInterface* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_interface_process_ccode_attribute (self, a);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -894,10 +944,10 @@ static gint vala_interface_real_get_type_parameter_index (ValaTypeSymbol* base,
 			{
 				if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (parameter)), name) == 0) {
 					gint _tmp0;
-					return (_tmp0 = i, (parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL))), _tmp0);
+					return (_tmp0 = i, (parameter == NULL ? NULL : (parameter = (vala_code_node_unref (parameter), NULL))), _tmp0);
 				}
 				i++;
-				(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
+				(parameter == NULL ? NULL : (parameter = (vala_code_node_unref (parameter), NULL)));
 			}
 		}
 	}
@@ -917,7 +967,7 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->prerequisites)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) (gee_list_get (((GeeList*) (self->priv->prerequisites)), i)))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) (self->priv->prerequisites)), i, new_type);
 				return;
 			}
@@ -934,6 +984,61 @@ static ValaCodeBinding* vala_interface_real_create_code_binding (ValaCodeNode* b
 }
 
 
+static char* vala_interface_real_get_param_spec_function (ValaTypeSymbol* base) {
+	ValaInterface * self;
+	self = VALA_INTERFACE (base);
+	{
+		GeeList* prerequisite_collection;
+		int prerequisite_it;
+		prerequisite_collection = self->priv->prerequisites;
+		for (prerequisite_it = 0; prerequisite_it < gee_collection_get_size (GEE_COLLECTION (prerequisite_collection)); prerequisite_it = prerequisite_it + 1) {
+			ValaDataType* prerequisite;
+			prerequisite = ((ValaDataType*) (gee_list_get (GEE_LIST (prerequisite_collection), prerequisite_it)));
+			{
+				ValaObjectType* _tmp1;
+				ValaDataType* _tmp0;
+				ValaObjectType* prereq;
+				ValaClass* _tmp3;
+				ValaObjectTypeSymbol* _tmp2;
+				ValaClass* cl;
+				ValaInterface* _tmp6;
+				ValaObjectTypeSymbol* _tmp5;
+				ValaInterface* interf;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				prereq = (_tmp1 = (_tmp0 = prerequisite, (VALA_IS_OBJECT_TYPE (_tmp0) ? ((ValaObjectType*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+				_tmp3 = NULL;
+				_tmp2 = NULL;
+				cl = (_tmp3 = (_tmp2 = vala_object_type_get_type_symbol (prereq), (VALA_IS_CLASS (_tmp2) ? ((ValaClass*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : vala_code_node_ref (_tmp3)));
+				if (cl != NULL) {
+					char* _tmp4;
+					_tmp4 = NULL;
+					return (_tmp4 = vala_typesymbol_get_param_spec_function (VALA_TYPESYMBOL (cl)), (prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL))), (prereq == NULL ? NULL : (prereq = (vala_code_node_unref (prereq), NULL))), (cl == NULL ? NULL : (cl = (vala_code_node_unref (cl), NULL))), _tmp4);
+				}
+				_tmp6 = NULL;
+				_tmp5 = NULL;
+				interf = (_tmp6 = (_tmp5 = vala_object_type_get_type_symbol (prereq), (VALA_IS_INTERFACE (_tmp5) ? ((ValaInterface*) (_tmp5)) : NULL)), (_tmp6 == NULL ? NULL : vala_code_node_ref (_tmp6)));
+				if (interf != NULL) {
+					char* param_spec_function;
+					param_spec_function = vala_typesymbol_get_param_spec_function (VALA_TYPESYMBOL (interf));
+					if (param_spec_function != NULL) {
+						char* _tmp7;
+						_tmp7 = NULL;
+						return (_tmp7 = param_spec_function, (prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL))), (prereq == NULL ? NULL : (prereq = (vala_code_node_unref (prereq), NULL))), (cl == NULL ? NULL : (cl = (vala_code_node_unref (cl), NULL))), (interf == NULL ? NULL : (interf = (vala_code_node_unref (interf), NULL))), _tmp7);
+					}
+					param_spec_function = (g_free (param_spec_function), NULL);
+				}
+				(prerequisite == NULL ? NULL : (prerequisite = (vala_code_node_unref (prerequisite), NULL)));
+				(prereq == NULL ? NULL : (prereq = (vala_code_node_unref (prereq), NULL)));
+				(cl == NULL ? NULL : (cl = (vala_code_node_unref (cl), NULL)));
+				(interf == NULL ? NULL : (interf = (vala_code_node_unref (interf), NULL)));
+			}
+		}
+	}
+	return NULL;
+}
+
+
 gboolean vala_interface_get_is_static (ValaInterface* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), FALSE);
 	return self->priv->_is_static;
@@ -946,40 +1051,10 @@ void vala_interface_set_is_static (ValaInterface* self, gboolean value) {
 }
 
 
-static void vala_interface_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInterface * self;
-	self = VALA_INTERFACE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_IS_STATIC:
-		g_value_set_boolean (value, vala_interface_get_is_static (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_interface_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaInterface * self;
-	self = VALA_INTERFACE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_IS_STATIC:
-		vala_interface_set_is_static (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_interface_class_init (ValaInterfaceClass * klass) {
 	vala_interface_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_interface_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInterfacePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_interface_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_interface_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_interface_dispose;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_methods = vala_interface_real_get_methods;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_properties = vala_interface_real_get_properties;
 	VALA_OBJECT_TYPE_SYMBOL_CLASS (klass)->get_signals = vala_interface_real_get_signals;
@@ -1001,50 +1076,50 @@ static void vala_interface_class_init (ValaInterfaceClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_parameter_index = vala_interface_real_get_type_parameter_index;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_interface_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_interface_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_IS_STATIC, g_param_spec_boolean ("is-static", "is-static", "is-static", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_TYPESYMBOL_CLASS (klass)->get_param_spec_function = vala_interface_real_get_param_spec_function;
 }
 
 
 static void vala_interface_instance_init (ValaInterface * self) {
 	self->priv = VALA_INTERFACE_GET_PRIVATE (self);
-	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->prerequisites = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->properties = GEE_LIST (gee_array_list_new (VALA_TYPE_PROPERTY, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->signals = GEE_LIST (gee_array_list_new (VALA_TYPE_SIGNAL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->classes = GEE_LIST (gee_array_list_new (VALA_TYPE_CLASS, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->structs = GEE_LIST (gee_array_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->enums = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->delegates = GEE_LIST (gee_array_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->prerequisites = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->properties = GEE_LIST (gee_array_list_new (VALA_TYPE_PROPERTY, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->signals = GEE_LIST (gee_array_list_new (VALA_TYPE_SIGNAL, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->classes = GEE_LIST (gee_array_list_new (VALA_TYPE_CLASS, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->structs = GEE_LIST (gee_array_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->enums = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->delegates = GEE_LIST (gee_array_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_interface_dispose (GObject * obj) {
+static void vala_interface_finalize (ValaCodeNode* obj) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (obj);
-	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
-	(self->priv->prerequisites == NULL ? NULL : (self->priv->prerequisites = (g_object_unref (self->priv->prerequisites), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
-	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
-	(self->priv->properties == NULL ? NULL : (self->priv->properties = (g_object_unref (self->priv->properties), NULL)));
-	(self->priv->signals == NULL ? NULL : (self->priv->signals = (g_object_unref (self->priv->signals), NULL)));
-	(self->priv->classes == NULL ? NULL : (self->priv->classes = (g_object_unref (self->priv->classes), NULL)));
-	(self->priv->structs == NULL ? NULL : (self->priv->structs = (g_object_unref (self->priv->structs), NULL)));
-	(self->priv->enums == NULL ? NULL : (self->priv->enums = (g_object_unref (self->priv->enums), NULL)));
-	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (g_object_unref (self->priv->delegates), NULL)));
+	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (gee_collection_object_unref (self->priv->type_parameters), NULL)));
+	(self->priv->prerequisites == NULL ? NULL : (self->priv->prerequisites = (gee_collection_object_unref (self->priv->prerequisites), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
+	(self->priv->fields == NULL ? NULL : (self->priv->fields = (gee_collection_object_unref (self->priv->fields), NULL)));
+	(self->priv->properties == NULL ? NULL : (self->priv->properties = (gee_collection_object_unref (self->priv->properties), NULL)));
+	(self->priv->signals == NULL ? NULL : (self->priv->signals = (gee_collection_object_unref (self->priv->signals), NULL)));
+	(self->priv->classes == NULL ? NULL : (self->priv->classes = (gee_collection_object_unref (self->priv->classes), NULL)));
+	(self->priv->structs == NULL ? NULL : (self->priv->structs = (gee_collection_object_unref (self->priv->structs), NULL)));
+	(self->priv->enums == NULL ? NULL : (self->priv->enums = (gee_collection_object_unref (self->priv->enums), NULL)));
+	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (gee_collection_object_unref (self->priv->delegates), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
 	self->priv->type_cname = (g_free (self->priv->type_cname), NULL);
 	self->priv->type_id = (g_free (self->priv->type_id), NULL);
-	G_OBJECT_CLASS (vala_interface_parent_class)->dispose (obj);
+	VALA_CODE_NODE_CLASS (vala_interface_parent_class)->finalize (obj);
 }
 
 
 GType vala_interface_get_type (void) {
 	static GType vala_interface_type_id = 0;
-	if (G_UNLIKELY (vala_interface_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterface), 0, (GInstanceInitFunc) vala_interface_instance_init };
+	if (vala_interface_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterface), 0, (GInstanceInitFunc) vala_interface_instance_init, NULL };
 		vala_interface_type_id = g_type_register_static (VALA_TYPE_OBJECT_TYPE_SYMBOL, "ValaInterface", &g_define_type_info, 0);
 	}
 	return vala_interface_type_id;
