@@ -32,22 +32,26 @@ struct _ValaInterfaceTypePrivate {
 
 #define VALA_INTERFACE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_TYPE, ValaInterfaceTypePrivate))
 enum  {
-	VALA_INTERFACE_TYPE_DUMMY_PROPERTY,
-	VALA_INTERFACE_TYPE_INTERFACE_SYMBOL
+	VALA_INTERFACE_TYPE_DUMMY_PROPERTY
 };
 static ValaDataType* vala_interface_type_real_copy (ValaDataType* base);
 static char* vala_interface_type_real_get_cname (ValaDataType* base);
 static gpointer vala_interface_type_parent_class = NULL;
-static void vala_interface_type_finalize (GObject * obj);
+static void vala_interface_type_finalize (ValaCodeNode* obj);
 
 
 
+ValaInterfaceType* vala_interface_type_construct (GType object_type, ValaInterface* interface_symbol) {
+	ValaInterfaceType* self;
+	g_return_val_if_fail (VALA_IS_INTERFACE (interface_symbol), NULL);
+	self = ((ValaInterfaceType*) (g_type_create_instance (object_type)));
+	vala_interface_type_set_interface_symbol (self, interface_symbol);
+	return self;
+}
+
+
 ValaInterfaceType* vala_interface_type_new (ValaInterface* interface_symbol) {
-	ValaInterfaceType * self;
-	g_return_val_if_fail (VALA_IS_INTERFACE (interface_symbol), NULL);
-	self = g_object_newv (VALA_TYPE_INTERFACE_TYPE, 0, NULL);
-	vala_interface_type_set_interface_symbol (self, interface_symbol);
-	return self;
+	return vala_interface_type_construct (VALA_TYPE_INTERFACE_TYPE, interface_symbol);
 }
 
 
@@ -72,11 +76,11 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 				ValaDataType* _tmp0;
 				_tmp0 = NULL;
 				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
 			}
 		}
-		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
+		(arg_collection == NULL ? NULL : (arg_collection = (gee_collection_object_unref (arg_collection), NULL)));
 	}
 	return VALA_DATA_TYPE (result);
 }
@@ -102,47 +106,15 @@ ValaInterface* vala_interface_type_get_interface_symbol (ValaInterfaceType* self
 void vala_interface_type_set_interface_symbol (ValaInterfaceType* self, ValaInterface* value) {
 	g_return_if_fail (VALA_IS_INTERFACE_TYPE (self));
 	self->priv->_interface_symbol = value;
-	g_object_notify (((GObject *) (self)), "interface-symbol");
-}
-
-
-static void vala_interface_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInterfaceType * self;
-	self = VALA_INTERFACE_TYPE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_TYPE_INTERFACE_SYMBOL:
-		g_value_set_object (value, vala_interface_type_get_interface_symbol (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_interface_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaInterfaceType * self;
-	self = VALA_INTERFACE_TYPE (object);
-	switch (property_id) {
-		case VALA_INTERFACE_TYPE_INTERFACE_SYMBOL:
-		vala_interface_type_set_interface_symbol (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_interface_type_class_init (ValaInterfaceTypeClass * klass) {
 	vala_interface_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_interface_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInterfaceTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_interface_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_interface_type_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_interface_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_interface_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_interface_type_real_get_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_TYPE_INTERFACE_SYMBOL, g_param_spec_object ("interface-symbol", "interface-symbol", "interface-symbol", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -151,17 +123,17 @@ static void vala_interface_type_instance_init (ValaInterfaceType * self) {
 }
 
 
-static void vala_interface_type_finalize (GObject * obj) {
+static void vala_interface_type_finalize (ValaCodeNode* obj) {
 	ValaInterfaceType * self;
 	self = VALA_INTERFACE_TYPE (obj);
-	G_OBJECT_CLASS (vala_interface_type_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_interface_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_interface_type_get_type (void) {
 	static GType vala_interface_type_type_id = 0;
 	if (vala_interface_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_instance_init, NULL };
 		vala_interface_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaInterfaceType", &g_define_type_info, 0);
 	}
 	return vala_interface_type_type_id;
