@@ -39,9 +39,7 @@ struct _ValaInvocationExpressionPrivate {
 
 #define VALA_INVOCATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INVOCATION_EXPRESSION, ValaInvocationExpressionPrivate))
 enum  {
-	VALA_INVOCATION_EXPRESSION_DUMMY_PROPERTY,
-	VALA_INVOCATION_EXPRESSION_CALL,
-	VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET
+	VALA_INVOCATION_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_invocation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -49,7 +47,7 @@ static void vala_invocation_expression_real_replace_expression (ValaCodeNode* ba
 static gboolean vala_invocation_expression_real_is_pure (ValaExpression* base);
 static ValaCodeBinding* vala_invocation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_invocation_expression_parent_class = NULL;
-static void vala_invocation_expression_dispose (GObject * obj);
+static void vala_invocation_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -60,29 +58,22 @@ static void vala_invocation_expression_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created invocation expression
  */
-ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaInvocationExpression * self;
+ValaInvocationExpression* vala_invocation_expression_construct (GType object_type, ValaExpression* call, ValaSourceReference* source_reference) {
+	ValaInvocationExpression* self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (call), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "call";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, call);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_INVOCATION_EXPRESSION, __params_it - __params, __params);
+	self = ((ValaInvocationExpression*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+	vala_invocation_expression_set_call (self, call);
 	return self;
 }
 
 
+ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference) {
+	return vala_invocation_expression_construct (VALA_TYPE_INVOCATION_EXPRESSION, call, source_reference);
+}
+
+
 /**
  * Appends the specified expression to the list of arguments.
  *
@@ -103,7 +94,7 @@ void vala_invocation_expression_add_argument (ValaInvocationExpression* self, Va
  */
 GeeList* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->argument_list));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->argument_list));
 }
 
 
@@ -123,7 +114,7 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
  */
 GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self) {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->array_sizes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, self->priv->array_sizes));
 }
 
 
@@ -150,7 +141,7 @@ static void vala_invocation_expression_real_accept_children (ValaCodeNode* base,
 			expr = ((ValaExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
-				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				(expr == NULL ? NULL : (expr = (vala_code_node_unref (expr), NULL)));
 			}
 		}
 	}
@@ -201,7 +192,7 @@ void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaEx
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), _tmp2);
+	self->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->_call == NULL ? NULL : (self->_call = (vala_code_node_unref (self->_call), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->_call), VALA_CODE_NODE (self));
 }
 
@@ -218,82 +209,44 @@ void vala_invocation_expression_set_delegate_target (ValaInvocationExpression* s
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_delegate_target = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL))), _tmp2);
-}
-
-
-static void vala_invocation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaInvocationExpression * self;
-	self = VALA_INVOCATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_INVOCATION_EXPRESSION_CALL:
-		g_value_set_object (value, vala_invocation_expression_get_call (self));
-		break;
-		case VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET:
-		g_value_set_object (value, vala_invocation_expression_get_delegate_target (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_invocation_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaInvocationExpression * self;
-	self = VALA_INVOCATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_INVOCATION_EXPRESSION_CALL:
-		vala_invocation_expression_set_call (self, g_value_get_object (value));
-		break;
-		case VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET:
-		vala_invocation_expression_set_delegate_target (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_delegate_target = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (vala_ccode_node_unref (self->priv->_delegate_target), NULL))), _tmp2);
 }
 
 
 static void vala_invocation_expression_class_init (ValaInvocationExpressionClass * klass) {
 	vala_invocation_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_invocation_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaInvocationExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_invocation_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_invocation_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_invocation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_invocation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_invocation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_invocation_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_invocation_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_invocation_expression_real_create_code_binding;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_CALL, g_param_spec_object ("call", "call", "call", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INVOCATION_EXPRESSION_DELEGATE_TARGET, g_param_spec_object ("delegate-target", "delegate-target", "delegate-target", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_invocation_expression_instance_init (ValaInvocationExpression * self) {
 	self->priv = VALA_INVOCATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	self->priv->array_sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->array_sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (vala_ccode_node_ref)), vala_ccode_node_unref, g_direct_equal));
 }
 
 
-static void vala_invocation_expression_dispose (GObject * obj) {
+static void vala_invocation_expression_finalize (ValaCodeNode* obj) {
 	ValaInvocationExpression * self;
 	self = VALA_INVOCATION_EXPRESSION (obj);
-	(self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (g_object_unref (self->priv->_delegate_target), NULL)));
-	(self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL)));
-	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
-	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_object_unref (self->priv->array_sizes), NULL)));
-	G_OBJECT_CLASS (vala_invocation_expression_parent_class)->dispose (obj);
+	(self->priv->_delegate_target == NULL ? NULL : (self->priv->_delegate_target = (vala_ccode_node_unref (self->priv->_delegate_target), NULL)));
+	(self->_call == NULL ? NULL : (self->_call = (vala_code_node_unref (self->_call), NULL)));
+	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (gee_collection_object_unref (self->priv->argument_list), NULL)));
+	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (gee_collection_object_unref (self->priv->array_sizes), NULL)));
+	VALA_CODE_NODE_CLASS (vala_invocation_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_invocation_expression_get_type (void) {
 	static GType vala_invocation_expression_type_id = 0;
-	if (G_UNLIKELY (vala_invocation_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInvocationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invocation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvocationExpression), 0, (GInstanceInitFunc) vala_invocation_expression_instance_init };
+	if (vala_invocation_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInvocationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_invocation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInvocationExpression), 0, (GInstanceInitFunc) vala_invocation_expression_instance_init, NULL };
 		vala_invocation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaInvocationExpression", &g_define_type_info, 0);
 	}
 	return vala_invocation_expression_type_id;
