@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -57,10 +57,12 @@ struct _ValaLambdaExpressionClass {
 };
 
 
+ValaLambdaExpression* vala_lambda_expression_construct (GType object_type, ValaExpression* expression_body, ValaSourceReference* source_reference);
 ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_body, ValaSourceReference* source_reference);
+ValaLambdaExpression* vala_lambda_expression_construct_with_statement_body (GType object_type, ValaBlock* statement_body, ValaSourceReference* source_reference);
 ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* statement_body, ValaSourceReference* source_reference);
 void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param);
-GeeCollection* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
+GeeList* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
 ValaExpression* vala_lambda_expression_get_expression_body (ValaLambdaExpression* self);
 void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, ValaExpression* value);
 ValaBlock* vala_lambda_expression_get_statement_body (ValaLambdaExpression* self);
