@@ -42,7 +42,7 @@ enum  {
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base);
 static gpointer vala_member_parent_class = NULL;
-static void vala_member_dispose (GObject * obj);
+static void vala_member_finalize (ValaCodeNode* obj);
 
 
 
@@ -71,7 +71,7 @@ static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
+			(filename_collection == NULL ? NULL : (filename_collection = (gee_collection_object_unref (filename_collection), NULL)));
 		}
 		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_symbol_get_external_package (VALA_SYMBOL (self))) {
 			char* _tmp0;
@@ -98,20 +98,10 @@ void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
 }
 
 
-/**
- * Represents a general class member.
- */
-ValaMember* vala_member_new (void) {
-	ValaMember * self;
-	self = g_object_newv (VALA_TYPE_MEMBER, 0, NULL);
-	return self;
-}
-
-
 static void vala_member_class_init (ValaMemberClass * klass) {
 	vala_member_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_member_finalize;
 	g_type_class_add_private (klass, sizeof (ValaMemberPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_member_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_real_accept;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_member_real_get_cheader_filenames;
 }
@@ -123,19 +113,19 @@ static void vala_member_instance_init (ValaMember * self) {
 }
 
 
-static void vala_member_dispose (GObject * obj) {
+static void vala_member_finalize (ValaCodeNode* obj) {
 	ValaMember * self;
 	self = VALA_MEMBER (obj);
-	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
-	G_OBJECT_CLASS (vala_member_parent_class)->dispose (obj);
+	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (gee_collection_object_unref (self->priv->cheader_filenames), NULL)));
+	VALA_CODE_NODE_CLASS (vala_member_parent_class)->finalize (obj);
 }
 
 
 GType vala_member_get_type (void) {
 	static GType vala_member_type_id = 0;
-	if (G_UNLIKELY (vala_member_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMember), 0, (GInstanceInitFunc) vala_member_instance_init };
-		vala_member_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaMember", &g_define_type_info, 0);
+	if (vala_member_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMember), 0, (GInstanceInitFunc) vala_member_instance_init, NULL };
+		vala_member_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaMember", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_member_type_id;
 }
