@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 #include <vala/valacodebinding.h>
@@ -57,14 +57,17 @@ struct _ValaMemberAccessClass {
 };
 
 
+ValaMemberAccess* vala_member_access_construct (GType object_type, ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
 ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
+ValaMemberAccess* vala_member_access_construct_simple (GType object_type, const char* member_name, ValaSourceReference* source_reference);
 ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference);
+ValaMemberAccess* vala_member_access_construct_pointer (GType object_type, ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
 ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
 void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaDataType* arg);
-GeeCollection* vala_member_access_get_type_arguments (ValaMemberAccess* self);
+GeeList* vala_member_access_get_type_arguments (ValaMemberAccess* self);
 ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self);
 void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value);
-char* vala_member_access_get_member_name (ValaMemberAccess* self);
+const char* vala_member_access_get_member_name (ValaMemberAccess* self);
 void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value);
 gboolean vala_member_access_get_pointer_member_access (ValaMemberAccess* self);
 void vala_member_access_set_pointer_member_access (ValaMemberAccess* self, gboolean value);
@@ -72,6 +75,8 @@ gboolean vala_member_access_get_prototype_access (ValaMemberAccess* self);
 void vala_member_access_set_prototype_access (ValaMemberAccess* self, gboolean value);
 gboolean vala_member_access_get_creation_member (ValaMemberAccess* self);
 void vala_member_access_set_creation_member (ValaMemberAccess* self, gboolean value);
+gboolean vala_member_access_get_qualified (ValaMemberAccess* self);
+void vala_member_access_set_qualified (ValaMemberAccess* self, gboolean value);
 GType vala_member_access_get_type (void);
 
 
