@@ -37,14 +37,11 @@ struct _ValaMemberInitializerPrivate {
 
 #define VALA_MEMBER_INITIALIZER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_MEMBER_INITIALIZER, ValaMemberInitializerPrivate))
 enum  {
-	VALA_MEMBER_INITIALIZER_DUMMY_PROPERTY,
-	VALA_MEMBER_INITIALIZER_NAME,
-	VALA_MEMBER_INITIALIZER_INITIALIZER,
-	VALA_MEMBER_INITIALIZER_SYMBOL_REFERENCE
+	VALA_MEMBER_INITIALIZER_DUMMY_PROPERTY
 };
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_member_initializer_parent_class = NULL;
-static void vala_member_initializer_dispose (GObject * obj);
+static void vala_member_initializer_finalize (ValaCodeNode* obj);
 
 
 
@@ -56,12 +53,12 @@ static void vala_member_initializer_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created member initializer
  */
-ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
-	ValaMemberInitializer * self;
+ValaMemberInitializer* vala_member_initializer_construct (GType object_type, const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	ValaMemberInitializer* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_MEMBER_INITIALIZER, 0, NULL);
+	self = ((ValaMemberInitializer*) (g_type_create_instance (object_type)));
 	vala_member_initializer_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_member_initializer_set_name (self, name);
@@ -69,6 +66,11 @@ ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpres
 }
 
 
+ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
+	return vala_member_initializer_construct (VALA_TYPE_MEMBER_INITIALIZER, name, initializer, source_reference);
+}
+
+
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (base);
@@ -77,7 +79,7 @@ static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVis
 }
 
 
-char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
+const char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_INITIALIZER (self), NULL);
 	return self->priv->_name;
 }
@@ -105,7 +107,7 @@ void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaE
 	g_return_if_fail (VALA_IS_MEMBER_INITIALIZER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL))), _tmp2);
 }
 
 
@@ -121,77 +123,32 @@ void vala_member_initializer_set_symbol_reference (ValaMemberInitializer* self,
 }
 
 
-static void vala_member_initializer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaMemberInitializer * self;
-	self = VALA_MEMBER_INITIALIZER (object);
-	switch (property_id) {
-		case VALA_MEMBER_INITIALIZER_NAME:
-		g_value_set_string (value, vala_member_initializer_get_name (self));
-		break;
-		case VALA_MEMBER_INITIALIZER_INITIALIZER:
-		g_value_set_object (value, vala_member_initializer_get_initializer (self));
-		break;
-		case VALA_MEMBER_INITIALIZER_SYMBOL_REFERENCE:
-		g_value_set_object (value, vala_member_initializer_get_symbol_reference (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_member_initializer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaMemberInitializer * self;
-	self = VALA_MEMBER_INITIALIZER (object);
-	switch (property_id) {
-		case VALA_MEMBER_INITIALIZER_NAME:
-		vala_member_initializer_set_name (self, g_value_get_string (value));
-		break;
-		case VALA_MEMBER_INITIALIZER_INITIALIZER:
-		vala_member_initializer_set_initializer (self, g_value_get_object (value));
-		break;
-		case VALA_MEMBER_INITIALIZER_SYMBOL_REFERENCE:
-		vala_member_initializer_set_symbol_reference (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_member_initializer_class_init (ValaMemberInitializerClass * klass) {
 	vala_member_initializer_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_member_initializer_finalize;
 	g_type_class_add_private (klass, sizeof (ValaMemberInitializerPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_member_initializer_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_member_initializer_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_member_initializer_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_member_initializer_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_INITIALIZER_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_INITIALIZER_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_INITIALIZER_SYMBOL_REFERENCE, g_param_spec_object ("symbol-reference", "symbol-reference", "symbol-reference", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_member_initializer_init (ValaMemberInitializer * self) {
+static void vala_member_initializer_instance_init (ValaMemberInitializer * self) {
 	self->priv = VALA_MEMBER_INITIALIZER_GET_PRIVATE (self);
 }
 
 
-static void vala_member_initializer_dispose (GObject * obj) {
+static void vala_member_initializer_finalize (ValaCodeNode* obj) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
-	G_OBJECT_CLASS (vala_member_initializer_parent_class)->dispose (obj);
+	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)));
+	VALA_CODE_NODE_CLASS (vala_member_initializer_parent_class)->finalize (obj);
 }
 
 
 GType vala_member_initializer_get_type (void) {
 	static GType vala_member_initializer_type_id = 0;
-	if (G_UNLIKELY (vala_member_initializer_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberInitializerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_initializer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberInitializer), 0, (GInstanceInitFunc) vala_member_initializer_init };
+	if (vala_member_initializer_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberInitializerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_initializer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberInitializer), 0, (GInstanceInitFunc) vala_member_initializer_instance_init, NULL };
 		vala_member_initializer_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaMemberInitializer", &g_define_type_info, 0);
 	}
 	return vala_member_initializer_type_id;
