@@ -83,14 +83,19 @@ static void vala_null_checker_real_visit_conditional_expression (ValaCodeVisitor
 static void vala_null_checker_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l);
 static void vala_null_checker_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a);
 static gpointer vala_null_checker_parent_class = NULL;
-static void vala_null_checker_dispose (GObject * obj);
+static void vala_null_checker_finalize (ValaCodeVisitor* obj);
 
 
 
+ValaNullChecker* vala_null_checker_construct (GType object_type) {
+	ValaNullChecker* self;
+	self = ((ValaNullChecker*) (g_type_create_instance (object_type)));
+	return self;
+}
+
+
 ValaNullChecker* vala_null_checker_new (void) {
-	ValaNullChecker * self;
-	self = g_object_newv (VALA_TYPE_NULL_CHECKER, 0, NULL);
-	return self;
+	return vala_null_checker_construct (VALA_TYPE_NULL_CHECKER);
 }
 
 
@@ -101,7 +106,7 @@ void vala_null_checker_check (ValaNullChecker* self, ValaCodeContext* context) {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->context = (_tmp1 = (_tmp0 = context, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp1);
+	self->priv->context = (_tmp1 = (_tmp0 = context, (_tmp0 == NULL ? NULL : vala_code_context_ref (_tmp0))), (self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL))), _tmp1);
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
 }
 
@@ -217,15 +222,15 @@ static void vala_null_checker_real_visit_method (ValaCodeVisitor* base, ValaMeth
 	self = VALA_NULL_CHECKER (base);
 	g_return_if_fail (VALA_IS_METHOD (m));
 	_tmp0 = NULL;
-	old_return_type = (_tmp0 = self->priv->current_return_type, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	old_return_type = (_tmp0 = self->priv->current_return_type, (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->current_return_type = (_tmp2 = (_tmp1 = vala_method_get_return_type (m), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (g_object_unref (self->priv->current_return_type), NULL))), _tmp2);
+	self->priv->current_return_type = (_tmp2 = (_tmp1 = vala_method_get_return_type (m), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (vala_code_node_unref (self->priv->current_return_type), NULL))), _tmp2);
 	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	self->priv->current_return_type = (_tmp4 = (_tmp3 = old_return_type, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (g_object_unref (self->priv->current_return_type), NULL))), _tmp4);
-	(old_return_type == NULL ? NULL : (old_return_type = (g_object_unref (old_return_type), NULL)));
+	self->priv->current_return_type = (_tmp4 = (_tmp3 = old_return_type, (_tmp3 == NULL ? NULL : vala_code_node_ref (_tmp3))), (self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (vala_code_node_unref (self->priv->current_return_type), NULL))), _tmp4);
+	(old_return_type == NULL ? NULL : (old_return_type = (vala_code_node_unref (old_return_type), NULL)));
 }
 
 
@@ -409,15 +414,15 @@ static void vala_null_checker_real_visit_invocation_expression (ValaCodeVisitor*
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	mtype = (_tmp1 = (_tmp0 = vala_expression_get_value_type (vala_invocation_expression_get_call (expr)), (VALA_IS_METHOD_TYPE (_tmp0) ? ((ValaMethodType*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	mtype = (_tmp1 = (_tmp0 = vala_expression_get_value_type (vala_invocation_expression_get_call (expr)), (VALA_IS_METHOD_TYPE (_tmp0) ? ((ValaMethodType*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
 	_tmp3 = NULL;
 	_tmp2 = NULL;
-	ma = (_tmp3 = (_tmp2 = vala_invocation_expression_get_call (expr), (VALA_IS_MEMBER_ACCESS (_tmp2) ? ((ValaMemberAccess*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+	ma = (_tmp3 = (_tmp2 = vala_invocation_expression_get_call (expr), (VALA_IS_MEMBER_ACCESS (_tmp2) ? ((ValaMemberAccess*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : vala_code_node_ref (_tmp3)));
 	if (mtype != NULL && vala_method_get_binding (vala_method_type_get_method_symbol (mtype)) == MEMBER_BINDING_INSTANCE && ma != NULL) {
 		vala_null_checker_check_non_null (self, vala_member_access_get_inner (ma));
 	}
-	(mtype == NULL ? NULL : (mtype = (g_object_unref (mtype), NULL)));
-	(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
+	(mtype == NULL ? NULL : (mtype = (vala_code_node_unref (mtype), NULL)));
+	(ma == NULL ? NULL : (ma = (vala_code_node_unref (ma), NULL)));
 }
 
 
@@ -487,8 +492,8 @@ static void vala_null_checker_real_visit_assignment (ValaCodeVisitor* base, Vala
 
 static void vala_null_checker_class_init (ValaNullCheckerClass * klass) {
 	vala_null_checker_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_VISITOR_CLASS (klass)->finalize = vala_null_checker_finalize;
 	g_type_class_add_private (klass, sizeof (ValaNullCheckerPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_null_checker_dispose;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_null_checker_real_visit_source_file;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_null_checker_real_visit_class;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_null_checker_real_visit_struct;
@@ -532,19 +537,19 @@ static void vala_null_checker_instance_init (ValaNullChecker * self) {
 }
 
 
-static void vala_null_checker_dispose (GObject * obj) {
+static void vala_null_checker_finalize (ValaCodeVisitor* obj) {
 	ValaNullChecker * self;
 	self = VALA_NULL_CHECKER (obj);
-	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
-	(self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (g_object_unref (self->priv->current_return_type), NULL)));
-	G_OBJECT_CLASS (vala_null_checker_parent_class)->dispose (obj);
+	(self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)));
+	(self->priv->current_return_type == NULL ? NULL : (self->priv->current_return_type = (vala_code_node_unref (self->priv->current_return_type), NULL)));
+	VALA_CODE_VISITOR_CLASS (vala_null_checker_parent_class)->finalize (obj);
 }
 
 
 GType vala_null_checker_get_type (void) {
 	static GType vala_null_checker_type_id = 0;
-	if (G_UNLIKELY (vala_null_checker_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNullCheckerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_checker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullChecker), 0, (GInstanceInitFunc) vala_null_checker_instance_init };
+	if (vala_null_checker_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNullCheckerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_checker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullChecker), 0, (GInstanceInitFunc) vala_null_checker_instance_init, NULL };
 		vala_null_checker_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaNullChecker", &g_define_type_info, 0);
 	}
 	return vala_null_checker_type_id;
