@@ -58,6 +58,7 @@
 #include <vala/valaelementaccess.h>
 #include <vala/valapostfixexpression.h>
 #include <vala/valaunaryexpression.h>
+#include <vala/valareferencetransferexpression.h>
 #include <vala/valaconditionalexpression.h>
 #include <vala/valalambdaexpression.h>
 #include <vala/valaassignment.h>
@@ -89,6 +90,7 @@ struct _ValaNullCheckerClass {
 };
 
 
+ValaNullChecker* vala_null_checker_construct (GType object_type);
 ValaNullChecker* vala_null_checker_new (void);
 void vala_null_checker_check (ValaNullChecker* self, ValaCodeContext* context);
 GType vala_null_checker_get_type (void);
