@@ -44,15 +44,20 @@ static gpointer vala_null_literal_parent_class = NULL;
  * @param source reference to source code
  * @return       newly created null literal
  */
-ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source) {
-	ValaNullLiteral * self;
+ValaNullLiteral* vala_null_literal_construct (GType object_type, ValaSourceReference* source) {
+	ValaNullLiteral* self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_NULL_LITERAL, 0, NULL);
+	self = ((ValaNullLiteral*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source) {
+	return vala_null_literal_construct (VALA_TYPE_NULL_LITERAL, source);
+}
+
+
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNullLiteral * self;
 	self = VALA_NULL_LITERAL (base);
@@ -91,7 +96,7 @@ static void vala_null_literal_instance_init (ValaNullLiteral * self) {
 GType vala_null_literal_get_type (void) {
 	static GType vala_null_literal_type_id = 0;
 	if (vala_null_literal_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNullLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullLiteral), 0, (GInstanceInitFunc) vala_null_literal_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNullLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullLiteral), 0, (GInstanceInitFunc) vala_null_literal_instance_init, NULL };
 		vala_null_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaNullLiteral", &g_define_type_info, 0);
 	}
 	return vala_null_literal_type_id;
