@@ -36,19 +36,25 @@ enum  {
 static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static ValaDataType* vala_null_type_real_copy (ValaDataType* base);
 static char* vala_null_type_real_get_cname (ValaDataType* base);
+static gboolean vala_null_type_real_is_disposable (ValaDataType* base);
 static gpointer vala_null_type_parent_class = NULL;
 
 
 
-ValaNullType* vala_null_type_new (ValaSourceReference* source_reference) {
-	ValaNullType * self;
+ValaNullType* vala_null_type_construct (GType object_type, ValaSourceReference* source_reference) {
+	ValaNullType* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_NULL_TYPE, 0, NULL);
+	self = ((ValaNullType*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
+ValaNullType* vala_null_type_new (ValaSourceReference* source_reference) {
+	return vala_null_type_construct (VALA_TYPE_NULL_TYPE, source_reference);
+}
+
+
 static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaNullType * self;
 	ValaAttribute* _tmp1;
@@ -60,7 +66,7 @@ static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType
 	}
 	/* null can be cast to any reference or array type or pointer type */
 	_tmp1 = NULL;
-	if ((_tmp2 = vala_data_type_get_type_parameter (target_type) != NULL || VALA_IS_POINTER_TYPE (target_type) || vala_data_type_get_nullable (target_type) || (_tmp1 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2)) {
+	if ((_tmp2 = vala_data_type_get_type_parameter (target_type) != NULL || VALA_IS_POINTER_TYPE (target_type) || vala_data_type_get_nullable (target_type) || (_tmp1 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL))), _tmp2)) {
 		return TRUE;
 	}
 	if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (target_type)) || VALA_IS_ARRAY_TYPE (target_type) || VALA_IS_DELEGATE_TYPE (target_type)) {
@@ -85,22 +91,30 @@ static char* vala_null_type_real_get_cname (ValaDataType* base) {
 }
 
 
+static gboolean vala_null_type_real_is_disposable (ValaDataType* base) {
+	ValaNullType * self;
+	self = VALA_NULL_TYPE (base);
+	return FALSE;
+}
+
+
 static void vala_null_type_class_init (ValaNullTypeClass * klass) {
 	vala_null_type_parent_class = g_type_class_peek_parent (klass);
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_null_type_real_compatible;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_null_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_null_type_real_get_cname;
+	VALA_DATA_TYPE_CLASS (klass)->is_disposable = vala_null_type_real_is_disposable;
 }
 
 
-static void vala_null_type_init (ValaNullType * self) {
+static void vala_null_type_instance_init (ValaNullType * self) {
 }
 
 
 GType vala_null_type_get_type (void) {
 	static GType vala_null_type_type_id = 0;
-	if (G_UNLIKELY (vala_null_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNullTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullType), 0, (GInstanceInitFunc) vala_null_type_init };
+	if (vala_null_type_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNullTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullType), 0, (GInstanceInitFunc) vala_null_type_instance_init, NULL };
 		vala_null_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaNullType", &g_define_type_info, 0);
 	}
 	return vala_null_type_type_id;
