@@ -22,8 +22,8 @@
 
 #include <vala/valaobjectcreationexpression.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valamethod.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valamemberinitializer.h>
@@ -45,11 +45,7 @@ struct _ValaObjectCreationExpressionPrivate {
 
 #define VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_OBJECT_CREATION_EXPRESSION, ValaObjectCreationExpressionPrivate))
 enum  {
-	VALA_OBJECT_CREATION_EXPRESSION_DUMMY_PROPERTY,
-	VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE,
-	VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR,
-	VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME,
-	VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION
+	VALA_OBJECT_CREATION_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -57,7 +53,7 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* base);
 static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_object_creation_expression_parent_class = NULL;
-static void vala_object_creation_expression_dispose (GObject * obj);
+static void vala_object_creation_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -68,17 +64,22 @@ static void vala_object_creation_expression_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created object creation expression
  */
-ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
-	ValaObjectCreationExpression * self;
+ValaObjectCreationExpression* vala_object_creation_expression_construct (GType object_type, ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
+	ValaObjectCreationExpression* self;
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (member_name), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_OBJECT_CREATION_EXPRESSION, 0, NULL);
+	self = ((ValaObjectCreationExpression*) (g_type_create_instance (object_type)));
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_object_creation_expression_set_member_name (self, member_name);
 	return self;
 }
 
 
+ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
+	return vala_object_creation_expression_construct (VALA_TYPE_OBJECT_CREATION_EXPRESSION, member_name, source_reference);
+}
+
+
 /**
  * Appends the specified expression to the list of arguments.
  *
@@ -97,9 +98,9 @@ void vala_object_creation_expression_add_argument (ValaObjectCreationExpression*
  *
  * @return argument list
  */
-GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self) {
+GeeList* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->argument_list));
 }
 
 
@@ -121,9 +122,9 @@ void vala_object_creation_expression_add_member_initializer (ValaObjectCreationE
  *
  * @return member initializer list
  */
-GeeCollection* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self) {
+GeeList* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->object_initializer)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->object_initializer));
 }
 
 
@@ -132,6 +133,7 @@ static void vala_object_creation_expression_real_accept (ValaCodeNode* base, Val
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_object_creation_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -147,33 +149,29 @@ static void vala_object_creation_expression_real_accept_children (ValaCodeNode*
 	}
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->priv->argument_list;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaExpression* arg;
-			arg = ((ValaExpression*) gee_iterator_get (arg_it));
+			arg = ((ValaExpression*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (arg), visitor);
-				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
+				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	{
 		GeeList* init_collection;
-		GeeIterator* init_it;
+		int init_it;
 		init_collection = self->priv->object_initializer;
-		init_it = gee_iterable_iterator (GEE_ITERABLE (init_collection));
-		while (gee_iterator_next (init_it)) {
+		for (init_it = 0; init_it < gee_collection_get_size (GEE_COLLECTION (init_collection)); init_it = init_it + 1) {
 			ValaMemberInitializer* init;
-			init = ((ValaMemberInitializer*) gee_iterator_get (init_it));
+			init = ((ValaMemberInitializer*) (gee_list_get (GEE_LIST (init_collection), init_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (init), visitor);
-				(init == NULL ? NULL : (init = (g_object_unref (init), NULL)));
+				(init == NULL ? NULL : (init = (vala_code_node_unref (init), NULL)));
 			}
 		}
-		(init_it == NULL ? NULL : (init_it = (g_object_unref (init_it), NULL)));
 	}
 }
 
@@ -186,7 +184,7 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	index = gee_list_index_of (self->priv->argument_list, old_node);
 	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
-		gee_list_set (((GeeList*) self->priv->argument_list), index, new_node);
+		gee_list_set (((GeeList*) (self->priv->argument_list)), index, new_node);
 		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
 	}
 }
@@ -222,7 +220,7 @@ void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpre
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
@@ -239,7 +237,7 @@ void vala_object_creation_expression_set_constructor (ValaObjectCreationExpressi
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), _tmp2);
+	self->priv->_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (vala_code_node_unref (self->priv->_constructor), NULL))), _tmp2);
 }
 
 
@@ -255,7 +253,7 @@ void vala_object_creation_expression_set_member_name (ValaObjectCreationExpressi
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL))), _tmp2);
+	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (vala_code_node_unref (self->priv->_member_name), NULL))), _tmp2);
 }
 
 
@@ -271,93 +269,41 @@ void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpr
 }
 
 
-static void vala_object_creation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaObjectCreationExpression * self;
-	self = VALA_OBJECT_CREATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE:
-		g_value_set_object (value, vala_object_creation_expression_get_type_reference (self));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR:
-		g_value_set_object (value, vala_object_creation_expression_get_constructor (self));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
-		g_value_set_object (value, vala_object_creation_expression_get_member_name (self));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION:
-		g_value_set_boolean (value, vala_object_creation_expression_get_struct_creation (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_object_creation_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaObjectCreationExpression * self;
-	self = VALA_OBJECT_CREATION_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE:
-		vala_object_creation_expression_set_type_reference (self, g_value_get_object (value));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR:
-		vala_object_creation_expression_set_constructor (self, g_value_get_object (value));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
-		vala_object_creation_expression_set_member_name (self, g_value_get_object (value));
-		break;
-		case VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION:
-		vala_object_creation_expression_set_struct_creation (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_object_creation_expression_class_init (ValaObjectCreationExpressionClass * klass) {
 	vala_object_creation_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_object_creation_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaObjectCreationExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_object_creation_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_object_creation_expression_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_object_creation_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_object_creation_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_object_creation_expression_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_object_creation_expression_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_object_creation_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_object_creation_expression_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR, g_param_spec_object ("constructor", "constructor", "constructor", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME, g_param_spec_object ("member-name", "member-name", "member-name", VALA_TYPE_MEMBER_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION, g_param_spec_boolean ("struct-creation", "struct-creation", "struct-creation", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_object_creation_expression_init (ValaObjectCreationExpression * self) {
+static void vala_object_creation_expression_instance_init (ValaObjectCreationExpression * self) {
 	self->priv = VALA_OBJECT_CREATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->object_initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->argument_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
+	self->priv->object_initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_MEMBER_INITIALIZER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_object_creation_expression_dispose (GObject * obj) {
+static void vala_object_creation_expression_finalize (ValaCodeNode* obj) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (obj);
-	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL)));
-	(self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL)));
-	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
-	(self->priv->object_initializer == NULL ? NULL : (self->priv->object_initializer = (g_object_unref (self->priv->object_initializer), NULL)));
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_object_creation_expression_parent_class)->dispose (obj);
+	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (vala_code_node_unref (self->priv->_constructor), NULL)));
+	(self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (vala_code_node_unref (self->priv->_member_name), NULL)));
+	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (gee_collection_object_unref (self->priv->argument_list), NULL)));
+	(self->priv->object_initializer == NULL ? NULL : (self->priv->object_initializer = (gee_collection_object_unref (self->priv->object_initializer), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_object_creation_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_object_creation_expression_get_type (void) {
 	static GType vala_object_creation_expression_type_id = 0;
-	if (G_UNLIKELY (vala_object_creation_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaObjectCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_object_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaObjectCreationExpression), 0, (GInstanceInitFunc) vala_object_creation_expression_init };
+	if (vala_object_creation_expression_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaObjectCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_object_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaObjectCreationExpression), 0, (GInstanceInitFunc) vala_object_creation_expression_instance_init, NULL };
 		vala_object_creation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaObjectCreationExpression", &g_define_type_info, 0);
 	}
 	return vala_object_creation_expression_type_id;
