@@ -63,24 +63,7 @@ struct _ValaPropertyPrivate {
 
 #define VALA_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY, ValaPropertyPrivate))
 enum  {
-	VALA_PROPERTY_DUMMY_PROPERTY,
-	VALA_PROPERTY_PROPERTY_TYPE,
-	VALA_PROPERTY_GET_ACCESSOR,
-	VALA_PROPERTY_SET_ACCESSOR,
-	VALA_PROPERTY_THIS_PARAMETER,
-	VALA_PROPERTY_NOTIFY,
-	VALA_PROPERTY_NO_ACCESSOR_METHOD,
-	VALA_PROPERTY_INTERFACE_ONLY,
-	VALA_PROPERTY_IS_ABSTRACT,
-	VALA_PROPERTY_IS_VIRTUAL,
-	VALA_PROPERTY_OVERRIDES,
-	VALA_PROPERTY_FIELD,
-	VALA_PROPERTY_BINDING,
-	VALA_PROPERTY_BASE_PROPERTY,
-	VALA_PROPERTY_BASE_INTERFACE_PROPERTY,
-	VALA_PROPERTY_DEFAULT_EXPRESSION,
-	VALA_PROPERTY_NICK,
-	VALA_PROPERTY_BLURB
+	VALA_PROPERTY_DUMMY_PROPERTY
 };
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -94,7 +77,7 @@ static void vala_property_find_base_class_property (ValaProperty* self, ValaClas
 static void vala_property_find_base_interface_property (ValaProperty* self, ValaClass* cl);
 static gpointer vala_property_parent_class = NULL;
 static ValaLockableIface* vala_property_vala_lockable_parent_iface = NULL;
-static void vala_property_finalize (GObject * obj);
+static void vala_property_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -109,14 +92,15 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source       reference to source code
  * @return             newly created property
  */
-ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference) {
-	ValaProperty * self;
+ValaProperty* vala_property_construct (GType object_type, const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference) {
+	ValaProperty* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (property_type), NULL);
 	g_return_val_if_fail (get_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (get_accessor), NULL);
 	g_return_val_if_fail (set_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (set_accessor), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_PROPERTY, 0, NULL);
+	self = ((ValaProperty*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_MEMBER (self)));
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_property_set_property_type (self, property_type);
 	vala_property_set_get_accessor (self, get_accessor);
@@ -126,6 +110,11 @@ ValaProperty* vala_property_new (const char* name, ValaDataType* property_type,
 }
 
 
+ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference) {
+	return vala_property_construct (VALA_TYPE_PROPERTY, name, property_type, get_accessor, set_accessor, source_reference);
+}
+
+
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
@@ -242,7 +231,7 @@ void vala_property_process_attributes (ValaProperty* self) {
 			ValaAttribute* _tmp2;
 			ValaAttribute* a;
 			_tmp2 = NULL;
-			a = (_tmp2 = ((ValaAttribute*) (a_it->data)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+			a = (_tmp2 = ((ValaAttribute*) (a_it->data)), (_tmp2 == NULL ? NULL : vala_code_node_ref (_tmp2)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_property_process_ccode_attribute (self, a);
@@ -266,7 +255,7 @@ void vala_property_process_attributes (ValaProperty* self) {
 						}
 					}
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -354,7 +343,7 @@ static void vala_property_find_base_properties (ValaProperty* self) {
 				ValaProperty* _tmp0;
 				_tmp1 = NULL;
 				_tmp0 = NULL;
-				self->priv->_base_interface_property = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp1);
+				self->priv->_base_interface_property = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (vala_code_node_unref (self->priv->_base_interface_property), NULL))), _tmp1);
 			}
 		}
 	}
@@ -371,7 +360,7 @@ static void vala_property_find_base_class_property (ValaProperty* self, ValaClas
 		ValaProperty* _tmp0;
 		ValaProperty* base_property;
 		_tmp0 = NULL;
-		base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 		if (base_property->priv->_is_abstract || base_property->priv->_is_virtual) {
 			if (!vala_property_equals (self, base_property)) {
 				char* _tmp3;
@@ -385,21 +374,21 @@ static void vala_property_find_base_class_property (ValaProperty* self, ValaClas
 				_tmp3 = (g_free (_tmp3), NULL);
 				_tmp2 = (g_free (_tmp2), NULL);
 				_tmp1 = (g_free (_tmp1), NULL);
-				(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
-				(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+				(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
+				(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
 				return;
 			}
 			self->priv->_base_property = base_property;
-			(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
-			(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+			(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
+			(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
 			return;
 		}
-		(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+		(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
 	}
 	if (vala_class_get_base_class (cl) != NULL) {
 		vala_property_find_base_class_property (self, vala_class_get_base_class (cl));
 	}
-	(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+	(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
 }
 
 
@@ -422,7 +411,7 @@ static void vala_property_find_base_interface_property (ValaProperty* self, Vala
 						ValaProperty* _tmp0;
 						ValaProperty* base_property;
 						_tmp0 = NULL;
-						base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+						base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 						if (base_property->priv->_is_abstract) {
 							ValaProperty* _tmp5;
 							ValaProperty* _tmp4;
@@ -438,29 +427,29 @@ static void vala_property_find_base_interface_property (ValaProperty* self, Vala
 								_tmp3 = (g_free (_tmp3), NULL);
 								_tmp2 = (g_free (_tmp2), NULL);
 								_tmp1 = (g_free (_tmp1), NULL);
-								(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
-								(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
-								(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-								(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+								(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
+								(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
+								(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+								(type_collection == NULL ? NULL : (type_collection = (gee_collection_object_unref (type_collection), NULL)));
 								return;
 							}
 							_tmp5 = NULL;
 							_tmp4 = NULL;
-							self->priv->_base_interface_property = (_tmp5 = (_tmp4 = base_property, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp5);
-							(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
-							(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
-							(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-							(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+							self->priv->_base_interface_property = (_tmp5 = (_tmp4 = base_property, (_tmp4 == NULL ? NULL : vala_code_node_ref (_tmp4))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (vala_code_node_unref (self->priv->_base_interface_property), NULL))), _tmp5);
+							(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
+							(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
+							(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
+							(type_collection == NULL ? NULL : (type_collection = (gee_collection_object_unref (type_collection), NULL)));
 							return;
 						}
-						(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+						(base_property == NULL ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)));
 					}
-					(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+					(sym == NULL ? NULL : (sym = (vala_code_node_unref (sym), NULL)));
 				}
-				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(type == NULL ? NULL : (type = (vala_code_node_unref (type), NULL)));
 			}
 		}
-		(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+		(type_collection == NULL ? NULL : (type_collection = (gee_collection_object_unref (type_collection), NULL)));
 	}
 }
 
@@ -477,9 +466,8 @@ void vala_property_set_property_type (ValaProperty* self, ValaDataType* value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "property-type");
 }
 
 
@@ -495,8 +483,7 @@ void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* v
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_get_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "get-accessor");
+	self->priv->_get_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (vala_code_node_unref (self->priv->_get_accessor), NULL))), _tmp2);
 }
 
 
@@ -512,8 +499,7 @@ void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* v
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_set_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "set-accessor");
+	self->priv->_set_accessor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (vala_code_node_unref (self->priv->_set_accessor), NULL))), _tmp2);
 }
 
 
@@ -529,8 +515,7 @@ void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter*
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "this-parameter");
+	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL))), _tmp2);
 }
 
 
@@ -543,7 +528,6 @@ gboolean vala_property_get_notify (ValaProperty* self) {
 void vala_property_set_notify (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_notify = value;
-	g_object_notify (((GObject *) (self)), "notify");
 }
 
 
@@ -556,7 +540,6 @@ gboolean vala_property_get_no_accessor_method (ValaProperty* self) {
 void vala_property_set_no_accessor_method (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_no_accessor_method = value;
-	g_object_notify (((GObject *) (self)), "no-accessor-method");
 }
 
 
@@ -569,7 +552,6 @@ gboolean vala_property_get_interface_only (ValaProperty* self) {
 void vala_property_set_interface_only (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_interface_only = value;
-	g_object_notify (((GObject *) (self)), "interface-only");
 }
 
 
@@ -582,7 +564,6 @@ gboolean vala_property_get_is_abstract (ValaProperty* self) {
 void vala_property_set_is_abstract (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_is_abstract = value;
-	g_object_notify (((GObject *) (self)), "is-abstract");
 }
 
 
@@ -595,7 +576,6 @@ gboolean vala_property_get_is_virtual (ValaProperty* self) {
 void vala_property_set_is_virtual (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_is_virtual = value;
-	g_object_notify (((GObject *) (self)), "is-virtual");
 }
 
 
@@ -608,7 +588,6 @@ gboolean vala_property_get_overrides (ValaProperty* self) {
 void vala_property_set_overrides (ValaProperty* self, gboolean value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_overrides = value;
-	g_object_notify (((GObject *) (self)), "overrides");
 }
 
 
@@ -624,8 +603,7 @@ void vala_property_set_field (ValaProperty* self, ValaField* value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_field = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "field");
+	self->priv->_field = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_field == NULL ? NULL : (self->priv->_field = (vala_code_node_unref (self->priv->_field), NULL))), _tmp2);
 }
 
 
@@ -638,7 +616,6 @@ MemberBinding vala_property_get_binding (ValaProperty* self) {
 void vala_property_set_binding (ValaProperty* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	self->priv->_binding = value;
-	g_object_notify (((GObject *) (self)), "binding");
 }
 
 
@@ -668,8 +645,7 @@ void vala_property_set_default_expression (ValaProperty* self, ValaExpression* v
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "default-expression");
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL))), _tmp2);
 }
 
 
@@ -691,7 +667,6 @@ void vala_property_set_nick (ValaProperty* self, const char* value) {
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	self->priv->_nick = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_nick = (g_free (self->priv->_nick), NULL)), _tmp3);
-	g_object_notify (((GObject *) (self)), "nick");
 }
 
 
@@ -713,154 +688,16 @@ void vala_property_set_blurb (ValaProperty* self, const char* value) {
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	self->priv->_blurb = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->_blurb = (g_free (self->priv->_blurb), NULL)), _tmp3);
-	g_object_notify (((GObject *) (self)), "blurb");
-}
-
-
-static void vala_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaProperty * self;
-	self = VALA_PROPERTY (object);
-	switch (property_id) {
-		case VALA_PROPERTY_PROPERTY_TYPE:
-		g_value_set_object (value, vala_property_get_property_type (self));
-		break;
-		case VALA_PROPERTY_GET_ACCESSOR:
-		g_value_set_object (value, vala_property_get_get_accessor (self));
-		break;
-		case VALA_PROPERTY_SET_ACCESSOR:
-		g_value_set_object (value, vala_property_get_set_accessor (self));
-		break;
-		case VALA_PROPERTY_THIS_PARAMETER:
-		g_value_set_object (value, vala_property_get_this_parameter (self));
-		break;
-		case VALA_PROPERTY_NOTIFY:
-		g_value_set_boolean (value, vala_property_get_notify (self));
-		break;
-		case VALA_PROPERTY_NO_ACCESSOR_METHOD:
-		g_value_set_boolean (value, vala_property_get_no_accessor_method (self));
-		break;
-		case VALA_PROPERTY_INTERFACE_ONLY:
-		g_value_set_boolean (value, vala_property_get_interface_only (self));
-		break;
-		case VALA_PROPERTY_IS_ABSTRACT:
-		g_value_set_boolean (value, vala_property_get_is_abstract (self));
-		break;
-		case VALA_PROPERTY_IS_VIRTUAL:
-		g_value_set_boolean (value, vala_property_get_is_virtual (self));
-		break;
-		case VALA_PROPERTY_OVERRIDES:
-		g_value_set_boolean (value, vala_property_get_overrides (self));
-		break;
-		case VALA_PROPERTY_FIELD:
-		g_value_set_object (value, vala_property_get_field (self));
-		break;
-		case VALA_PROPERTY_BINDING:
-		g_value_set_enum (value, vala_property_get_binding (self));
-		break;
-		case VALA_PROPERTY_BASE_PROPERTY:
-		g_value_set_object (value, vala_property_get_base_property (self));
-		break;
-		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
-		g_value_set_object (value, vala_property_get_base_interface_property (self));
-		break;
-		case VALA_PROPERTY_DEFAULT_EXPRESSION:
-		g_value_set_object (value, vala_property_get_default_expression (self));
-		break;
-		case VALA_PROPERTY_NICK:
-		g_value_set_string (value, vala_property_get_nick (self));
-		break;
-		case VALA_PROPERTY_BLURB:
-		g_value_set_string (value, vala_property_get_blurb (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaProperty * self;
-	self = VALA_PROPERTY (object);
-	switch (property_id) {
-		case VALA_PROPERTY_PROPERTY_TYPE:
-		vala_property_set_property_type (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_GET_ACCESSOR:
-		vala_property_set_get_accessor (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_SET_ACCESSOR:
-		vala_property_set_set_accessor (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_THIS_PARAMETER:
-		vala_property_set_this_parameter (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_NOTIFY:
-		vala_property_set_notify (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_NO_ACCESSOR_METHOD:
-		vala_property_set_no_accessor_method (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_INTERFACE_ONLY:
-		vala_property_set_interface_only (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_IS_ABSTRACT:
-		vala_property_set_is_abstract (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_IS_VIRTUAL:
-		vala_property_set_is_virtual (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_OVERRIDES:
-		vala_property_set_overrides (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_FIELD:
-		vala_property_set_field (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_BINDING:
-		vala_property_set_binding (self, g_value_get_enum (value));
-		break;
-		case VALA_PROPERTY_DEFAULT_EXPRESSION:
-		vala_property_set_default_expression (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_NICK:
-		vala_property_set_nick (self, g_value_get_string (value));
-		break;
-		case VALA_PROPERTY_BLURB:
-		vala_property_set_blurb (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_property_class_init (ValaPropertyClass * klass) {
 	vala_property_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_property_finalize;
 	g_type_class_add_private (klass, sizeof (ValaPropertyPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_property_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_property_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_property_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_property_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_PROPERTY_TYPE, g_param_spec_object ("property-type", "property-type", "property-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_GET_ACCESSOR, g_param_spec_object ("get-accessor", "get-accessor", "get-accessor", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_SET_ACCESSOR, g_param_spec_object ("set-accessor", "set-accessor", "set-accessor", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NOTIFY, g_param_spec_boolean ("notify", "notify", "notify", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NO_ACCESSOR_METHOD, g_param_spec_boolean ("no-accessor-method", "no-accessor-method", "no-accessor-method", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INTERFACE_ONLY, g_param_spec_boolean ("interface-only", "interface-only", "interface-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_FIELD, g_param_spec_object ("field", "field", "field", VALA_TYPE_FIELD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NICK, g_param_spec_string ("nick", "nick", "nick", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BLURB, g_param_spec_string ("blurb", "blurb", "blurb", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -879,26 +716,26 @@ static void vala_property_instance_init (ValaProperty * self) {
 }
 
 
-static void vala_property_finalize (GObject * obj) {
+static void vala_property_finalize (ValaCodeNode* obj) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (obj);
-	(self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL)));
-	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL)));
-	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
-	(self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL)));
-	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	(self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (vala_code_node_unref (self->priv->_get_accessor), NULL)));
+	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (vala_code_node_unref (self->priv->_set_accessor), NULL)));
+	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)));
+	(self->priv->_field == NULL ? NULL : (self->priv->_field = (vala_code_node_unref (self->priv->_field), NULL)));
+	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
 	self->priv->_nick = (g_free (self->priv->_nick), NULL);
 	self->priv->_blurb = (g_free (self->priv->_blurb), NULL);
-	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL)));
-	G_OBJECT_CLASS (vala_property_parent_class)->finalize (obj);
+	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (vala_code_node_unref (self->priv->_base_interface_property), NULL)));
+	VALA_CODE_NODE_CLASS (vala_property_parent_class)->finalize (obj);
 }
 
 
 GType vala_property_get_type (void) {
 	static GType vala_property_type_id = 0;
 	if (vala_property_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProperty), 0, (GInstanceInitFunc) vala_property_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProperty), 0, (GInstanceInitFunc) vala_property_instance_init, NULL };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_property_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_property_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaProperty", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_property_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
