@@ -23,6 +23,7 @@
 #include <vala/valascanner.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -38,8 +39,7 @@ struct _ValaScannerPrivate {
 
 #define VALA_SCANNER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SCANNER, ValaScannerPrivate))
 enum  {
-	VALA_SCANNER_DUMMY_PROPERTY,
-	VALA_SCANNER_SOURCE_FILE
+	VALA_SCANNER_DUMMY_PROPERTY
 };
 static gboolean vala_scanner_is_ident_char (ValaScanner* self, gchar c);
 static ValaTokenType vala_scanner_get_identifier_or_keyword (ValaScanner* self, gchar* begin, gint len);
@@ -49,30 +49,28 @@ static gboolean vala_scanner_comment (ValaScanner* self);
 static void vala_scanner_space (ValaScanner* self);
 static void vala_scanner_push_comment (ValaScanner* self, const char* comment_item, gboolean file_comment);
 static void vala_scanner_set_source_file (ValaScanner* self, ValaSourceFile* value);
-static GObject * vala_scanner_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_scanner_parent_class = NULL;
-static void vala_scanner_finalize (GObject * obj);
+static void vala_scanner_finalize (ValaScanner* obj);
 
 
 
+ValaScanner* vala_scanner_construct (GType object_type, ValaSourceFile* source_file) {
+	ValaScanner* self;
+	gchar* begin;
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (source_file), NULL);
+	self = ((ValaScanner*) (g_type_create_instance (object_type)));
+	vala_scanner_set_source_file (self, source_file);
+	begin = vala_source_file_get_mapped_contents (source_file);
+	self->priv->end = begin + vala_source_file_get_mapped_length (source_file);
+	self->priv->current = begin;
+	self->priv->line = 1;
+	self->priv->column = 1;
+	return self;
+}
+
+
 ValaScanner* vala_scanner_new (ValaSourceFile* source_file) {
-	GParameter * __params;
-	GParameter * __params_it;
-	ValaScanner * self;
-	g_return_val_if_fail (VALA_IS_SOURCE_FILE (source_file), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	__params_it->name = "source-file";
-	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, source_file);
-	__params_it++;
-	self = g_object_newv (VALA_TYPE_SCANNER, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return vala_scanner_construct (VALA_TYPE_SCANNER, source_file);
 }
 
 
@@ -618,7 +616,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 								}
 							}
 						} else {
-							if (self->priv->current < self->priv->end && self->priv->current[0] == '.') {
+							if (self->priv->current < self->priv->end - 1 && self->priv->current[0] == '.' && g_ascii_isdigit (self->priv->current[1])) {
 								self->priv->current++;
 								while (self->priv->current < self->priv->end && g_ascii_isdigit (self->priv->current[0])) {
 									self->priv->current++;
@@ -943,7 +941,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 												ValaSourceReference* _tmp6;
 												_tmp6 = NULL;
 												vala_report_error ((_tmp6 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), "invalid UTF-8 character");
-												(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
+												(_tmp6 == NULL ? NULL : (_tmp6 = (vala_source_reference_unref (_tmp6), NULL)));
 											}
 										}
 									}
@@ -954,7 +952,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 									ValaSourceReference* _tmp7;
 									_tmp7 = NULL;
 									vala_report_error ((_tmp7 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), "syntax error, expected \"\"\"");
-									(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
+									(_tmp7 == NULL ? NULL : (_tmp7 = (vala_source_reference_unref (_tmp7), NULL)));
 								}
 								break;
 							} else {
@@ -992,7 +990,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 										ValaSourceReference* _tmp8;
 										_tmp8 = NULL;
 										vala_report_error ((_tmp8 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), "invalid UTF-8 character");
-										(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
+										(_tmp8 == NULL ? NULL : (_tmp8 = (vala_source_reference_unref (_tmp8), NULL)));
 									}
 								}
 							}
@@ -1006,7 +1004,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 							_tmp9 = NULL;
 							vala_report_error ((_tmp9 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars)), (_tmp10 = g_strdup_printf ("syntax error, expected %c", ((gint) (begin[0])))));
 							_tmp10 = (g_free (_tmp10), NULL);
-							(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
+							(_tmp9 == NULL ? NULL : (_tmp9 = (vala_source_reference_unref (_tmp9), NULL)));
 						}
 						break;
 					} while (0); else
@@ -1018,13 +1016,13 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 							self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
 							_tmp11 = NULL;
 							vala_report_error ((_tmp11 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "syntax error, unexpected character");
-							(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
+							(_tmp11 == NULL ? NULL : (_tmp11 = (vala_source_reference_unref (_tmp11), NULL)));
 						} else {
 							ValaSourceReference* _tmp12;
 							self->priv->current++;
 							_tmp12 = NULL;
 							vala_report_error ((_tmp12 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "invalid UTF-8 character");
-							(_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL)));
+							(_tmp12 == NULL ? NULL : (_tmp12 = (vala_source_reference_unref (_tmp12), NULL)));
 						}
 						self->priv->column++;
 						return vala_scanner_read_token (self, &(*token_begin), &(*token_end));
@@ -1119,7 +1117,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 			ValaSourceReference* _tmp2;
 			_tmp2 = NULL;
 			vala_report_error ((_tmp2 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column)), "syntax error, expected */");
-			(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+			(_tmp2 == NULL ? NULL : (_tmp2 = (vala_source_reference_unref (_tmp2), NULL)));
 			return TRUE;
 		}
 		_tmp4 = NULL;
@@ -1202,94 +1200,151 @@ static void vala_scanner_set_source_file (ValaScanner* self, ValaSourceFile* val
 	g_return_if_fail (VALA_IS_SCANNER (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_source_file = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "source-file");
+	self->priv->_source_file = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_file_ref (_tmp1))), (self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL))), _tmp2);
 }
 
 
-static GObject * vala_scanner_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
-	GObject * obj;
-	ValaScannerClass * klass;
-	GObjectClass * parent_class;
-	ValaScanner * self;
-	klass = VALA_SCANNER_CLASS (g_type_class_peek (VALA_TYPE_SCANNER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	self = VALA_SCANNER (obj);
-	{
-		gchar* begin;
-		begin = vala_source_file_get_mapped_contents (self->priv->_source_file);
-		self->priv->end = begin + vala_source_file_get_mapped_length (self->priv->_source_file);
-		self->priv->current = begin;
-		self->priv->line = 1;
-		self->priv->column = 1;
-	}
-	return obj;
+static void vala_value_scanner_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
 }
 
 
-static void vala_scanner_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaScanner * self;
-	self = VALA_SCANNER (object);
-	switch (property_id) {
-		case VALA_SCANNER_SOURCE_FILE:
-		g_value_set_object (value, vala_scanner_get_source_file (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_scanner_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_scanner_unref (value->data[0].v_pointer);
 	}
 }
 
 
-static void vala_scanner_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaScanner * self;
-	self = VALA_SCANNER (object);
-	switch (property_id) {
-		case VALA_SCANNER_SOURCE_FILE:
-		vala_scanner_set_source_file (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_scanner_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_scanner_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_scanner_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_scanner_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaScanner* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_scanner_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaScanner** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_scanner_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_scanner (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecScanner* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_SCANNER), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_scanner (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_SCANNER), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_scanner (GValue* value, gpointer v_object) {
+	ValaScanner* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_SCANNER));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_SCANNER));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_scanner_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_scanner_unref (old);
 	}
 }
 
 
 static void vala_scanner_class_init (ValaScannerClass * klass) {
 	vala_scanner_parent_class = g_type_class_peek_parent (klass);
+	VALA_SCANNER_CLASS (klass)->finalize = vala_scanner_finalize;
 	g_type_class_add_private (klass, sizeof (ValaScannerPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_scanner_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_scanner_set_property;
-	G_OBJECT_CLASS (klass)->constructor = vala_scanner_constructor;
-	G_OBJECT_CLASS (klass)->finalize = vala_scanner_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SCANNER_SOURCE_FILE, g_param_spec_object ("source-file", "source-file", "source-file", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
 static void vala_scanner_instance_init (ValaScanner * self) {
 	self->priv = VALA_SCANNER_GET_PRIVATE (self);
+	self->ref_count = 1;
 }
 
 
-static void vala_scanner_finalize (GObject * obj) {
+static void vala_scanner_finalize (ValaScanner* obj) {
 	ValaScanner * self;
 	self = VALA_SCANNER (obj);
-	(self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (g_object_unref (self->priv->_source_file), NULL)));
+	(self->priv->_source_file == NULL ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL)));
 	self->priv->_comment = (g_free (self->priv->_comment), NULL);
-	G_OBJECT_CLASS (vala_scanner_parent_class)->finalize (obj);
 }
 
 
 GType vala_scanner_get_type (void) {
 	static GType vala_scanner_type_id = 0;
 	if (vala_scanner_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaScannerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_scanner_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaScanner), 0, (GInstanceInitFunc) vala_scanner_instance_init };
-		vala_scanner_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaScanner", &g_define_type_info, 0);
+		static const GTypeValueTable g_define_type_value_table = { vala_value_scanner_init, vala_value_scanner_free_value, vala_value_scanner_copy_value, vala_value_scanner_peek_pointer, "p", vala_value_scanner_collect_value, "p", vala_value_scanner_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaScannerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_scanner_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaScanner), 0, (GInstanceInitFunc) vala_scanner_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_scanner_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaScanner", &g_define_type_info, &g_define_type_fundamental_info, 0);
 	}
 	return vala_scanner_type_id;
 }
 
 
+gpointer vala_scanner_ref (gpointer instance) {
+	ValaScanner* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_scanner_unref (gpointer instance) {
+	ValaScanner* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_SCANNER_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 
 
