@@ -25,16 +25,12 @@
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valadelegate.h>
+#include <vala/valamethod.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
-#include <vala/valareferencetype.h>
-#include <vala/valaclass.h>
-#include <vala/valaclassinstancetype.h>
-#include <vala/valainterfaceinstancetype.h>
-#include <vala/valainterface.h>
+#include <vala/valadelegate.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
@@ -43,8 +39,9 @@
 
 struct _ValaSignalPrivate {
 	gboolean _has_emitter;
+	gboolean _is_virtual;
 	GeeList* parameters;
-	ValaDelegate* generated_delegate;
+	ValaMethod* generated_method;
 	char* cname;
 	gboolean lock_used;
 	ValaDataType* _return_type;
@@ -52,9 +49,7 @@ struct _ValaSignalPrivate {
 
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
-	VALA_SIGNAL_DUMMY_PROPERTY,
-	VALA_SIGNAL_RETURN_TYPE,
-	VALA_SIGNAL_HAS_EMITTER
+	VALA_SIGNAL_DUMMY_PROPERTY
 };
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -63,7 +58,7 @@ static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_signal_parent_class = NULL;
 static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
-static void vala_signal_dispose (GObject * obj);
+static void vala_signal_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -76,19 +71,25 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source      reference to source code
  * @return            newly created signal
  */
-ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
-	ValaSignal * self;
+ValaSignal* vala_signal_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	ValaSignal* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
+	self = ((ValaSignal*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (VALA_MEMBER (self)));
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_signal_set_return_type (self, return_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
 
+ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
+	return vala_signal_construct (VALA_TYPE_SIGNAL, name, return_type, source_reference);
+}
+
+
 /**
  * Appends parameter to signal handler.
  *
@@ -98,7 +99,7 @@ void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	/* default C parameter position*/
-	vala_formal_parameter_set_cparameter_position (param, ((double) gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1));
+	vala_formal_parameter_set_cparameter_position (param, ((double) (gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1)));
 	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
@@ -108,7 +109,7 @@ void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 
 GeeList* vala_signal_get_parameters (ValaSignal* self) {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->parameters));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->parameters));
 }
 
 
@@ -117,49 +118,40 @@ GeeList* vala_signal_get_parameters (ValaSignal* self) {
  *
  * @return delegate
  */
-ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
-	ValaDelegate* _tmp3;
+ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_type) {
+	ValaDelegate* generated_delegate;
+	ValaDataType* sender_param_type;
+	ValaFormalParameter* sender_param;
+	ValaDelegate* _tmp1;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	/* parent_symbol is null for D-Bus signals*/
-	if (self->priv->generated_delegate == NULL && vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) != NULL) {
-		ValaDelegate* _tmp0;
-		ValaReferenceType* sender_type;
-		ValaFormalParameter* sender_param;
-		_tmp0 = NULL;
-		self->priv->generated_delegate = (_tmp0 = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL))), _tmp0);
-		vala_delegate_set_has_target (self->priv->generated_delegate, TRUE);
-		sender_type = NULL;
-		if (VALA_IS_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
-			ValaReferenceType* _tmp1;
-			_tmp1 = NULL;
-			sender_type = (_tmp1 = VALA_REFERENCE_TYPE (vala_class_instance_type_new (VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp1);
-		} else {
-			ValaReferenceType* _tmp2;
-			_tmp2 = NULL;
-			sender_type = (_tmp2 = VALA_REFERENCE_TYPE (vala_interface_instance_type_new (VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp2);
-		}
-		sender_param = vala_formal_parameter_new ("sender", VALA_DATA_TYPE (sender_type), NULL);
-		vala_delegate_add_parameter (self->priv->generated_delegate, sender_param);
-		{
-			GeeList* param_collection;
-			GeeIterator* param_it;
-			param_collection = self->priv->parameters;
-			param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-			while (gee_iterator_next (param_it)) {
-				ValaFormalParameter* param;
-				param = ((ValaFormalParameter*) gee_iterator_get (param_it));
-				{
-					vala_delegate_add_parameter (self->priv->generated_delegate, param);
-					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-				}
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (sender_type), NULL);
+	generated_delegate = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL);
+	vala_delegate_set_has_target (generated_delegate, TRUE);
+	/* sender parameter is never null and doesn't own its value*/
+	sender_param_type = vala_data_type_copy (sender_type);
+	vala_data_type_set_value_owned (sender_param_type, FALSE);
+	vala_data_type_set_nullable (sender_param_type, FALSE);
+	sender_param = vala_formal_parameter_new ("_sender", sender_param_type, NULL);
+	vala_delegate_add_parameter (generated_delegate, sender_param);
+	{
+		GeeList* param_collection;
+		int param_it;
+		param_collection = self->priv->parameters;
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+			{
+				ValaFormalParameter* _tmp0;
+				_tmp0 = NULL;
+				vala_delegate_add_parameter (generated_delegate, (_tmp0 = vala_formal_parameter_copy (param)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
-			(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 		}
-		(sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL)));
-		(sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL)));
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->generated_delegate, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), NULL, VALA_SYMBOL (generated_delegate));
+	_tmp1 = NULL;
+	return (_tmp1 = generated_delegate, (sender_param_type == NULL ? NULL : (sender_param_type = (vala_code_node_unref (sender_param_type), NULL))), (sender_param == NULL ? NULL : (sender_param = (vala_code_node_unref (sender_param), NULL))), _tmp1);
 }
 
 
@@ -169,17 +161,15 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
  * @return the name to be used in C code
  */
 char* vala_signal_get_cname (ValaSignal* self) {
-	const char* _tmp2;
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	if (self->priv->cname == NULL) {
-		char* _tmp1;
-		const char* _tmp0;
-		_tmp1 = NULL;
+		char* _tmp0;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp1 = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		self->priv->cname = (_tmp0 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
 	}
-	_tmp2 = NULL;
-	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->cname, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 }
 
 
@@ -199,7 +189,7 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname) {
  *
  * @return string literal to be used in C code
  */
-ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
+ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self, const char* detail) {
 	GString* str;
 	const char* _tmp0;
 	char* i;
@@ -222,6 +212,10 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
 		_tmp1 = NULL;
 		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
 	}
+	if (detail != NULL) {
+		g_string_append (str, "::");
+		g_string_append (str, detail);
+	}
 	g_string_append_c (str, '"');
 	_tmp3 = NULL;
 	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
@@ -244,18 +238,16 @@ static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 	vala_code_node_accept (VALA_CODE_NODE (vala_signal_get_return_type (self)), visitor);
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 }
 
@@ -273,12 +265,12 @@ void vala_signal_process_attributes (ValaSignal* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "HasEmitter") == 0) {
 					vala_signal_set_has_emitter (self, TRUE);
 				}
-				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
 			}
 		}
 	}
@@ -310,6 +302,36 @@ static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old
 }
 
 
+ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
+	ValaMethod* _tmp1;
+	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
+	g_assert (self->priv->_is_virtual);
+	if (self->priv->generated_method == NULL) {
+		ValaMethod* _tmp0;
+		_tmp0 = NULL;
+		self->priv->generated_method = (_tmp0 = vala_method_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_signal_get_return_type (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->generated_method == NULL ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL))), _tmp0);
+		vala_method_set_is_virtual (self->priv->generated_method, TRUE);
+		vala_method_set_vfunc_name (self->priv->generated_method, vala_symbol_get_name (VALA_SYMBOL (self)));
+		{
+			GeeList* param_collection;
+			int param_it;
+			param_collection = self->priv->parameters;
+			for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+				ValaFormalParameter* param;
+				param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+				{
+					vala_method_add_parameter (self->priv->generated_method, param);
+					(param == NULL ? NULL : (param = (vala_code_node_unref (param), NULL)));
+				}
+			}
+		}
+		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), NULL, VALA_SYMBOL (self->priv->generated_method));
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->generated_method, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+}
+
+
 ValaDataType* vala_signal_get_return_type (ValaSignal* self) {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	return self->priv->_return_type;
@@ -322,7 +344,7 @@ void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
+	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_type), VALA_CODE_NODE (self));
 }
 
@@ -339,51 +361,25 @@ void vala_signal_set_has_emitter (ValaSignal* self, gboolean value) {
 }
 
 
-static void vala_signal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaSignal * self;
-	self = VALA_SIGNAL (object);
-	switch (property_id) {
-		case VALA_SIGNAL_RETURN_TYPE:
-		g_value_set_object (value, vala_signal_get_return_type (self));
-		break;
-		case VALA_SIGNAL_HAS_EMITTER:
-		g_value_set_boolean (value, vala_signal_get_has_emitter (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+gboolean vala_signal_get_is_virtual (ValaSignal* self) {
+	g_return_val_if_fail (VALA_IS_SIGNAL (self), FALSE);
+	return self->priv->_is_virtual;
 }
 
 
-static void vala_signal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaSignal * self;
-	self = VALA_SIGNAL (object);
-	switch (property_id) {
-		case VALA_SIGNAL_RETURN_TYPE:
-		vala_signal_set_return_type (self, g_value_get_object (value));
-		break;
-		case VALA_SIGNAL_HAS_EMITTER:
-		vala_signal_set_has_emitter (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+void vala_signal_set_is_virtual (ValaSignal* self, gboolean value) {
+	g_return_if_fail (VALA_IS_SIGNAL (self));
+	self->priv->_is_virtual = value;
 }
 
 
 static void vala_signal_class_init (ValaSignalClass * klass) {
 	vala_signal_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_signal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSignalPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_signal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_signal_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_signal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_signal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_signal_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_signal_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_HAS_EMITTER, g_param_spec_boolean ("has-emitter", "has-emitter", "has-emitter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -394,28 +390,28 @@ static void vala_signal_vala_lockable_interface_init (ValaLockableIface * iface)
 }
 
 
-static void vala_signal_init (ValaSignal * self) {
+static void vala_signal_instance_init (ValaSignal * self) {
 	self->priv = VALA_SIGNAL_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 	self->priv->lock_used = FALSE;
 }
 
 
-static void vala_signal_dispose (GObject * obj) {
+static void vala_signal_finalize (ValaCodeNode* obj) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (obj);
-	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	(self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL)));
+	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (gee_collection_object_unref (self->priv->parameters), NULL)));
+	(self->priv->generated_method == NULL ? NULL : (self->priv->generated_method = (vala_code_node_unref (self->priv->generated_method), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
-	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
-	G_OBJECT_CLASS (vala_signal_parent_class)->dispose (obj);
+	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (vala_code_node_unref (self->priv->_return_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_signal_parent_class)->finalize (obj);
 }
 
 
 GType vala_signal_get_type (void) {
 	static GType vala_signal_type_id = 0;
-	if (G_UNLIKELY (vala_signal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_init };
+	if (vala_signal_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_instance_init, NULL };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_signal_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
