@@ -34,14 +34,13 @@ struct _ValaSizeofExpressionPrivate {
 
 #define VALA_SIZEOF_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIZEOF_EXPRESSION, ValaSizeofExpressionPrivate))
 enum  {
-	VALA_SIZEOF_EXPRESSION_DUMMY_PROPERTY,
-	VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE
+	VALA_SIZEOF_EXPRESSION_DUMMY_PROPERTY
 };
 static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_sizeof_expression_real_is_pure (ValaExpression* base);
 static void vala_sizeof_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_sizeof_expression_parent_class = NULL;
-static void vala_sizeof_expression_finalize (GObject * obj);
+static void vala_sizeof_expression_finalize (ValaCodeNode* obj);
 
 
 
@@ -52,17 +51,22 @@ static void vala_sizeof_expression_finalize (GObject * obj);
  * @param source reference to source code
  * @return       newly created sizeof expression
  */
-ValaSizeofExpression* vala_sizeof_expression_new (ValaDataType* type, ValaSourceReference* source) {
-	ValaSizeofExpression * self;
+ValaSizeofExpression* vala_sizeof_expression_construct (GType object_type, ValaDataType* type, ValaSourceReference* source) {
+	ValaSizeofExpression* self;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_SIZEOF_EXPRESSION, 0, NULL);
+	self = ((ValaSizeofExpression*) (g_type_create_instance (object_type)));
 	vala_sizeof_expression_set_type_reference (self, type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaSizeofExpression* vala_sizeof_expression_new (ValaDataType* type, ValaSourceReference* source) {
+	return vala_sizeof_expression_construct (VALA_TYPE_SIZEOF_EXPRESSION, type, source);
+}
+
+
 static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSizeofExpression * self;
 	self = VALA_SIZEOF_EXPRESSION (base);
@@ -103,50 +107,18 @@ void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, Vala
 	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
-	g_object_notify (((GObject *) (self)), "type-reference");
-}
-
-
-static void vala_sizeof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaSizeofExpression * self;
-	self = VALA_SIZEOF_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE:
-		g_value_set_object (value, vala_sizeof_expression_get_type_reference (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_sizeof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaSizeofExpression * self;
-	self = VALA_SIZEOF_EXPRESSION (object);
-	switch (property_id) {
-		case VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE:
-		vala_sizeof_expression_set_type_reference (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_sizeof_expression_class_init (ValaSizeofExpressionClass * klass) {
 	vala_sizeof_expression_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_sizeof_expression_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSizeofExpressionPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_sizeof_expression_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_sizeof_expression_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_sizeof_expression_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_sizeof_expression_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_sizeof_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_sizeof_expression_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -155,18 +127,18 @@ static void vala_sizeof_expression_instance_init (ValaSizeofExpression * self) {
 }
 
 
-static void vala_sizeof_expression_finalize (GObject * obj) {
+static void vala_sizeof_expression_finalize (ValaCodeNode* obj) {
 	ValaSizeofExpression * self;
 	self = VALA_SIZEOF_EXPRESSION (obj);
-	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
-	G_OBJECT_CLASS (vala_sizeof_expression_parent_class)->finalize (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)));
+	VALA_CODE_NODE_CLASS (vala_sizeof_expression_parent_class)->finalize (obj);
 }
 
 
 GType vala_sizeof_expression_get_type (void) {
 	static GType vala_sizeof_expression_type_id = 0;
 	if (vala_sizeof_expression_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSizeofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_sizeof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSizeofExpression), 0, (GInstanceInitFunc) vala_sizeof_expression_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSizeofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_sizeof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSizeofExpression), 0, (GInstanceInitFunc) vala_sizeof_expression_instance_init, NULL };
 		vala_sizeof_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaSizeofExpression", &g_define_type_info, 0);
 	}
 	return vala_sizeof_expression_type_id;
