@@ -22,6 +22,7 @@
 
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
+#include <gobject/gvaluecollector.h>
 
 
 
@@ -34,18 +35,13 @@ struct _ValaSourceReferencePrivate {
 	gint _last_column;
 	char* _comment;
 };
+
 #define VALA_SOURCE_REFERENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferencePrivate))
 enum  {
-	VALA_SOURCE_REFERENCE_DUMMY_PROPERTY,
-	VALA_SOURCE_REFERENCE_FILE,
-	VALA_SOURCE_REFERENCE_FIRST_LINE,
-	VALA_SOURCE_REFERENCE_FIRST_COLUMN,
-	VALA_SOURCE_REFERENCE_LAST_LINE,
-	VALA_SOURCE_REFERENCE_LAST_COLUMN,
-	VALA_SOURCE_REFERENCE_COMMENT
+	VALA_SOURCE_REFERENCE_DUMMY_PROPERTY
 };
 static gpointer vala_source_reference_parent_class = NULL;
-static void vala_source_reference_dispose (GObject * obj);
+static void vala_source_reference_finalize (ValaSourceReference* obj);
 
 
 
@@ -59,10 +55,10 @@ static void vala_source_reference_dispose (GObject * obj);
  * @param last_column  last column number
  * @return             newly created source reference
  */
-ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column) {
-	ValaSourceReference * self;
+ValaSourceReference* vala_source_reference_construct (GType object_type, ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column) {
+	ValaSourceReference* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
-	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
+	self = ((ValaSourceReference*) (g_type_create_instance (object_type)));
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
 	vala_source_reference_set_first_column (self, _first_column);
@@ -72,6 +68,11 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
 }
 
 
+ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column) {
+	return vala_source_reference_construct (VALA_TYPE_SOURCE_REFERENCE, _file, _first_line, _first_column, _last_line, _last_column);
+}
+
+
 /**
  * Creates a new commented source reference.
  *
@@ -83,10 +84,10 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
  * @param comment      code comment
  * @return             newly created source reference
  */
-ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment) {
-	ValaSourceReference * self;
+ValaSourceReference* vala_source_reference_construct_with_comment (GType object_type, ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment) {
+	ValaSourceReference* self;
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
-	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
+	self = ((ValaSourceReference*) (g_type_create_instance (object_type)));
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
 	vala_source_reference_set_first_column (self, _first_column);
@@ -97,14 +98,23 @@ ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _fi
 }
 
 
+ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment) {
+	return vala_source_reference_construct_with_comment (VALA_TYPE_SOURCE_REFERENCE, _file, _first_line, _first_column, _last_line, _last_column, _comment);
+}
+
+
 /**
  * Returns a string representation of this source reference.
  *
  * @return human-readable string
  */
 char* vala_source_reference_to_string (ValaSourceReference* self) {
+	char* _tmp0;
+	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
-	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = (g_strdup_printf ("%s:%d.%d-%d.%d", (_tmp0 = vala_source_file_get_relative_filename (self->priv->_file)), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -168,7 +178,7 @@ void vala_source_reference_set_last_column (ValaSourceReference* self, gint valu
 }
 
 
-char* vala_source_reference_get_comment (ValaSourceReference* self) {
+const char* vala_source_reference_get_comment (ValaSourceReference* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
 	return self->priv->_comment;
 }
@@ -184,101 +194,146 @@ void vala_source_reference_set_comment (ValaSourceReference* self, const char* v
 }
 
 
-static void vala_source_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaSourceReference * self;
-	self = VALA_SOURCE_REFERENCE (object);
-	switch (property_id) {
-		case VALA_SOURCE_REFERENCE_FILE:
-		g_value_set_object (value, vala_source_reference_get_file (self));
-		break;
-		case VALA_SOURCE_REFERENCE_FIRST_LINE:
-		g_value_set_int (value, vala_source_reference_get_first_line (self));
-		break;
-		case VALA_SOURCE_REFERENCE_FIRST_COLUMN:
-		g_value_set_int (value, vala_source_reference_get_first_column (self));
-		break;
-		case VALA_SOURCE_REFERENCE_LAST_LINE:
-		g_value_set_int (value, vala_source_reference_get_last_line (self));
-		break;
-		case VALA_SOURCE_REFERENCE_LAST_COLUMN:
-		g_value_set_int (value, vala_source_reference_get_last_column (self));
-		break;
-		case VALA_SOURCE_REFERENCE_COMMENT:
-		g_value_set_string (value, vala_source_reference_get_comment (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_source_reference_init (GValue* value) {
+	value->data[0].v_pointer = NULL;
+}
+
+
+static void vala_value_source_reference_free_value (GValue* value) {
+	if (value->data[0].v_pointer) {
+		vala_source_reference_unref (value->data[0].v_pointer);
 	}
 }
 
 
-static void vala_source_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaSourceReference * self;
-	self = VALA_SOURCE_REFERENCE (object);
-	switch (property_id) {
-		case VALA_SOURCE_REFERENCE_FILE:
-		vala_source_reference_set_file (self, g_value_get_object (value));
-		break;
-		case VALA_SOURCE_REFERENCE_FIRST_LINE:
-		vala_source_reference_set_first_line (self, g_value_get_int (value));
-		break;
-		case VALA_SOURCE_REFERENCE_FIRST_COLUMN:
-		vala_source_reference_set_first_column (self, g_value_get_int (value));
-		break;
-		case VALA_SOURCE_REFERENCE_LAST_LINE:
-		vala_source_reference_set_last_line (self, g_value_get_int (value));
-		break;
-		case VALA_SOURCE_REFERENCE_LAST_COLUMN:
-		vala_source_reference_set_last_column (self, g_value_get_int (value));
-		break;
-		case VALA_SOURCE_REFERENCE_COMMENT:
-		vala_source_reference_set_comment (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
+static void vala_value_source_reference_copy_value (const GValue* src_value, GValue* dest_value) {
+	if (src_value->data[0].v_pointer) {
+		dest_value->data[0].v_pointer = vala_source_reference_ref (src_value->data[0].v_pointer);
+	} else {
+		dest_value->data[0].v_pointer = NULL;
+	}
+}
+
+
+static gpointer vala_value_source_reference_peek_pointer (const GValue* value) {
+	return value->data[0].v_pointer;
+}
+
+
+static gchar* vala_value_source_reference_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	if (collect_values[0].v_pointer) {
+		ValaSourceReference* object;
+		object = value->data[0].v_pointer;
+		if (object->parent_instance.g_class == NULL) {
+			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		}
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	return NULL;
+}
+
+
+static gchar* vala_value_source_reference_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
+	ValaSourceReference** object_p;
+	object_p = collect_values[0].v_pointer;
+	if (!object_p) {
+	}
+	if (!value->data[0].v_pointer) {
+		*object_p = NULL;
+	} else if (collect_flags && G_VALUE_NOCOPY_CONTENTS) {
+		*object_p = value->data[0].v_pointer;
+	} else {
+		*object_p = vala_source_reference_ref (value->data[0].v_pointer);
+	}
+	return NULL;
+}
+
+
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
+	ValaParamSpecSourceReference* spec;
+	g_return_val_if_fail (g_type_is_a (object_type, VALA_TYPE_SOURCE_REFERENCE), NULL);
+	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
+	G_PARAM_SPEC (spec)->value_type = object_type;
+	return G_PARAM_SPEC (spec);
+}
+
+
+gpointer vala_value_get_source_reference (const GValue* value) {
+	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_SOURCE_REFERENCE), NULL);
+	return value->data[0].v_pointer;
+}
+
+
+void vala_value_set_source_reference (GValue* value, gpointer v_object) {
+	ValaSourceReference* old;
+	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, VALA_TYPE_SOURCE_REFERENCE));
+	old = value->data[0].v_pointer;
+	if (v_object) {
+		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, VALA_TYPE_SOURCE_REFERENCE));
+		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
+		value->data[0].v_pointer = v_object;
+		vala_source_reference_ref (value->data[0].v_pointer);
+	} else {
+		value->data[0].v_pointer = NULL;
+	}
+	if (old) {
+		vala_source_reference_unref (old);
 	}
 }
 
 
 static void vala_source_reference_class_init (ValaSourceReferenceClass * klass) {
 	vala_source_reference_parent_class = g_type_class_peek_parent (klass);
+	VALA_SOURCE_REFERENCE_CLASS (klass)->finalize = vala_source_reference_finalize;
 	g_type_class_add_private (klass, sizeof (ValaSourceReferencePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_source_reference_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_source_reference_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_source_reference_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_FILE, g_param_spec_object ("file", "file", "file", VALA_TYPE_SOURCE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_FIRST_LINE, g_param_spec_int ("first-line", "first-line", "first-line", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_FIRST_COLUMN, g_param_spec_int ("first-column", "first-column", "first-column", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_LAST_LINE, g_param_spec_int ("last-line", "last-line", "last-line", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_LAST_COLUMN, g_param_spec_int ("last-column", "last-column", "last-column", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_REFERENCE_COMMENT, g_param_spec_string ("comment", "comment", "comment", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_source_reference_init (ValaSourceReference * self) {
+static void vala_source_reference_instance_init (ValaSourceReference * self) {
 	self->priv = VALA_SOURCE_REFERENCE_GET_PRIVATE (self);
+	self->ref_count = 1;
 }
 
 
-static void vala_source_reference_dispose (GObject * obj) {
+static void vala_source_reference_finalize (ValaSourceReference* obj) {
 	ValaSourceReference * self;
 	self = VALA_SOURCE_REFERENCE (obj);
 	self->priv->_comment = (g_free (self->priv->_comment), NULL);
-	G_OBJECT_CLASS (vala_source_reference_parent_class)->dispose (obj);
 }
 
 
 GType vala_source_reference_get_type (void) {
 	static GType vala_source_reference_type_id = 0;
-	if (G_UNLIKELY (vala_source_reference_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceReference), 0, (GInstanceInitFunc) vala_source_reference_init };
-		vala_source_reference_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaSourceReference", &g_define_type_info, 0);
+	if (vala_source_reference_type_id == 0) {
+		static const GTypeValueTable g_define_type_value_table = { vala_value_source_reference_init, vala_value_source_reference_free_value, vala_value_source_reference_copy_value, vala_value_source_reference_peek_pointer, "p", vala_value_source_reference_collect_value, "p", vala_value_source_reference_lcopy_value };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceReference), 0, (GInstanceInitFunc) vala_source_reference_instance_init, &g_define_type_value_table };
+		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
+		vala_source_reference_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValaSourceReference", &g_define_type_info, &g_define_type_fundamental_info, 0);
 	}
 	return vala_source_reference_type_id;
 }
 
 
+gpointer vala_source_reference_ref (gpointer instance) {
+	ValaSourceReference* self;
+	self = instance;
+	g_atomic_int_inc (&self->ref_count);
+	return instance;
+}
+
+
+void vala_source_reference_unref (gpointer instance) {
+	ValaSourceReference* self;
+	self = instance;
+	if (g_atomic_int_dec_and_test (&self->ref_count)) {
+		VALA_SOURCE_REFERENCE_GET_CLASS (self)->finalize (self);
+		g_type_free_instance (((GTypeInstance *) (self)));
+	}
+}
+
+
 
 
