@@ -34,14 +34,14 @@ struct _ValaStringLiteralPrivate {
 
 #define VALA_STRING_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRING_LITERAL, ValaStringLiteralPrivate))
 enum  {
-	VALA_STRING_LITERAL_DUMMY_PROPERTY,
-	VALA_STRING_LITERAL_VALUE
+	VALA_STRING_LITERAL_DUMMY_PROPERTY
 };
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_string_literal_real_is_pure (ValaExpression* base);
+static gboolean vala_string_literal_real_is_non_null (ValaExpression* base);
 static char* vala_string_literal_real_to_string (ValaCodeNode* base);
 static gpointer vala_string_literal_parent_class = NULL;
-static void vala_string_literal_finalize (GObject * obj);
+static void vala_string_literal_finalize (ValaCodeNode* obj);
 
 
 
@@ -52,34 +52,41 @@ static void vala_string_literal_finalize (GObject * obj);
  * @param source reference to source code
  * @return       newly created string literal
  */
-ValaStringLiteral* vala_string_literal_new (const char* value, ValaSourceReference* source_reference) {
-	ValaStringLiteral * self;
+ValaStringLiteral* vala_string_literal_construct (GType object_type, const char* value, ValaSourceReference* source_reference) {
+	ValaStringLiteral* self;
 	g_return_val_if_fail (value != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_STRING_LITERAL, 0, NULL);
+	self = ((ValaStringLiteral*) (g_type_create_instance (object_type)));
 	vala_string_literal_set_value (self, value);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
+ValaStringLiteral* vala_string_literal_new (const char* value, ValaSourceReference* source_reference) {
+	return vala_string_literal_construct (VALA_TYPE_STRING_LITERAL, value, source_reference);
+}
+
+
 /**
  * Evaluates the literal string value.
  *
  * @return the unescaped string
  */
 char* vala_string_literal_eval (ValaStringLiteral* self) {
-	char* noquotes;
 	char* _tmp1;
+	char* noquotes;
+	char* _tmp2;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	if (self->priv->_value == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
-	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) (1))), ((gulong) (((guint) ((g_utf8_strlen (self->priv->_value, -1) - 2))))));
-	/* unescape string */
 	_tmp1 = NULL;
-	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
+	noquotes = (_tmp1 = g_utf8_offset_to_pointer (self->priv->_value, ((glong) (1))), g_strndup (_tmp1, g_utf8_offset_to_pointer (_tmp1, ((glong) (((guint) ((g_utf8_strlen (self->priv->_value, -1) - 2)))))) - _tmp1));
+	/* unescape string */
+	_tmp2 = NULL;
+	return (_tmp2 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp2);
 }
 
 
@@ -99,6 +106,13 @@ static gboolean vala_string_literal_real_is_pure (ValaExpression* base) {
 }
 
 
+static gboolean vala_string_literal_real_is_non_null (ValaExpression* base) {
+	ValaStringLiteral * self;
+	self = VALA_STRING_LITERAL (base);
+	return TRUE;
+}
+
+
 static char* vala_string_literal_real_to_string (ValaCodeNode* base) {
 	ValaStringLiteral * self;
 	const char* _tmp0;
@@ -121,48 +135,17 @@ void vala_string_literal_set_value (ValaStringLiteral* self, const char* value)
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "value");
-}
-
-
-static void vala_string_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaStringLiteral * self;
-	self = VALA_STRING_LITERAL (object);
-	switch (property_id) {
-		case VALA_STRING_LITERAL_VALUE:
-		g_value_set_string (value, vala_string_literal_get_value (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_string_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaStringLiteral * self;
-	self = VALA_STRING_LITERAL (object);
-	switch (property_id) {
-		case VALA_STRING_LITERAL_VALUE:
-		vala_string_literal_set_value (self, g_value_get_string (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 	vala_string_literal_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_string_literal_finalize;
 	g_type_class_add_private (klass, sizeof (ValaStringLiteralPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_string_literal_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_string_literal_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_string_literal_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_string_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_string_literal_real_is_pure;
+	VALA_EXPRESSION_CLASS (klass)->is_non_null = vala_string_literal_real_is_non_null;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_string_literal_real_to_string;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -171,18 +154,18 @@ static void vala_string_literal_instance_init (ValaStringLiteral * self) {
 }
 
 
-static void vala_string_literal_finalize (GObject * obj) {
+static void vala_string_literal_finalize (ValaCodeNode* obj) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (obj);
 	self->priv->_value = (g_free (self->priv->_value), NULL);
-	G_OBJECT_CLASS (vala_string_literal_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_string_literal_parent_class)->finalize (obj);
 }
 
 
 GType vala_string_literal_get_type (void) {
 	static GType vala_string_literal_type_id = 0;
 	if (vala_string_literal_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaStringLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_string_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStringLiteral), 0, (GInstanceInitFunc) vala_string_literal_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaStringLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_string_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStringLiteral), 0, (GInstanceInitFunc) vala_string_literal_instance_init, NULL };
 		vala_string_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaStringLiteral", &g_define_type_info, 0);
 	}
 	return vala_string_literal_type_id;
