@@ -40,15 +40,13 @@ struct _ValaTryStatementPrivate {
 
 #define VALA_TRY_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TRY_STATEMENT, ValaTryStatementPrivate))
 enum  {
-	VALA_TRY_STATEMENT_DUMMY_PROPERTY,
-	VALA_TRY_STATEMENT_BODY,
-	VALA_TRY_STATEMENT_FINALLY_BODY
+	VALA_TRY_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_try_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_try_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_try_statement_parent_class = NULL;
 static ValaStatementIface* vala_try_statement_vala_statement_parent_iface = NULL;
-static void vala_try_statement_dispose (GObject * obj);
+static void vala_try_statement_finalize (ValaCodeNode* obj);
 
 
 
@@ -60,12 +58,12 @@ static void vala_try_statement_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created try statement
  */
-ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference) {
-	ValaTryStatement * self;
+ValaTryStatement* vala_try_statement_construct (GType object_type, ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference) {
+	ValaTryStatement* self;
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (finally_body == NULL || VALA_IS_BLOCK (finally_body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = g_object_newv (VALA_TYPE_TRY_STATEMENT, 0, NULL);
+	self = ((ValaTryStatement*) (g_type_create_instance (object_type)));
 	vala_try_statement_set_body (self, body);
 	vala_try_statement_set_finally_body (self, finally_body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -73,6 +71,11 @@ ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_bo
 }
 
 
+ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference) {
+	return vala_try_statement_construct (VALA_TYPE_TRY_STATEMENT, body, finally_body, source_reference);
+}
+
+
 /**
  * Appends the specified clause to the list of catch clauses.
  *
@@ -92,7 +95,7 @@ void vala_try_statement_add_catch_clause (ValaTryStatement* self, ValaCatchClaus
  */
 GeeList* vala_try_statement_get_catch_clauses (ValaTryStatement* self) {
 	g_return_val_if_fail (VALA_IS_TRY_STATEMENT (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CATCH_CLAUSE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->catch_clauses));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CATCH_CLAUSE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, self->priv->catch_clauses));
 }
 
 
@@ -118,7 +121,7 @@ static void vala_try_statement_real_accept_children (ValaCodeNode* base, ValaCod
 			clause = ((ValaCatchClause*) (gee_list_get (GEE_LIST (clause_collection), clause_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (clause), visitor);
-				(clause == NULL ? NULL : (clause = (g_object_unref (clause), NULL)));
+				(clause == NULL ? NULL : (clause = (vala_code_node_unref (clause), NULL)));
 			}
 		}
 	}
@@ -140,7 +143,7 @@ void vala_try_statement_set_body (ValaTryStatement* self, ValaBlock* value) {
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -156,54 +159,16 @@ void vala_try_statement_set_finally_body (ValaTryStatement* self, ValaBlock* val
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_finally_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (g_object_unref (self->priv->_finally_body), NULL))), _tmp2);
-}
-
-
-static void vala_try_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaTryStatement * self;
-	self = VALA_TRY_STATEMENT (object);
-	switch (property_id) {
-		case VALA_TRY_STATEMENT_BODY:
-		g_value_set_object (value, vala_try_statement_get_body (self));
-		break;
-		case VALA_TRY_STATEMENT_FINALLY_BODY:
-		g_value_set_object (value, vala_try_statement_get_finally_body (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_try_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaTryStatement * self;
-	self = VALA_TRY_STATEMENT (object);
-	switch (property_id) {
-		case VALA_TRY_STATEMENT_BODY:
-		vala_try_statement_set_body (self, g_value_get_object (value));
-		break;
-		case VALA_TRY_STATEMENT_FINALLY_BODY:
-		vala_try_statement_set_finally_body (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+	self->priv->_finally_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (vala_code_node_unref (self->priv->_finally_body), NULL))), _tmp2);
 }
 
 
 static void vala_try_statement_class_init (ValaTryStatementClass * klass) {
 	vala_try_statement_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_try_statement_finalize;
 	g_type_class_add_private (klass, sizeof (ValaTryStatementPrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_try_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_try_statement_set_property;
-	G_OBJECT_CLASS (klass)->dispose = vala_try_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_try_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_try_statement_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TRY_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TRY_STATEMENT_FINALLY_BODY, g_param_spec_object ("finally-body", "finally-body", "finally-body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -214,24 +179,24 @@ static void vala_try_statement_vala_statement_interface_init (ValaStatementIface
 
 static void vala_try_statement_instance_init (ValaTryStatement * self) {
 	self->priv = VALA_TRY_STATEMENT_GET_PRIVATE (self);
-	self->priv->catch_clauses = GEE_LIST (gee_array_list_new (VALA_TYPE_CATCH_CLAUSE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->catch_clauses = GEE_LIST (gee_array_list_new (VALA_TYPE_CATCH_CLAUSE, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_try_statement_dispose (GObject * obj) {
+static void vala_try_statement_finalize (ValaCodeNode* obj) {
 	ValaTryStatement * self;
 	self = VALA_TRY_STATEMENT (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (g_object_unref (self->priv->_finally_body), NULL)));
-	(self->priv->catch_clauses == NULL ? NULL : (self->priv->catch_clauses = (g_object_unref (self->priv->catch_clauses), NULL)));
-	G_OBJECT_CLASS (vala_try_statement_parent_class)->dispose (obj);
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
+	(self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (vala_code_node_unref (self->priv->_finally_body), NULL)));
+	(self->priv->catch_clauses == NULL ? NULL : (self->priv->catch_clauses = (gee_collection_object_unref (self->priv->catch_clauses), NULL)));
+	VALA_CODE_NODE_CLASS (vala_try_statement_parent_class)->finalize (obj);
 }
 
 
 GType vala_try_statement_get_type (void) {
 	static GType vala_try_statement_type_id = 0;
-	if (G_UNLIKELY (vala_try_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTryStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_try_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTryStatement), 0, (GInstanceInitFunc) vala_try_statement_instance_init };
+	if (vala_try_statement_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTryStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_try_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTryStatement), 0, (GInstanceInitFunc) vala_try_statement_instance_init, NULL };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_try_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_try_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaTryStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_try_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
