@@ -37,14 +37,19 @@ enum  {
 };
 static gboolean vala_tuple_real_is_pure (ValaExpression* base);
 static gpointer vala_tuple_parent_class = NULL;
-static void vala_tuple_dispose (GObject * obj);
+static void vala_tuple_finalize (ValaCodeNode* obj);
 
 
 
+ValaTuple* vala_tuple_construct (GType object_type) {
+	ValaTuple* self;
+	self = ((ValaTuple*) (g_type_create_instance (object_type)));
+	return self;
+}
+
+
 ValaTuple* vala_tuple_new (void) {
-	ValaTuple * self;
-	self = g_object_newv (VALA_TYPE_TUPLE, 0, NULL);
-	return self;
+	return vala_tuple_construct (VALA_TYPE_TUPLE);
 }
 
 
@@ -59,7 +64,7 @@ GeeList* vala_tuple_get_expressions (ValaTuple* self) {
 	GeeList* _tmp0;
 	g_return_val_if_fail (VALA_IS_TUPLE (self), NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->expression_list, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	return (_tmp0 = self->priv->expression_list, (_tmp0 == NULL ? NULL : gee_collection_object_ref (_tmp0)));
 }
 
 
@@ -72,30 +77,30 @@ static gboolean vala_tuple_real_is_pure (ValaExpression* base) {
 
 static void vala_tuple_class_init (ValaTupleClass * klass) {
 	vala_tuple_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_tuple_finalize;
 	g_type_class_add_private (klass, sizeof (ValaTuplePrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_tuple_dispose;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_tuple_real_is_pure;
 }
 
 
-static void vala_tuple_init (ValaTuple * self) {
+static void vala_tuple_instance_init (ValaTuple * self) {
 	self->priv = VALA_TUPLE_GET_PRIVATE (self);
-	self->priv->expression_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->expression_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal));
 }
 
 
-static void vala_tuple_dispose (GObject * obj) {
+static void vala_tuple_finalize (ValaCodeNode* obj) {
 	ValaTuple * self;
 	self = VALA_TUPLE (obj);
-	(self->priv->expression_list == NULL ? NULL : (self->priv->expression_list = (g_object_unref (self->priv->expression_list), NULL)));
-	G_OBJECT_CLASS (vala_tuple_parent_class)->dispose (obj);
+	(self->priv->expression_list == NULL ? NULL : (self->priv->expression_list = (gee_collection_object_unref (self->priv->expression_list), NULL)));
+	VALA_CODE_NODE_CLASS (vala_tuple_parent_class)->finalize (obj);
 }
 
 
 GType vala_tuple_get_type (void) {
 	static GType vala_tuple_type_id = 0;
-	if (G_UNLIKELY (vala_tuple_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTupleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_tuple_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTuple), 0, (GInstanceInitFunc) vala_tuple_init };
+	if (vala_tuple_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTupleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_tuple_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTuple), 0, (GInstanceInitFunc) vala_tuple_instance_init, NULL };
 		vala_tuple_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaTuple", &g_define_type_info, 0);
 	}
 	return vala_tuple_type_id;
