@@ -21,24 +21,18 @@
  */
 
 #include <vala/valatypeparameter.h>
-#include <gee/map.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 
 
 
-struct _ValaTypeParameterPrivate {
-	GeeMap* array_types;
-};
-
-#define VALA_TYPEPARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPEPARAMETER, ValaTypeParameterPrivate))
 enum  {
 	VALA_TYPEPARAMETER_DUMMY_PROPERTY
 };
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_typeparameter_parent_class = NULL;
-static void vala_typeparameter_dispose (GObject * obj);
+static void vala_typeparameter_finalize (ValaCodeNode* obj);
 
 
 
@@ -49,17 +43,23 @@ static void vala_typeparameter_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created generic type parameter
  */
-ValaTypeParameter* vala_typeparameter_new (const char* _name, ValaSourceReference* source) {
-	ValaTypeParameter * self;
+ValaTypeParameter* vala_typeparameter_construct (GType object_type, const char* _name, ValaSourceReference* source) {
+	ValaTypeParameter* self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = g_object_newv (VALA_TYPE_TYPEPARAMETER, 0, NULL);
+	self = ((ValaTypeParameter*) (g_type_create_instance (object_type)));
+	vala_symbol_init (VALA_SYMBOL (self));
 	vala_symbol_set_name (VALA_SYMBOL (self), _name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
+ValaTypeParameter* vala_typeparameter_new (const char* _name, ValaSourceReference* source) {
+	return vala_typeparameter_construct (VALA_TYPE_TYPEPARAMETER, _name, source);
+}
+
+
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeParameter * self;
 	self = VALA_TYPEPARAMETER (base);
@@ -88,29 +88,26 @@ gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter*
 
 static void vala_typeparameter_class_init (ValaTypeParameterClass * klass) {
 	vala_typeparameter_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (ValaTypeParameterPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_typeparameter_dispose;
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_typeparameter_finalize;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_typeparameter_real_accept;
 }
 
 
-static void vala_typeparameter_init (ValaTypeParameter * self) {
-	self->priv = VALA_TYPEPARAMETER_GET_PRIVATE (self);
+static void vala_typeparameter_instance_init (ValaTypeParameter * self) {
 }
 
 
-static void vala_typeparameter_dispose (GObject * obj) {
+static void vala_typeparameter_finalize (ValaCodeNode* obj) {
 	ValaTypeParameter * self;
 	self = VALA_TYPEPARAMETER (obj);
-	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL)));
-	G_OBJECT_CLASS (vala_typeparameter_parent_class)->dispose (obj);
+	VALA_CODE_NODE_CLASS (vala_typeparameter_parent_class)->finalize (obj);
 }
 
 
 GType vala_typeparameter_get_type (void) {
 	static GType vala_typeparameter_type_id = 0;
-	if (G_UNLIKELY (vala_typeparameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameter), 0, (GInstanceInitFunc) vala_typeparameter_init };
+	if (vala_typeparameter_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameter), 0, (GInstanceInitFunc) vala_typeparameter_instance_init, NULL };
 		vala_typeparameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaTypeParameter", &g_define_type_info, 0);
 	}
 	return vala_typeparameter_type_id;
