@@ -36,15 +36,20 @@ static gpointer vala_typeparameter_type_parent_class = NULL;
 
 
 
-ValaTypeParameterType* vala_typeparameter_type_new (ValaTypeParameter* type_parameter) {
-	ValaTypeParameterType * self;
+ValaTypeParameterType* vala_typeparameter_type_construct (GType object_type, ValaTypeParameter* type_parameter) {
+	ValaTypeParameterType* self;
 	g_return_val_if_fail (VALA_IS_TYPEPARAMETER (type_parameter), NULL);
-	self = g_object_newv (VALA_TYPE_TYPEPARAMETER_TYPE, 0, NULL);
+	self = ((ValaTypeParameterType*) (g_type_create_instance (object_type)));
 	vala_data_type_set_type_parameter (VALA_DATA_TYPE (self), type_parameter);
 	return self;
 }
 
 
+ValaTypeParameterType* vala_typeparameter_type_new (ValaTypeParameter* type_parameter) {
+	return vala_typeparameter_type_construct (VALA_TYPE_TYPEPARAMETER_TYPE, type_parameter);
+}
+
+
 static ValaDataType* vala_typeparameter_type_real_copy (ValaDataType* base) {
 	ValaTypeParameterType * self;
 	ValaTypeParameterType* result;
@@ -91,7 +96,7 @@ static void vala_typeparameter_type_instance_init (ValaTypeParameterType * self)
 GType vala_typeparameter_type_get_type (void) {
 	static GType vala_typeparameter_type_type_id = 0;
 	if (vala_typeparameter_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameterType), 0, (GInstanceInitFunc) vala_typeparameter_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameterType), 0, (GInstanceInitFunc) vala_typeparameter_type_instance_init, NULL };
 		vala_typeparameter_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaTypeParameterType", &g_define_type_info, 0);
 	}
 	return vala_typeparameter_type_type_id;
