@@ -23,7 +23,6 @@
 
 #include <vala/valatypesymbol.h>
 #include <gee/arraylist.h>
-#include <gee/map.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <vala/valacodenode.h>
@@ -35,7 +34,6 @@
 
 struct _ValaTypeSymbolPrivate {
 	GeeList* cheader_filenames;
-	GeeMap* array_types;
 };
 
 #define VALA_TYPESYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolPrivate))
@@ -53,6 +51,7 @@ static char* vala_typesymbol_real_get_ref_function (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_unref_function (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_type_id (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_marshaller_type_name (ValaTypeSymbol* self);
+static char* vala_typesymbol_real_get_param_spec_function (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_get_value_function (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_set_value_function (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_upper_case_cname (ValaTypeSymbol* self, const char* infix);
@@ -62,7 +61,7 @@ static gboolean vala_typesymbol_real_is_subtype_of (ValaTypeSymbol* self, ValaTy
 static gint vala_typesymbol_real_get_type_parameter_index (ValaTypeSymbol* self, const char* name);
 static char* vala_typesymbol_real_get_type_signature (ValaTypeSymbol* self);
 static gpointer vala_typesymbol_parent_class = NULL;
-static void vala_typesymbol_finalize (GObject * obj);
+static void vala_typesymbol_finalize (ValaCodeNode* obj);
 
 
 
@@ -267,7 +266,21 @@ char* vala_typesymbol_get_marshaller_type_name (ValaTypeSymbol* self) {
 
 
 /**
- * Returns the cname of the GValue getter function,
+ * Returns the cname of the GValue parameter spec function.
+ */
+static char* vala_typesymbol_real_get_param_spec_function (ValaTypeSymbol* self) {
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (self), NULL);
+	return NULL;
+}
+
+
+char* vala_typesymbol_get_param_spec_function (ValaTypeSymbol* self) {
+	return VALA_TYPESYMBOL_GET_CLASS (self)->get_param_spec_function (self);
+}
+
+
+/**
+ * Returns the cname of the GValue getter function.
  */
 static char* vala_typesymbol_real_get_get_value_function (ValaTypeSymbol* self) {
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (self), NULL);
@@ -281,7 +294,7 @@ char* vala_typesymbol_get_get_value_function (ValaTypeSymbol* self) {
 
 
 /**
- * Returns the cname of the GValue setter function,
+ * Returns the cname of the GValue setter function.
  */
 static char* vala_typesymbol_real_get_set_value_function (ValaTypeSymbol* self) {
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (self), NULL);
@@ -349,7 +362,7 @@ static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
+			(filename_collection == NULL ? NULL : (filename_collection = (gee_collection_object_unref (filename_collection), NULL)));
 		}
 		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_symbol_get_external_package (VALA_SYMBOL (self))) {
 			char* _tmp0;
@@ -426,8 +439,8 @@ char* vala_typesymbol_get_type_signature (ValaTypeSymbol* self) {
 
 static void vala_typesymbol_class_init (ValaTypeSymbolClass * klass) {
 	vala_typesymbol_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_typesymbol_finalize;
 	g_type_class_add_private (klass, sizeof (ValaTypeSymbolPrivate));
-	G_OBJECT_CLASS (klass)->finalize = vala_typesymbol_finalize;
 	VALA_TYPESYMBOL_CLASS (klass)->get_cname = vala_typesymbol_real_get_cname;
 	VALA_TYPESYMBOL_CLASS (klass)->is_reference_type = vala_typesymbol_real_is_reference_type;
 	VALA_TYPESYMBOL_CLASS (klass)->get_dup_function = vala_typesymbol_real_get_dup_function;
@@ -439,6 +452,7 @@ static void vala_typesymbol_class_init (ValaTypeSymbolClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_unref_function = vala_typesymbol_real_get_unref_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_id = vala_typesymbol_real_get_type_id;
 	VALA_TYPESYMBOL_CLASS (klass)->get_marshaller_type_name = vala_typesymbol_real_get_marshaller_type_name;
+	VALA_TYPESYMBOL_CLASS (klass)->get_param_spec_function = vala_typesymbol_real_get_param_spec_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_typesymbol_real_get_get_value_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_set_value_function = vala_typesymbol_real_get_set_value_function;
 	VALA_TYPESYMBOL_CLASS (klass)->get_upper_case_cname = vala_typesymbol_real_get_upper_case_cname;
@@ -456,19 +470,18 @@ static void vala_typesymbol_instance_init (ValaTypeSymbol * self) {
 }
 
 
-static void vala_typesymbol_finalize (GObject * obj) {
+static void vala_typesymbol_finalize (ValaCodeNode* obj) {
 	ValaTypeSymbol * self;
 	self = VALA_TYPESYMBOL (obj);
-	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
-	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL)));
-	G_OBJECT_CLASS (vala_typesymbol_parent_class)->finalize (obj);
+	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (gee_collection_object_unref (self->priv->cheader_filenames), NULL)));
+	VALA_CODE_NODE_CLASS (vala_typesymbol_parent_class)->finalize (obj);
 }
 
 
 GType vala_typesymbol_get_type (void) {
 	static GType vala_typesymbol_type_id = 0;
 	if (vala_typesymbol_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typesymbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeSymbol), 0, (GInstanceInitFunc) vala_typesymbol_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typesymbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeSymbol), 0, (GInstanceInitFunc) vala_typesymbol_instance_init, NULL };
 		vala_typesymbol_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaTypeSymbol", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_typesymbol_type_id;
