@@ -22,6 +22,7 @@
 
 #include <vala/valavaluetype.h>
 #include <vala/valacodenode.h>
+#include <vala/valastruct.h>
 
 
 
@@ -32,26 +33,31 @@ struct _ValaValueTypePrivate {
 
 #define VALA_VALUE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VALUE_TYPE, ValaValueTypePrivate))
 enum  {
-	VALA_VALUE_TYPE_DUMMY_PROPERTY,
-	VALA_VALUE_TYPE_TYPE_SYMBOL
+	VALA_VALUE_TYPE_DUMMY_PROPERTY
 };
 static ValaDataType* vala_value_type_real_copy (ValaDataType* base);
 static char* vala_value_type_real_get_cname (ValaDataType* base);
+static gboolean vala_value_type_real_is_disposable (ValaDataType* base);
 static gpointer vala_value_type_parent_class = NULL;
-static void vala_value_type_finalize (GObject * obj);
+static void vala_value_type_finalize (ValaCodeNode* obj);
 
 
 
-ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol) {
-	ValaValueType * self;
+ValaValueType* vala_value_type_construct (GType object_type, ValaTypeSymbol* type_symbol) {
+	ValaValueType* self;
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type_symbol), NULL);
-	self = g_object_newv (VALA_TYPE_VALUE_TYPE, 0, NULL);
+	self = ((ValaValueType*) (g_type_create_instance (object_type)));
 	vala_value_type_set_type_symbol (self, type_symbol);
 	vala_data_type_set_data_type (VALA_DATA_TYPE (self), type_symbol);
 	return self;
 }
 
 
+ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol) {
+	return vala_value_type_construct (VALA_TYPE_VALUE_TYPE, type_symbol);
+}
+
+
 static ValaDataType* vala_value_type_real_copy (ValaDataType* base) {
 	ValaValueType * self;
 	ValaValueType* result;
@@ -74,11 +80,11 @@ static ValaDataType* vala_value_type_real_copy (ValaDataType* base) {
 				ValaDataType* _tmp0;
 				_tmp0 = NULL;
 				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
-				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
-				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)));
+				(arg == NULL ? NULL : (arg = (vala_code_node_unref (arg), NULL)));
 			}
 		}
-		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
+		(arg_collection == NULL ? NULL : (arg_collection = (gee_collection_object_unref (arg_collection), NULL)));
 	}
 	return VALA_DATA_TYPE (result);
 }
@@ -104,6 +110,31 @@ static char* vala_value_type_real_get_cname (ValaDataType* base) {
 }
 
 
+static gboolean vala_value_type_real_is_disposable (ValaDataType* base) {
+	ValaValueType * self;
+	ValaStruct* _tmp3;
+	ValaTypeSymbol* _tmp2;
+	ValaStruct* st;
+	gboolean _tmp5;
+	self = VALA_VALUE_TYPE (base);
+	if (!vala_data_type_get_value_owned (VALA_DATA_TYPE (self))) {
+		return FALSE;
+	}
+	/* nullable structs are heap allocated*/
+	if (vala_data_type_get_nullable (VALA_DATA_TYPE (self))) {
+		return TRUE;
+	}
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	st = (_tmp3 = (_tmp2 = self->priv->_type_symbol, (VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : vala_code_node_ref (_tmp3)));
+	if (st != NULL) {
+		gboolean _tmp4;
+		return (_tmp4 = vala_struct_is_disposable (st), (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp4);
+	}
+	return (_tmp5 = FALSE, (st == NULL ? NULL : (st = (vala_code_node_unref (st), NULL))), _tmp5);
+}
+
+
 ValaTypeSymbol* vala_value_type_get_type_symbol (ValaValueType* self) {
 	g_return_val_if_fail (VALA_IS_VALUE_TYPE (self), NULL);
 	return self->priv->_type_symbol;
@@ -113,47 +144,16 @@ ValaTypeSymbol* vala_value_type_get_type_symbol (ValaValueType* self) {
 void vala_value_type_set_type_symbol (ValaValueType* self, ValaTypeSymbol* value) {
 	g_return_if_fail (VALA_IS_VALUE_TYPE (self));
 	self->priv->_type_symbol = value;
-	g_object_notify (((GObject *) (self)), "type-symbol");
-}
-
-
-static void vala_value_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaValueType * self;
-	self = VALA_VALUE_TYPE (object);
-	switch (property_id) {
-		case VALA_VALUE_TYPE_TYPE_SYMBOL:
-		g_value_set_object (value, vala_value_type_get_type_symbol (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_value_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaValueType * self;
-	self = VALA_VALUE_TYPE (object);
-	switch (property_id) {
-		case VALA_VALUE_TYPE_TYPE_SYMBOL:
-		vala_value_type_set_type_symbol (self, g_value_get_object (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
 }
 
 
 static void vala_value_type_class_init (ValaValueTypeClass * klass) {
 	vala_value_type_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_value_type_finalize;
 	g_type_class_add_private (klass, sizeof (ValaValueTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_value_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_value_type_set_property;
-	G_OBJECT_CLASS (klass)->finalize = vala_value_type_finalize;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_value_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_value_type_real_get_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_VALUE_TYPE_TYPE_SYMBOL, g_param_spec_object ("type-symbol", "type-symbol", "type-symbol", VALA_TYPE_TYPESYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_DATA_TYPE_CLASS (klass)->is_disposable = vala_value_type_real_is_disposable;
 }
 
 
@@ -162,17 +162,17 @@ static void vala_value_type_instance_init (ValaValueType * self) {
 }
 
 
-static void vala_value_type_finalize (GObject * obj) {
+static void vala_value_type_finalize (ValaCodeNode* obj) {
 	ValaValueType * self;
 	self = VALA_VALUE_TYPE (obj);
-	G_OBJECT_CLASS (vala_value_type_parent_class)->finalize (obj);
+	VALA_CODE_NODE_CLASS (vala_value_type_parent_class)->finalize (obj);
 }
 
 
 GType vala_value_type_get_type (void) {
 	static GType vala_value_type_type_id = 0;
 	if (vala_value_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaValueTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_value_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaValueType), 0, (GInstanceInitFunc) vala_value_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaValueTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_value_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaValueType), 0, (GInstanceInitFunc) vala_value_type_instance_init, NULL };
 		vala_value_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaValueType", &g_define_type_info, 0);
 	}
 	return vala_value_type_type_id;
