@@ -36,13 +36,18 @@ static gpointer vala_void_type_parent_class = NULL;
 
 
 
-ValaVoidType* vala_void_type_new (void) {
-	ValaVoidType * self;
-	self = g_object_newv (VALA_TYPE_VOID_TYPE, 0, NULL);
+ValaVoidType* vala_void_type_construct (GType object_type) {
+	ValaVoidType* self;
+	self = ((ValaVoidType*) (g_type_create_instance (object_type)));
 	return self;
 }
 
 
+ValaVoidType* vala_void_type_new (void) {
+	return vala_void_type_construct (VALA_TYPE_VOID_TYPE);
+}
+
+
 static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType* type2) {
 	ValaVoidType * self;
 	self = VALA_VOID_TYPE (base);
@@ -89,7 +94,7 @@ static void vala_void_type_instance_init (ValaVoidType * self) {
 GType vala_void_type_get_type (void) {
 	static GType vala_void_type_type_id = 0;
 	if (vala_void_type_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVoidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_void_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVoidType), 0, (GInstanceInitFunc) vala_void_type_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVoidTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_void_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVoidType), 0, (GInstanceInitFunc) vala_void_type_instance_init, NULL };
 		vala_void_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaVoidType", &g_define_type_info, 0);
 	}
 	return vala_void_type_type_id;
