@@ -34,6 +34,7 @@
 #include <vala/valasymbolresolver.h>
 #include <vala/valainterfacewriter.h>
 #include <config.h>
+#include "vapigen/valagirparser.h"
 #include "vapigen/valagidlparser.h"
 
 
@@ -74,18 +75,20 @@ static char** vala_vapi_gen_sources;
 static char** vala_vapi_gen_vapi_directories;
 static char* vala_vapi_gen_library;
 static char** vala_vapi_gen_packages;
+static char* vala_vapi_gen_metadata_filename;
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
 static gint vala_vapi_gen_run (ValaVAPIGen* self);
 static gint vala_vapi_gen_main (char** args, int args_length1);
+static ValaVAPIGen* vala_vapi_gen_construct (GType object_type);
 static ValaVAPIGen* vala_vapi_gen_new (void);
 static gpointer vala_vapi_gen_parent_class = NULL;
-static void vala_vapi_gen_finalize (GObject * obj);
+static void vala_vapi_gen_finalize (GObject* obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
-static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) (0)), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) (0)), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) (0)), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
+static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) (0)), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) (0)), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"metadata", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_metadata_filename, "Metadata filename", "FILE"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) (0)), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 
 
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
@@ -121,8 +124,8 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	}
 	vala_code_context_add_package (self->priv->context, pkg);
 	_tmp2 = NULL;
-	vala_code_context_add_source_file (self->priv->context, (_tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE)));
-	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+	vala_code_context_add_source_file (self->priv->context, (_tmp2 = vala_source_file_new (self->priv->context, package_path, TRUE, NULL)));
+	(_tmp2 == NULL ? NULL : (_tmp2 = (vala_source_file_unref (_tmp2), NULL)));
 	return (_tmp3 = TRUE, (package_path = (g_free (package_path), NULL)), _tmp3);
 }
 
@@ -146,7 +149,7 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 		_tmp1;
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
-				goto __catch2_g_file_error;
+				goto __catch4_g_file_error;
 			}
 			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 			g_clear_error (&inner_error);
@@ -155,8 +158,8 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 		_tmp4 = NULL;
 		return (_tmp4 = (_tmp3 = g_strsplit (g_strstrip (contents), "\n", 0), (*result_length1) = -1, _tmp3), (contents = (g_free (contents), NULL)), _tmp4);
 	}
-	goto __finally2;
-	__catch2_g_file_error:
+	goto __finally4;
+	__catch4_g_file_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -169,7 +172,7 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 			return (_tmp6 = (_tmp5 = NULL, (*result_length1) = 0, _tmp5), (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp6);
 		}
 	}
-	__finally2:
+	__finally4:
 	;
 }
 
@@ -179,12 +182,13 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	char** _tmp16;
 	ValaParser* parser;
 	ValaAttributeProcessor* attributeprocessor;
+	ValaGirParser* girparser;
 	ValaGIdlParser* gidlparser;
 	ValaSymbolResolver* resolver;
-	gint _tmp24;
+	gint _tmp25;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
 	_tmp0 = NULL;
-	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp0);
+	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL))), _tmp0);
 	/* default package */
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
@@ -298,8 +302,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				if (g_file_test (source, G_FILE_TEST_EXISTS)) {
 					ValaSourceFile* _tmp13;
 					_tmp13 = NULL;
-					vala_code_context_add_source_file (self->priv->context, (_tmp13 = vala_source_file_new (self->priv->context, source, FALSE)));
-					(_tmp13 == NULL ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL)));
+					vala_code_context_add_source_file (self->priv->context, (_tmp13 = vala_source_file_new (self->priv->context, source, FALSE, NULL)));
+					(_tmp13 == NULL ? NULL : (_tmp13 = (vala_source_file_unref (_tmp13), NULL)));
 				} else {
 					char* _tmp14;
 					_tmp14 = NULL;
@@ -319,39 +323,48 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	vala_parser_parse (parser, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp18;
-		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), _tmp18);
+		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), _tmp18);
 	}
 	attributeprocessor = vala_attribute_processor_new ();
 	vala_attribute_processor_process (attributeprocessor, self->priv->context);
 	if (vala_report_get_errors () > 0) {
 		gint _tmp19;
-		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), _tmp19);
+		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (vala_code_visitor_unref (attributeprocessor), NULL))), _tmp19);
+	}
+	girparser = vala_gir_parser_new ();
+	if (vala_vapi_gen_metadata_filename != NULL) {
+		vala_gir_parser_parse_metadata (girparser, vala_vapi_gen_metadata_filename);
+	}
+	vala_gir_parser_parse (girparser, self->priv->context);
+	if (vala_report_get_errors () > 0) {
+		gint _tmp20;
+		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (vala_code_visitor_unref (attributeprocessor), NULL))), (girparser == NULL ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL))), _tmp20);
 	}
 	gidlparser = vala_gidl_parser_new ();
 	vala_gidl_parser_parse (gidlparser, self->priv->context);
 	if (vala_report_get_errors () > 0) {
-		gint _tmp20;
-		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), _tmp20);
+		gint _tmp21;
+		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (vala_code_visitor_unref (attributeprocessor), NULL))), (girparser == NULL ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL))), _tmp21);
 	}
 	resolver = vala_symbol_resolver_new ();
 	vala_symbol_resolver_resolve (resolver, self->priv->context);
 	if (vala_report_get_errors () > 0) {
-		gint _tmp21;
-		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), _tmp21);
+		gint _tmp22;
+		return (_tmp22 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (vala_code_visitor_unref (attributeprocessor), NULL))), (girparser == NULL ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL))), _tmp22);
 	}
 	if (vala_vapi_gen_library != NULL) {
 		ValaInterfaceWriter* interface_writer;
-		char* _tmp22;
 		char* _tmp23;
+		char* _tmp24;
 		interface_writer = vala_interface_writer_new ();
-		_tmp22 = NULL;
-		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp22 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library)));
-		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp23 = NULL;
-		vala_vapi_gen_library = (_tmp23 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), _tmp23);
-		(interface_writer == NULL ? NULL : (interface_writer = (g_object_unref (interface_writer), NULL)));
+		vala_interface_writer_write_file (interface_writer, self->priv->context, (_tmp23 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library)));
+		_tmp23 = (g_free (_tmp23), NULL);
+		_tmp24 = NULL;
+		vala_vapi_gen_library = (_tmp24 = NULL, (vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL)), _tmp24);
+		(interface_writer == NULL ? NULL : (interface_writer = (vala_code_visitor_unref (interface_writer), NULL)));
 	}
-	return (_tmp24 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (g_object_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (g_object_unref (attributeprocessor), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (g_object_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (g_object_unref (resolver), NULL))), _tmp24);
+	return (_tmp25 = vala_vapi_gen_quit (self), (parser == NULL ? NULL : (parser = (vala_code_visitor_unref (parser), NULL))), (attributeprocessor == NULL ? NULL : (attributeprocessor = (vala_code_visitor_unref (attributeprocessor), NULL))), (girparser == NULL ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL))), (gidlparser == NULL ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL))), (resolver == NULL ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL))), _tmp25);
 }
 
 
@@ -368,15 +381,15 @@ static gint vala_vapi_gen_main (char** args, int args_length1) {
 		g_option_context_parse (opt_context, &args_length1, &args, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_OPTION_ERROR) {
-				goto __catch3_g_option_error;
+				goto __catch5_g_option_error;
 			}
 			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 			g_clear_error (&inner_error);
 		}
 		(opt_context == NULL ? NULL : (opt_context = (g_option_context_free (opt_context), NULL)));
 	}
-	goto __finally3;
-	__catch3_g_option_error:
+	goto __finally5;
+	__catch5_g_option_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -388,7 +401,7 @@ static gint vala_vapi_gen_main (char** args, int args_length1) {
 			return (_tmp0 = 1, (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp0);
 		}
 	}
-	__finally3:
+	__finally5:
 	;
 	if (vala_vapi_gen_version) {
 		fprintf (stdout, "Vala API Generator %s\n", PACKAGE_VERSION);
@@ -409,13 +422,18 @@ int main (int argc, char ** argv) {
 }
 
 
-static ValaVAPIGen* vala_vapi_gen_new (void) {
+static ValaVAPIGen* vala_vapi_gen_construct (GType object_type) {
 	ValaVAPIGen * self;
-	self = g_object_newv (VALA_TYPE_VAPI_GEN, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
+static ValaVAPIGen* vala_vapi_gen_new (void) {
+	return vala_vapi_gen_construct (VALA_TYPE_VAPI_GEN);
+}
+
+
 static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass) {
 	vala_vapi_gen_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaVAPIGenPrivate));
@@ -428,10 +446,10 @@ static void vala_vapi_gen_instance_init (ValaVAPIGen * self) {
 }
 
 
-static void vala_vapi_gen_finalize (GObject * obj) {
+static void vala_vapi_gen_finalize (GObject* obj) {
 	ValaVAPIGen * self;
 	self = VALA_VAPI_GEN (obj);
-	(self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL)));
+	(self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)));
 	G_OBJECT_CLASS (vala_vapi_gen_parent_class)->finalize (obj);
 }
 
@@ -439,7 +457,7 @@ static void vala_vapi_gen_finalize (GObject * obj) {
 static GType vala_vapi_gen_get_type (void) {
 	static GType vala_vapi_gen_type_id = 0;
 	if (vala_vapi_gen_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_instance_init, NULL };
 		vala_vapi_gen_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPIGen", &g_define_type_info, 0);
 	}
 	return vala_vapi_gen_type_id;
